//#region ../../node_modules/.pnpm/prettier@3.8.2/node_modules/prettier/plugins/acorn.mjs
var Ii = Object.create;
var Be = Object.defineProperty;
var Ni = Object.getOwnPropertyDescriptor;
var Li = Object.getOwnPropertyNames;
var Ri = Object.getPrototypeOf, Vi = Object.prototype.hasOwnProperty;
var ot = (e, t) => () => (t || e((t = { exports: {} }).exports, t), t.exports), Oi = (e, t) => {
	for (var i in t) Be(e, i, {
		get: t[i],
		enumerable: !0
	});
}, Bi = (e, t, i, s) => {
	if (t && typeof t == "object" || typeof t == "function") for (let r of Li(t)) !Vi.call(e, r) && r !== i && Be(e, r, {
		get: () => t[r],
		enumerable: !(s = Ni(t, r)) || s.enumerable
	});
	return e;
};
var ut = (e, t, i) => (i = e != null ? Ii(Ri(e)) : {}, Bi(t || !e || !e.__esModule ? Be(i, "default", {
	value: e,
	enumerable: !0
}) : i, e));
var Qt = ot((xr, zt) => {
	zt.exports = {};
});
var $e = ot((yr, Ye) => {
	"use strict";
	var _s = Qt(), Cs = /^[\da-fA-F]+$/, Ts = /^\d+$/, Yt = /* @__PURE__ */ new WeakMap();
	function $t(e) {
		e = e.Parser.acorn || e;
		let t = Yt.get(e);
		if (!t) {
			let i = e.tokTypes, s = e.TokContext, r = e.TokenType, o = new s("<tag", !1), u = new s("</tag", !1), p = new s("<tag>...</tag>", !0, !0), h = {
				tc_oTag: o,
				tc_cTag: u,
				tc_expr: p
			}, l = {
				jsxName: new r("jsxName"),
				jsxText: new r("jsxText", { beforeExpr: !0 }),
				jsxTagStart: new r("jsxTagStart", { startsExpr: !0 }),
				jsxTagEnd: new r("jsxTagEnd")
			};
			l.jsxTagStart.updateContext = function() {
				this.context.push(p), this.context.push(o), this.exprAllowed = !1;
			}, l.jsxTagEnd.updateContext = function(m) {
				let S = this.context.pop();
				S === o && m === i.slash || S === u ? (this.context.pop(), this.exprAllowed = this.curContext() === p) : this.exprAllowed = !0;
			}, t = {
				tokContexts: h,
				tokTypes: l
			}, Yt.set(e, t);
		}
		return t;
	}
	function pe(e) {
		if (!e) return e;
		if (e.type === "JSXIdentifier") return e.name;
		if (e.type === "JSXNamespacedName") return e.namespace.name + ":" + e.name.name;
		if (e.type === "JSXMemberExpression") return pe(e.object) + "." + pe(e.property);
	}
	Ye.exports = function(e) {
		return e = e || {}, function(t) {
			return Es({
				allowNamespaces: e.allowNamespaces !== !1,
				allowNamespacedObjects: !!e.allowNamespacedObjects
			}, t);
		};
	};
	Object.defineProperty(Ye.exports, "tokTypes", {
		get: function() {
			return $t(void 0).tokTypes;
		},
		configurable: !0,
		enumerable: !0
	});
	function Es(e, t) {
		let i = t.acorn || void 0, s = $t(i), r = i.tokTypes, o = s.tokTypes, u = i.tokContexts, p = s.tokContexts.tc_oTag, h = s.tokContexts.tc_cTag, l = s.tokContexts.tc_expr, m = i.isNewLine, S = i.isIdentifierStart, E = i.isIdentifierChar;
		return class extends t {
			static get acornJsx() {
				return s;
			}
			jsx_readToken() {
				let c = "", x = this.pos;
				for (;;) {
					this.pos >= this.input.length && this.raise(this.start, "Unterminated JSX contents");
					let y = this.input.charCodeAt(this.pos);
					switch (y) {
						case 60:
						case 123: return this.pos === this.start ? y === 60 && this.exprAllowed ? (++this.pos, this.finishToken(o.jsxTagStart)) : this.getTokenFromCode(y) : (c += this.input.slice(x, this.pos), this.finishToken(o.jsxText, c));
						case 38:
							c += this.input.slice(x, this.pos), c += this.jsx_readEntity(), x = this.pos;
							break;
						case 62:
						case 125: this.raise(this.pos, "Unexpected token `" + this.input[this.pos] + "`. Did you mean `" + (y === 62 ? "&gt;" : "&rbrace;") + "` or `{\"" + this.input[this.pos] + "\"}`?");
						default: m(y) ? (c += this.input.slice(x, this.pos), c += this.jsx_readNewLine(!0), x = this.pos) : ++this.pos;
					}
				}
			}
			jsx_readNewLine(c) {
				let x = this.input.charCodeAt(this.pos), y;
				return ++this.pos, x === 13 && this.input.charCodeAt(this.pos) === 10 ? (++this.pos, y = c ? `
` : `\r
`) : y = String.fromCharCode(x), this.options.locations && (++this.curLine, this.lineStart = this.pos), y;
			}
			jsx_readString(c) {
				let x = "", y = ++this.pos;
				for (;;) {
					this.pos >= this.input.length && this.raise(this.start, "Unterminated string constant");
					let v = this.input.charCodeAt(this.pos);
					if (v === c) break;
					v === 38 ? (x += this.input.slice(y, this.pos), x += this.jsx_readEntity(), y = this.pos) : m(v) ? (x += this.input.slice(y, this.pos), x += this.jsx_readNewLine(!1), y = this.pos) : ++this.pos;
				}
				return x += this.input.slice(y, this.pos++), this.finishToken(r.string, x);
			}
			jsx_readEntity() {
				let c = "", x = 0, y, v = this.input[this.pos];
				v !== "&" && this.raise(this.pos, "Entity must start with an ampersand");
				let I = ++this.pos;
				for (; this.pos < this.input.length && x++ < 10;) {
					if (v = this.input[this.pos++], v === ";") {
						c[0] === "#" ? c[1] === "x" ? (c = c.substr(2), Cs.test(c) && (y = String.fromCharCode(parseInt(c, 16)))) : (c = c.substr(1), Ts.test(c) && (y = String.fromCharCode(parseInt(c, 10)))) : y = _s[c];
						break;
					}
					c += v;
				}
				return y || (this.pos = I, "&");
			}
			jsx_readWord() {
				let c, x = this.pos;
				do
					c = this.input.charCodeAt(++this.pos);
				while (E(c) || c === 45);
				return this.finishToken(o.jsxName, this.input.slice(x, this.pos));
			}
			jsx_parseIdentifier() {
				let c = this.startNode();
				return this.type === o.jsxName ? c.name = this.value : this.type.keyword ? c.name = this.type.keyword : this.unexpected(), this.next(), this.finishNode(c, "JSXIdentifier");
			}
			jsx_parseNamespacedName() {
				let c = this.start, x = this.startLoc, y = this.jsx_parseIdentifier();
				if (!e.allowNamespaces || !this.eat(r.colon)) return y;
				var v = this.startNodeAt(c, x);
				return v.namespace = y, v.name = this.jsx_parseIdentifier(), this.finishNode(v, "JSXNamespacedName");
			}
			jsx_parseElementName() {
				if (this.type === o.jsxTagEnd) return "";
				let c = this.start, x = this.startLoc, y = this.jsx_parseNamespacedName();
				for (this.type === r.dot && y.type === "JSXNamespacedName" && !e.allowNamespacedObjects && this.unexpected(); this.eat(r.dot);) {
					let v = this.startNodeAt(c, x);
					v.object = y, v.property = this.jsx_parseIdentifier(), y = this.finishNode(v, "JSXMemberExpression");
				}
				return y;
			}
			jsx_parseAttributeValue() {
				switch (this.type) {
					case r.braceL:
						let c = this.jsx_parseExpressionContainer();
						return c.expression.type === "JSXEmptyExpression" && this.raise(c.start, "JSX attributes must only be assigned a non-empty expression"), c;
					case o.jsxTagStart:
					case r.string: return this.parseExprAtom();
					default: this.raise(this.start, "JSX value should be either an expression or a quoted JSX text");
				}
			}
			jsx_parseEmptyExpression() {
				let c = this.startNodeAt(this.lastTokEnd, this.lastTokEndLoc);
				return this.finishNodeAt(c, "JSXEmptyExpression", this.start, this.startLoc);
			}
			jsx_parseExpressionContainer() {
				let c = this.startNode();
				return this.next(), c.expression = this.type === r.braceR ? this.jsx_parseEmptyExpression() : this.parseExpression(), this.expect(r.braceR), this.finishNode(c, "JSXExpressionContainer");
			}
			jsx_parseAttribute() {
				let c = this.startNode();
				return this.eat(r.braceL) ? (this.expect(r.ellipsis), c.argument = this.parseMaybeAssign(), this.expect(r.braceR), this.finishNode(c, "JSXSpreadAttribute")) : (c.name = this.jsx_parseNamespacedName(), c.value = this.eat(r.eq) ? this.jsx_parseAttributeValue() : null, this.finishNode(c, "JSXAttribute"));
			}
			jsx_parseOpeningElementAt(c, x) {
				let y = this.startNodeAt(c, x);
				y.attributes = [];
				let v = this.jsx_parseElementName();
				for (v && (y.name = v); this.type !== r.slash && this.type !== o.jsxTagEnd;) y.attributes.push(this.jsx_parseAttribute());
				return y.selfClosing = this.eat(r.slash), this.expect(o.jsxTagEnd), this.finishNode(y, v ? "JSXOpeningElement" : "JSXOpeningFragment");
			}
			jsx_parseClosingElementAt(c, x) {
				let y = this.startNodeAt(c, x), v = this.jsx_parseElementName();
				return v && (y.name = v), this.expect(o.jsxTagEnd), this.finishNode(y, v ? "JSXClosingElement" : "JSXClosingFragment");
			}
			jsx_parseElementAt(c, x) {
				let y = this.startNodeAt(c, x), v = [], I = this.jsx_parseOpeningElementAt(c, x), de = null;
				if (!I.selfClosing) {
					e: for (;;) switch (this.type) {
						case o.jsxTagStart:
							if (c = this.start, x = this.startLoc, this.next(), this.eat(r.slash)) {
								de = this.jsx_parseClosingElementAt(c, x);
								break e;
							}
							v.push(this.jsx_parseElementAt(c, x));
							break;
						case o.jsxText:
							v.push(this.parseExprAtom());
							break;
						case r.braceL:
							v.push(this.jsx_parseExpressionContainer());
							break;
						default: this.unexpected();
					}
					pe(de.name) !== pe(I.name) && this.raise(de.start, "Expected corresponding JSX closing tag for <" + pe(I.name) + ">");
				}
				let Oe = I.name ? "Element" : "Fragment";
				return y["opening" + Oe] = I, y["closing" + Oe] = de, y.children = v, this.type === r.relational && this.value === "<" && this.raise(this.start, "Adjacent JSX elements must be wrapped in an enclosing tag"), this.finishNode(y, "JSX" + Oe);
			}
			jsx_parseText() {
				let c = this.parseLiteral(this.value);
				return c.type = "JSXText", c;
			}
			jsx_parseElement() {
				let c = this.start, x = this.startLoc;
				return this.next(), this.jsx_parseElementAt(c, x);
			}
			parseExprAtom(c) {
				return this.type === o.jsxText ? this.jsx_parseText() : this.type === o.jsxTagStart ? this.jsx_parseElement() : super.parseExprAtom(c);
			}
			readToken(c) {
				let x = this.curContext();
				if (x === l) return this.jsx_readToken();
				if (x === p || x === h) {
					if (S(c)) return this.jsx_readWord();
					if (c == 62) return ++this.pos, this.finishToken(o.jsxTagEnd);
					if ((c === 34 || c === 39) && x == p) return this.jsx_readString(c);
				}
				return c === 60 && this.exprAllowed && this.input.charCodeAt(this.pos + 1) !== 33 ? (++this.pos, this.finishToken(o.jsxTagStart)) : super.readToken(c);
			}
			updateContext(c) {
				if (this.type == r.braceL) {
					var x = this.curContext();
					x == p ? this.context.push(u.b_expr) : x == l ? this.context.push(u.b_tmpl) : super.updateContext(c), this.exprAllowed = !0;
				} else if (this.type === r.slash && c === o.jsxTagStart) this.context.length -= 2, this.context.push(h), this.exprAllowed = !1;
				else return super.updateContext(c);
			}
		};
	}
});
var Pi = {};
Oi(Pi, { parsers: () => dr });
var Di = [
	509,
	0,
	227,
	0,
	150,
	4,
	294,
	9,
	1368,
	2,
	2,
	1,
	6,
	3,
	41,
	2,
	5,
	0,
	166,
	1,
	574,
	3,
	9,
	9,
	7,
	9,
	32,
	4,
	318,
	1,
	80,
	3,
	71,
	10,
	50,
	3,
	123,
	2,
	54,
	14,
	32,
	10,
	3,
	1,
	11,
	3,
	46,
	10,
	8,
	0,
	46,
	9,
	7,
	2,
	37,
	13,
	2,
	9,
	6,
	1,
	45,
	0,
	13,
	2,
	49,
	13,
	9,
	3,
	2,
	11,
	83,
	11,
	7,
	0,
	3,
	0,
	158,
	11,
	6,
	9,
	7,
	3,
	56,
	1,
	2,
	6,
	3,
	1,
	3,
	2,
	10,
	0,
	11,
	1,
	3,
	6,
	4,
	4,
	68,
	8,
	2,
	0,
	3,
	0,
	2,
	3,
	2,
	4,
	2,
	0,
	15,
	1,
	83,
	17,
	10,
	9,
	5,
	0,
	82,
	19,
	13,
	9,
	214,
	6,
	3,
	8,
	28,
	1,
	83,
	16,
	16,
	9,
	82,
	12,
	9,
	9,
	7,
	19,
	58,
	14,
	5,
	9,
	243,
	14,
	166,
	9,
	71,
	5,
	2,
	1,
	3,
	3,
	2,
	0,
	2,
	1,
	13,
	9,
	120,
	6,
	3,
	6,
	4,
	0,
	29,
	9,
	41,
	6,
	2,
	3,
	9,
	0,
	10,
	10,
	47,
	15,
	343,
	9,
	54,
	7,
	2,
	7,
	17,
	9,
	57,
	21,
	2,
	13,
	123,
	5,
	4,
	0,
	2,
	1,
	2,
	6,
	2,
	0,
	9,
	9,
	49,
	4,
	2,
	1,
	2,
	4,
	9,
	9,
	330,
	3,
	10,
	1,
	2,
	0,
	49,
	6,
	4,
	4,
	14,
	10,
	5350,
	0,
	7,
	14,
	11465,
	27,
	2343,
	9,
	87,
	9,
	39,
	4,
	60,
	6,
	26,
	9,
	535,
	9,
	470,
	0,
	2,
	54,
	8,
	3,
	82,
	0,
	12,
	1,
	19628,
	1,
	4178,
	9,
	519,
	45,
	3,
	22,
	543,
	4,
	4,
	5,
	9,
	7,
	3,
	6,
	31,
	3,
	149,
	2,
	1418,
	49,
	513,
	54,
	5,
	49,
	9,
	0,
	15,
	0,
	23,
	4,
	2,
	14,
	1361,
	6,
	2,
	16,
	3,
	6,
	2,
	1,
	2,
	4,
	101,
	0,
	161,
	6,
	10,
	9,
	357,
	0,
	62,
	13,
	499,
	13,
	245,
	1,
	2,
	9,
	726,
	6,
	110,
	6,
	6,
	9,
	4759,
	9,
	787719,
	239
], dt = [
	0,
	11,
	2,
	25,
	2,
	18,
	2,
	1,
	2,
	14,
	3,
	13,
	35,
	122,
	70,
	52,
	268,
	28,
	4,
	48,
	48,
	31,
	14,
	29,
	6,
	37,
	11,
	29,
	3,
	35,
	5,
	7,
	2,
	4,
	43,
	157,
	19,
	35,
	5,
	35,
	5,
	39,
	9,
	51,
	13,
	10,
	2,
	14,
	2,
	6,
	2,
	1,
	2,
	10,
	2,
	14,
	2,
	6,
	2,
	1,
	4,
	51,
	13,
	310,
	10,
	21,
	11,
	7,
	25,
	5,
	2,
	41,
	2,
	8,
	70,
	5,
	3,
	0,
	2,
	43,
	2,
	1,
	4,
	0,
	3,
	22,
	11,
	22,
	10,
	30,
	66,
	18,
	2,
	1,
	11,
	21,
	11,
	25,
	71,
	55,
	7,
	1,
	65,
	0,
	16,
	3,
	2,
	2,
	2,
	28,
	43,
	28,
	4,
	28,
	36,
	7,
	2,
	27,
	28,
	53,
	11,
	21,
	11,
	18,
	14,
	17,
	111,
	72,
	56,
	50,
	14,
	50,
	14,
	35,
	39,
	27,
	10,
	22,
	251,
	41,
	7,
	1,
	17,
	2,
	60,
	28,
	11,
	0,
	9,
	21,
	43,
	17,
	47,
	20,
	28,
	22,
	13,
	52,
	58,
	1,
	3,
	0,
	14,
	44,
	33,
	24,
	27,
	35,
	30,
	0,
	3,
	0,
	9,
	34,
	4,
	0,
	13,
	47,
	15,
	3,
	22,
	0,
	2,
	0,
	36,
	17,
	2,
	24,
	20,
	1,
	64,
	6,
	2,
	0,
	2,
	3,
	2,
	14,
	2,
	9,
	8,
	46,
	39,
	7,
	3,
	1,
	3,
	21,
	2,
	6,
	2,
	1,
	2,
	4,
	4,
	0,
	19,
	0,
	13,
	4,
	31,
	9,
	2,
	0,
	3,
	0,
	2,
	37,
	2,
	0,
	26,
	0,
	2,
	0,
	45,
	52,
	19,
	3,
	21,
	2,
	31,
	47,
	21,
	1,
	2,
	0,
	185,
	46,
	42,
	3,
	37,
	47,
	21,
	0,
	60,
	42,
	14,
	0,
	72,
	26,
	38,
	6,
	186,
	43,
	117,
	63,
	32,
	7,
	3,
	0,
	3,
	7,
	2,
	1,
	2,
	23,
	16,
	0,
	2,
	0,
	95,
	7,
	3,
	38,
	17,
	0,
	2,
	0,
	29,
	0,
	11,
	39,
	8,
	0,
	22,
	0,
	12,
	45,
	20,
	0,
	19,
	72,
	200,
	32,
	32,
	8,
	2,
	36,
	18,
	0,
	50,
	29,
	113,
	6,
	2,
	1,
	2,
	37,
	22,
	0,
	26,
	5,
	2,
	1,
	2,
	31,
	15,
	0,
	328,
	18,
	16,
	0,
	2,
	12,
	2,
	33,
	125,
	0,
	80,
	921,
	103,
	110,
	18,
	195,
	2637,
	96,
	16,
	1071,
	18,
	5,
	26,
	3994,
	6,
	582,
	6842,
	29,
	1763,
	568,
	8,
	30,
	18,
	78,
	18,
	29,
	19,
	47,
	17,
	3,
	32,
	20,
	6,
	18,
	433,
	44,
	212,
	63,
	129,
	74,
	6,
	0,
	67,
	12,
	65,
	1,
	2,
	0,
	29,
	6135,
	9,
	1237,
	42,
	9,
	8936,
	3,
	2,
	6,
	2,
	1,
	2,
	290,
	16,
	0,
	30,
	2,
	3,
	0,
	15,
	3,
	9,
	395,
	2309,
	106,
	6,
	12,
	4,
	8,
	8,
	9,
	5991,
	84,
	2,
	70,
	2,
	1,
	3,
	0,
	3,
	1,
	3,
	3,
	2,
	11,
	2,
	0,
	2,
	6,
	2,
	64,
	2,
	3,
	3,
	7,
	2,
	6,
	2,
	27,
	2,
	3,
	2,
	4,
	2,
	0,
	4,
	6,
	2,
	339,
	3,
	24,
	2,
	24,
	2,
	30,
	2,
	24,
	2,
	30,
	2,
	24,
	2,
	30,
	2,
	24,
	2,
	30,
	2,
	24,
	2,
	7,
	1845,
	30,
	7,
	5,
	262,
	61,
	147,
	44,
	11,
	6,
	17,
	0,
	322,
	29,
	19,
	43,
	485,
	27,
	229,
	29,
	3,
	0,
	496,
	6,
	2,
	3,
	2,
	1,
	2,
	14,
	2,
	196,
	60,
	67,
	8,
	0,
	1205,
	3,
	2,
	26,
	2,
	1,
	2,
	0,
	3,
	0,
	2,
	9,
	2,
	3,
	2,
	0,
	2,
	0,
	7,
	0,
	5,
	0,
	2,
	0,
	2,
	0,
	2,
	2,
	2,
	1,
	2,
	0,
	3,
	0,
	2,
	0,
	2,
	0,
	2,
	0,
	2,
	0,
	2,
	1,
	2,
	0,
	3,
	3,
	2,
	6,
	2,
	3,
	2,
	3,
	2,
	0,
	2,
	9,
	2,
	16,
	6,
	2,
	2,
	4,
	2,
	16,
	4421,
	42719,
	33,
	4153,
	7,
	221,
	3,
	5761,
	15,
	7472,
	16,
	621,
	2467,
	541,
	1507,
	4938,
	6,
	4191
], Mi = "‌‍·̀-ͯ·҃-֑҇-ׇֽֿׁׂׅׄؐ-ًؚ-٩ٰۖ-ۜ۟-۪ۤۧۨ-ۭ۰-۹ܑܰ-݊ަ-ް߀-߉߫-߽߳ࠖ-࠙ࠛ-ࠣࠥ-ࠧࠩ-࡙࠭-࡛ࢗ-࢟࣊-ࣣ࣡-ःऺ-़ा-ॏ॑-ॗॢॣ०-९ঁ-ঃ়া-ৄেৈো-্ৗৢৣ০-৯৾ਁ-ਃ਼ਾ-ੂੇੈੋ-੍ੑ੦-ੱੵઁ-ઃ઼ા-ૅે-ૉો-્ૢૣ૦-૯ૺ-૿ଁ-ଃ଼ା-ୄେୈୋ-୍୕-ୗୢୣ୦-୯ஂா-ூெ-ைொ-்ௗ௦-௯ఀ-ఄ఼ా-ౄె-ైొ-్ౕౖౢౣ౦-౯ಁ-ಃ಼ಾ-ೄೆ-ೈೊ-್ೕೖೢೣ೦-೯ೳഀ-ഃ഻഼ാ-ൄെ-ൈൊ-്ൗൢൣ൦-൯ඁ-ඃ්ා-ුූෘ-ෟ෦-෯ෲෳัิ-ฺ็-๎๐-๙ັິ-ຼ່-໎໐-໙༘༙༠-༩༹༵༷༾༿ཱ-྄྆྇ྍ-ྗྙ-ྼ࿆ါ-ှ၀-၉ၖ-ၙၞ-ၠၢ-ၤၧ-ၭၱ-ၴႂ-ႍႏ-ႝ፝-፟፩-፱ᜒ-᜕ᜲ-᜴ᝒᝓᝲᝳ឴-៓៝០-៩᠋-᠍᠏-᠙ᢩᤠ-ᤫᤰ-᤻᥆-᥏᧐-᧚ᨗ-ᨛᩕ-ᩞ᩠-᩿᩼-᪉᪐-᪙᪰-᪽ᪿ-ᫎᬀ-ᬄ᬴-᭄᭐-᭙᭫-᭳ᮀ-ᮂᮡ-ᮭ᮰-᮹᯦-᯳ᰤ-᰷᱀-᱉᱐-᱙᳐-᳔᳒-᳨᳭᳴᳷-᳹᷀-᷿‌‍‿⁀⁔⃐-⃥⃜⃡-⃰⳯-⵿⳱ⷠ-〪ⷿ-゙゚〯・꘠-꘩꙯ꙴ-꙽ꚞꚟ꛰꛱ꠂ꠆ꠋꠣ-ꠧ꠬ꢀꢁꢴ-ꣅ꣐-꣙꣠-꣱ꣿ-꤉ꤦ-꤭ꥇ-꥓ꦀ-ꦃ꦳-꧀꧐-꧙ꧥ꧰-꧹ꨩ-ꨶꩃꩌꩍ꩐-꩙ꩻ-ꩽꪰꪲ-ꪴꪷꪸꪾ꪿꫁ꫫ-ꫯꫵ꫶ꯣ-ꯪ꯬꯭꯰-꯹ﬞ︀-️︠-︯︳︴﹍-﹏０-９＿･", mt = "ªµºÀ-ÖØ-öø-ˁˆ-ˑˠ-ˤˬˮͰ-ʹͶͷͺ-ͽͿΆΈ-ΊΌΎ-ΡΣ-ϵϷ-ҁҊ-ԯԱ-Ֆՙՠ-ֈא-תׯ-ײؠ-يٮٯٱ-ۓەۥۦۮۯۺ-ۼۿܐܒ-ܯݍ-ޥޱߊ-ߪߴߵߺࠀ-ࠕࠚࠤࠨࡀ-ࡘࡠ-ࡪࡰ-ࢇࢉ-ࢎࢠ-ࣉऄ-हऽॐक़-ॡॱ-ঀঅ-ঌএঐও-নপ-রলশ-হঽৎড়ঢ়য়-ৡৰৱৼਅ-ਊਏਐਓ-ਨਪ-ਰਲਲ਼ਵਸ਼ਸਹਖ਼-ੜਫ਼ੲ-ੴઅ-ઍએ-ઑઓ-નપ-રલળવ-હઽૐૠૡૹଅ-ଌଏଐଓ-ନପ-ରଲଳଵ-ହଽଡ଼ଢ଼ୟ-ୡୱஃஅ-ஊஎ-ஐஒ-கஙசஜஞடணதந-பம-ஹௐఅ-ఌఎ-ఐఒ-నప-హఽౘ-ౚౝౠౡಀಅ-ಌಎ-ಐಒ-ನಪ-ಳವ-ಹಽೝೞೠೡೱೲഄ-ഌഎ-ഐഒ-ഺഽൎൔ-ൖൟ-ൡൺ-ൿඅ-ඖක-නඳ-රලව-ෆก-ะาำเ-ๆກຂຄຆ-ຊຌ-ຣລວ-ະາຳຽເ-ໄໆໜ-ໟༀཀ-ཇཉ-ཬྈ-ྌက-ဪဿၐ-ၕၚ-ၝၡၥၦၮ-ၰၵ-ႁႎႠ-ჅჇჍა-ჺჼ-ቈቊ-ቍቐ-ቖቘቚ-ቝበ-ኈኊ-ኍነ-ኰኲ-ኵኸ-ኾዀዂ-ዅወ-ዖዘ-ጐጒ-ጕጘ-ፚᎀ-ᎏᎠ-Ᏽᏸ-ᏽᐁ-ᙬᙯ-ᙿᚁ-ᚚᚠ-ᛪᛮ-ᛸᜀ-ᜑᜟ-ᜱᝀ-ᝑᝠ-ᝬᝮ-ᝰក-ឳៗៜᠠ-ᡸᢀ-ᢨᢪᢰ-ᣵᤀ-ᤞᥐ-ᥭᥰ-ᥴᦀ-ᦫᦰ-ᧉᨀ-ᨖᨠ-ᩔᪧᬅ-ᬳᭅ-ᭌᮃ-ᮠᮮᮯᮺ-ᯥᰀ-ᰣᱍ-ᱏᱚ-ᱽᲀ-ᲊᲐ-ᲺᲽ-Ჿᳩ-ᳬᳮ-ᳳᳵᳶᳺᴀ-ᶿḀ-ἕἘ-Ἕἠ-ὅὈ-Ὅὐ-ὗὙὛὝὟ-ώᾀ-ᾴᾶ-ᾼιῂ-ῄῆ-ῌῐ-ΐῖ-Ίῠ-Ῥῲ-ῴῶ-ῼⁱⁿₐ-ₜℂℇℊ-ℓℕ℘-ℝℤΩℨK-ℹℼ-ℿⅅ-ⅉⅎⅠ-ↈⰀ-ⳤⳫ-ⳮⳲⳳⴀ-ⴥⴧⴭⴰ-ⵧⵯⶀ-ⶖⶠ-ⶦⶨ-ⶮⶰ-ⶶⶸ-ⶾⷀ-ⷆⷈ-ⷎⷐ-ⷖⷘ-ⷞ々-〇〡-〩〱-〵〸-〼ぁ-ゖ゛-ゟァ-ヺー-ヿㄅ-ㄯㄱ-ㆎㆠ-ㆿㇰ-ㇿ㐀-䶿一-ꒌꓐ-ꓽꔀ-ꘌꘐ-ꘟꘪꘫꙀ-ꙮꙿ-ꚝꚠ-ꛯꜗ-ꜟꜢ-ꞈꞋ-ꟍꟐꟑꟓꟕ-Ƛꟲ-ꠁꠃ-ꠅꠇ-ꠊꠌ-ꠢꡀ-ꡳꢂ-ꢳꣲ-ꣷꣻꣽꣾꤊ-ꤥꤰ-ꥆꥠ-ꥼꦄ-ꦲꧏꧠ-ꧤꧦ-ꧯꧺ-ꧾꨀ-ꨨꩀ-ꩂꩄ-ꩋꩠ-ꩶꩺꩾ-ꪯꪱꪵꪶꪹ-ꪽꫀꫂꫛ-ꫝꫠ-ꫪꫲ-ꫴꬁ-ꬆꬉ-ꬎꬑ-ꬖꬠ-ꬦꬨ-ꬮꬰ-ꭚꭜ-ꭩꭰ-ꯢ가-힣ힰ-ퟆퟋ-ퟻ豈-舘並-龎ﬀ-ﬆﬓ-ﬗיִײַ-ﬨשׁ-זּטּ-לּמּנּסּףּפּצּ-ﮱﯓ-ﴽﵐ-ﶏﶒ-ﷇﷰ-ﷻﹰ-ﹴﹶ-ﻼＡ-Ｚａ-ｚｦ-ﾾￂ-ￇￊ-ￏￒ-ￗￚ-ￜ", De = {
	3: "abstract boolean byte char class double enum export extends final float goto implements import int interface long native package private protected public short static super synchronized throws transient volatile",
	5: "class enum extends super const export import",
	6: "enum",
	strict: "implements interface let package private protected public static yield",
	strictBind: "eval arguments"
}, Me = "break case catch continue debugger default do else finally for function if return switch throw try var while with null true false instanceof typeof void delete new in this", Fi = {
	5: Me,
	"5module": Me + " export import",
	6: Me + " const class extends export import super"
}, ji = /^in(stanceof)?$/, Ui = new RegExp("[" + mt + "]"), Gi = new RegExp("[" + mt + Mi + "]");
function je(e, t) {
	for (var i = 65536, s = 0; s < t.length; s += 2) {
		if (i += t[s], i > e) return !1;
		if (i += t[s + 1], i >= e) return !0;
	}
	return !1;
}
function j(e, t) {
	return e < 65 ? e === 36 : e < 91 ? !0 : e < 97 ? e === 95 : e < 123 ? !0 : e <= 65535 ? e >= 170 && Ui.test(String.fromCharCode(e)) : t === !1 ? !1 : je(e, dt);
}
function X(e, t) {
	return e < 48 ? e === 36 : e < 58 ? !0 : e < 65 ? !1 : e < 91 ? !0 : e < 97 ? e === 95 : e < 123 ? !0 : e <= 65535 ? e >= 170 && Gi.test(String.fromCharCode(e)) : t === !1 ? !1 : je(e, dt) || je(e, Di);
}
var C = function(t, i) {
	i === void 0 && (i = {}), this.label = t, this.keyword = i.keyword, this.beforeExpr = !!i.beforeExpr, this.startsExpr = !!i.startsExpr, this.isLoop = !!i.isLoop, this.isAssign = !!i.isAssign, this.prefix = !!i.prefix, this.postfix = !!i.postfix, this.binop = i.binop || null, this.updateContext = null;
};
function V(e, t) {
	return new C(e, {
		beforeExpr: !0,
		binop: t
	});
}
var O = { beforeExpr: !0 }, N = { startsExpr: !0 }, Je = {};
function _(e, t) {
	return t === void 0 && (t = {}), t.keyword = e, Je[e] = new C(e, t);
}
var a = {
	num: new C("num", N),
	regexp: new C("regexp", N),
	string: new C("string", N),
	name: new C("name", N),
	privateId: new C("privateId", N),
	eof: new C("eof"),
	bracketL: new C("[", {
		beforeExpr: !0,
		startsExpr: !0
	}),
	bracketR: new C("]"),
	braceL: new C("{", {
		beforeExpr: !0,
		startsExpr: !0
	}),
	braceR: new C("}"),
	parenL: new C("(", {
		beforeExpr: !0,
		startsExpr: !0
	}),
	parenR: new C(")"),
	comma: new C(",", O),
	semi: new C(";", O),
	colon: new C(":", O),
	dot: new C("."),
	question: new C("?", O),
	questionDot: new C("?."),
	arrow: new C("=>", O),
	template: new C("template"),
	invalidTemplate: new C("invalidTemplate"),
	ellipsis: new C("...", O),
	backQuote: new C("`", N),
	dollarBraceL: new C("${", {
		beforeExpr: !0,
		startsExpr: !0
	}),
	eq: new C("=", {
		beforeExpr: !0,
		isAssign: !0
	}),
	assign: new C("_=", {
		beforeExpr: !0,
		isAssign: !0
	}),
	incDec: new C("++/--", {
		prefix: !0,
		postfix: !0,
		startsExpr: !0
	}),
	prefix: new C("!/~", {
		beforeExpr: !0,
		prefix: !0,
		startsExpr: !0
	}),
	logicalOR: V("||", 1),
	logicalAND: V("&&", 2),
	bitwiseOR: V("|", 3),
	bitwiseXOR: V("^", 4),
	bitwiseAND: V("&", 5),
	equality: V("==/!=/===/!==", 6),
	relational: V("</>/<=/>=", 7),
	bitShift: V("<</>>/>>>", 8),
	plusMin: new C("+/-", {
		beforeExpr: !0,
		binop: 9,
		prefix: !0,
		startsExpr: !0
	}),
	modulo: V("%", 10),
	star: V("*", 10),
	slash: V("/", 10),
	starstar: new C("**", { beforeExpr: !0 }),
	coalesce: V("??", 1),
	_break: _("break"),
	_case: _("case", O),
	_catch: _("catch"),
	_continue: _("continue"),
	_debugger: _("debugger"),
	_default: _("default", O),
	_do: _("do", {
		isLoop: !0,
		beforeExpr: !0
	}),
	_else: _("else", O),
	_finally: _("finally"),
	_for: _("for", { isLoop: !0 }),
	_function: _("function", N),
	_if: _("if"),
	_return: _("return", O),
	_switch: _("switch"),
	_throw: _("throw", O),
	_try: _("try"),
	_var: _("var"),
	_const: _("const"),
	_while: _("while", { isLoop: !0 }),
	_with: _("with"),
	_new: _("new", {
		beforeExpr: !0,
		startsExpr: !0
	}),
	_this: _("this", N),
	_super: _("super", N),
	_class: _("class", N),
	_extends: _("extends", O),
	_export: _("export"),
	_import: _("import", N),
	_null: _("null", N),
	_true: _("true", N),
	_false: _("false", N),
	_in: _("in", {
		beforeExpr: !0,
		binop: 7
	}),
	_instanceof: _("instanceof", {
		beforeExpr: !0,
		binop: 7
	}),
	_typeof: _("typeof", {
		beforeExpr: !0,
		prefix: !0,
		startsExpr: !0
	}),
	_void: _("void", {
		beforeExpr: !0,
		prefix: !0,
		startsExpr: !0
	}),
	_delete: _("delete", {
		beforeExpr: !0,
		prefix: !0,
		startsExpr: !0
	})
}, L = /\r\n?|\n|\u2028|\u2029/, qi = new RegExp(L.source, "g");
function Y(e) {
	return e === 10 || e === 13 || e === 8232 || e === 8233;
}
function xt(e, t, i) {
	i === void 0 && (i = e.length);
	for (var s = t; s < i; s++) {
		var r = e.charCodeAt(s);
		if (Y(r)) return s < i - 1 && r === 13 && e.charCodeAt(s + 1) === 10 ? s + 2 : s + 1;
	}
	return -1;
}
var yt = /[\u1680\u2000-\u200a\u202f\u205f\u3000\ufeff]/, k = /(?:\s|\/\/.*|\/\*[^]*?\*\/)*/g, gt = Object.prototype, Ji = gt.hasOwnProperty, Ki = gt.toString, $ = Object.hasOwn || (function(e, t) {
	return Ji.call(e, t);
}), ht = Array.isArray || (function(e) {
	return Ki.call(e) === "[object Array]";
}), pt = Object.create(null);
function H(e) {
	return pt[e] || (pt[e] = new RegExp("^(?:" + e.replace(/ /g, "|") + ")$"));
}
function q(e) {
	return e <= 65535 ? String.fromCharCode(e) : (e -= 65536, String.fromCharCode((e >> 10) + 55296, (e & 1023) + 56320));
}
var Hi = /(?:[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF])/, ne = function(t, i) {
	this.line = t, this.column = i;
};
ne.prototype.offset = function(t) {
	return new ne(this.line, this.column + t);
};
var be = function(t, i, s) {
	this.start = i, this.end = s, t.sourceFile !== null && (this.source = t.sourceFile);
};
function vt(e, t) {
	for (var i = 1, s = 0;;) {
		var r = xt(e, s, t);
		if (r < 0) return new ne(i, t - s);
		++i, s = r;
	}
}
var Ue = {
	ecmaVersion: null,
	sourceType: "script",
	onInsertedSemicolon: null,
	onTrailingComma: null,
	allowReserved: null,
	allowReturnOutsideFunction: !1,
	allowImportExportEverywhere: !1,
	allowAwaitOutsideFunction: null,
	allowSuperOutsideMethod: null,
	allowHashBang: !1,
	checkPrivateFields: !0,
	locations: !1,
	onToken: null,
	onComment: null,
	ranges: !1,
	program: null,
	sourceFile: null,
	directSourceFile: null,
	preserveParens: !1
}, ct = !1;
function Xi(e) {
	var t = {};
	for (var i in Ue) t[i] = e && $(e, i) ? e[i] : Ue[i];
	if (t.ecmaVersion === "latest" ? t.ecmaVersion = 1e8 : t.ecmaVersion == null ? (!ct && typeof console == "object" && console.warn && (ct = !0, console.warn(`Since Acorn 8.0.0, options.ecmaVersion is required.
Defaulting to 2020, but this will stop working in the future.`)), t.ecmaVersion = 11) : t.ecmaVersion >= 2015 && (t.ecmaVersion -= 2009), t.allowReserved ??= t.ecmaVersion < 5, (!e || e.allowHashBang == null) && (t.allowHashBang = t.ecmaVersion >= 14), ht(t.onToken)) {
		var s = t.onToken;
		t.onToken = function(r) {
			return s.push(r);
		};
	}
	return ht(t.onComment) && (t.onComment = Wi(t, t.onComment)), t;
}
function Wi(e, t) {
	return function(i, s, r, o, u, p) {
		var h = {
			type: i ? "Block" : "Line",
			value: s,
			start: r,
			end: o
		};
		e.locations && (h.loc = new be(this, u, p)), e.ranges && (h.range = [r, o]), t.push(h);
	};
}
var oe = 1, Z = 2, Ke = 4, bt = 8, He = 16, St = 32, Se = 64, _t = 128, z = 256, ue = 512, _e = oe | Z | z;
function Xe(e, t) {
	return Z | (e ? Ke : 0) | (t ? bt : 0);
}
var xe = 0, We = 1, K = 2, Ct = 3, Tt = 4, Et = 5, A = function(t, i, s) {
	this.options = t = Xi(t), this.sourceFile = t.sourceFile, this.keywords = H(Fi[t.ecmaVersion >= 6 ? 6 : t.sourceType === "module" ? "5module" : 5]);
	var r = "";
	t.allowReserved !== !0 && (r = De[t.ecmaVersion >= 6 ? 6 : t.ecmaVersion === 5 ? 5 : 3], t.sourceType === "module" && (r += " await")), this.reservedWords = H(r);
	var o = (r ? r + " " : "") + De.strict;
	this.reservedWordsStrict = H(o), this.reservedWordsStrictBind = H(o + " " + De.strictBind), this.input = String(i), this.containsEsc = !1, s ? (this.pos = s, this.lineStart = this.input.lastIndexOf(`
`, s - 1) + 1, this.curLine = this.input.slice(0, this.lineStart).split(L).length) : (this.pos = this.lineStart = 0, this.curLine = 1), this.type = a.eof, this.value = null, this.start = this.end = this.pos, this.startLoc = this.endLoc = this.curPosition(), this.lastTokEndLoc = this.lastTokStartLoc = null, this.lastTokStart = this.lastTokEnd = this.pos, this.context = this.initialContext(), this.exprAllowed = !0, this.inModule = t.sourceType === "module", this.strict = this.inModule || this.strictDirective(this.pos), this.potentialArrowAt = -1, this.potentialArrowInForAwait = !1, this.yieldPos = this.awaitPos = this.awaitIdentPos = 0, this.labels = [], this.undefinedExports = Object.create(null), this.pos === 0 && t.allowHashBang && this.input.slice(0, 2) === "#!" && this.skipLineComment(2), this.scopeStack = [], this.enterScope(oe), this.regexpState = null, this.privateNameStack = [];
}, U = {
	inFunction: { configurable: !0 },
	inGenerator: { configurable: !0 },
	inAsync: { configurable: !0 },
	canAwait: { configurable: !0 },
	allowSuper: { configurable: !0 },
	allowDirectSuper: { configurable: !0 },
	treatFunctionsAsVar: { configurable: !0 },
	allowNewDotTarget: { configurable: !0 },
	inClassStaticBlock: { configurable: !0 }
};
A.prototype.parse = function() {
	var t = this.options.program || this.startNode();
	return this.nextToken(), this.parseTopLevel(t);
};
U.inFunction.get = function() {
	return (this.currentVarScope().flags & Z) > 0;
};
U.inGenerator.get = function() {
	return (this.currentVarScope().flags & bt) > 0;
};
U.inAsync.get = function() {
	return (this.currentVarScope().flags & Ke) > 0;
};
U.canAwait.get = function() {
	for (var e = this.scopeStack.length - 1; e >= 0; e--) {
		var i = this.scopeStack[e].flags;
		if (i & (z | ue)) return !1;
		if (i & Z) return (i & Ke) > 0;
	}
	return this.inModule && this.options.ecmaVersion >= 13 || this.options.allowAwaitOutsideFunction;
};
U.allowSuper.get = function() {
	return (this.currentThisScope().flags & Se) > 0 || this.options.allowSuperOutsideMethod;
};
U.allowDirectSuper.get = function() {
	return (this.currentThisScope().flags & _t) > 0;
};
U.treatFunctionsAsVar.get = function() {
	return this.treatFunctionsAsVarInScope(this.currentScope());
};
U.allowNewDotTarget.get = function() {
	for (var e = this.scopeStack.length - 1; e >= 0; e--) {
		var i = this.scopeStack[e].flags;
		if (i & (z | ue) || i & Z && !(i & He)) return !0;
	}
	return !1;
};
U.inClassStaticBlock.get = function() {
	return (this.currentVarScope().flags & z) > 0;
};
A.extend = function() {
	for (var t = [], i = arguments.length; i--;) t[i] = arguments[i];
	for (var s = this, r = 0; r < t.length; r++) s = t[r](s);
	return s;
};
A.parse = function(t, i) {
	return new this(i, t).parse();
};
A.parseExpressionAt = function(t, i, s) {
	var r = new this(s, t, i);
	return r.nextToken(), r.parseExpression();
};
A.tokenizer = function(t, i) {
	return new this(i, t);
};
Object.defineProperties(A.prototype, U);
var w = A.prototype, zi = /^(?:'((?:\\[^]|[^'\\])*?)'|"((?:\\[^]|[^"\\])*?)")/;
w.strictDirective = function(e) {
	if (this.options.ecmaVersion < 5) return !1;
	for (;;) {
		k.lastIndex = e, e += k.exec(this.input)[0].length;
		var t = zi.exec(this.input.slice(e));
		if (!t) return !1;
		if ((t[1] || t[2]) === "use strict") {
			k.lastIndex = e + t[0].length;
			var i = k.exec(this.input), s = i.index + i[0].length, r = this.input.charAt(s);
			return r === ";" || r === "}" || L.test(i[0]) && !(/[(`.[+\-/*%<>=,?^&]/.test(r) || r === "!" && this.input.charAt(s + 1) === "=");
		}
		e += t[0].length, k.lastIndex = e, e += k.exec(this.input)[0].length, this.input[e] === ";" && e++;
	}
};
w.eat = function(e) {
	return this.type === e ? (this.next(), !0) : !1;
};
w.isContextual = function(e) {
	return this.type === a.name && this.value === e && !this.containsEsc;
};
w.eatContextual = function(e) {
	return this.isContextual(e) ? (this.next(), !0) : !1;
};
w.expectContextual = function(e) {
	this.eatContextual(e) || this.unexpected();
};
w.canInsertSemicolon = function() {
	return this.type === a.eof || this.type === a.braceR || L.test(this.input.slice(this.lastTokEnd, this.start));
};
w.insertSemicolon = function() {
	if (this.canInsertSemicolon()) return this.options.onInsertedSemicolon && this.options.onInsertedSemicolon(this.lastTokEnd, this.lastTokEndLoc), !0;
};
w.semicolon = function() {
	!this.eat(a.semi) && !this.insertSemicolon() && this.unexpected();
};
w.afterTrailingComma = function(e, t) {
	if (this.type === e) return this.options.onTrailingComma && this.options.onTrailingComma(this.lastTokStart, this.lastTokStartLoc), t || this.next(), !0;
};
w.expect = function(e) {
	this.eat(e) || this.unexpected();
};
w.unexpected = function(e) {
	this.raise(e ?? this.start, "Unexpected token");
};
var Ce = function() {
	this.shorthandAssign = this.trailingComma = this.parenthesizedAssign = this.parenthesizedBind = this.doubleProto = -1;
};
w.checkPatternErrors = function(e, t) {
	if (e) {
		e.trailingComma > -1 && this.raiseRecoverable(e.trailingComma, "Comma is not permitted after the rest element");
		var i = t ? e.parenthesizedAssign : e.parenthesizedBind;
		i > -1 && this.raiseRecoverable(i, t ? "Assigning to rvalue" : "Parenthesized pattern");
	}
};
w.checkExpressionErrors = function(e, t) {
	if (!e) return !1;
	var i = e.shorthandAssign, s = e.doubleProto;
	if (!t) return i >= 0 || s >= 0;
	i >= 0 && this.raise(i, "Shorthand property assignments are valid only in destructuring patterns"), s >= 0 && this.raiseRecoverable(s, "Redefinition of __proto__ property");
};
w.checkYieldAwaitInDefaultParams = function() {
	this.yieldPos && (!this.awaitPos || this.yieldPos < this.awaitPos) && this.raise(this.yieldPos, "Yield expression cannot be a default value"), this.awaitPos && this.raise(this.awaitPos, "Await expression cannot be a default value");
};
w.isSimpleAssignTarget = function(e) {
	return e.type === "ParenthesizedExpression" ? this.isSimpleAssignTarget(e.expression) : e.type === "Identifier" || e.type === "MemberExpression";
};
var d = A.prototype;
d.parseTopLevel = function(e) {
	var t = Object.create(null);
	for (e.body || (e.body = []); this.type !== a.eof;) {
		var i = this.parseStatement(null, !0, t);
		e.body.push(i);
	}
	if (this.inModule) for (var s = 0, r = Object.keys(this.undefinedExports); s < r.length; s += 1) {
		var o = r[s];
		this.raiseRecoverable(this.undefinedExports[o].start, "Export '" + o + "' is not defined");
	}
	return this.adaptDirectivePrologue(e.body), this.next(), e.sourceType = this.options.sourceType, this.finishNode(e, "Program");
};
var ze = { kind: "loop" }, Qi = { kind: "switch" };
d.isLet = function(e) {
	if (this.options.ecmaVersion < 6 || !this.isContextual("let")) return !1;
	k.lastIndex = this.pos;
	var t = k.exec(this.input), i = this.pos + t[0].length, s = this.input.charCodeAt(i);
	if (s === 91 || s === 92) return !0;
	if (e) return !1;
	if (s === 123 || s > 55295 && s < 56320) return !0;
	if (j(s, !0)) {
		for (var r = i + 1; X(s = this.input.charCodeAt(r), !0);) ++r;
		if (s === 92 || s > 55295 && s < 56320) return !0;
		var o = this.input.slice(i, r);
		if (!ji.test(o)) return !0;
	}
	return !1;
};
d.isAsyncFunction = function() {
	if (this.options.ecmaVersion < 8 || !this.isContextual("async")) return !1;
	k.lastIndex = this.pos;
	var e = k.exec(this.input), t = this.pos + e[0].length, i;
	return !L.test(this.input.slice(this.pos, t)) && this.input.slice(t, t + 8) === "function" && (t + 8 === this.input.length || !(X(i = this.input.charCodeAt(t + 8)) || i > 55295 && i < 56320));
};
d.isUsingKeyword = function(e, t) {
	if (this.options.ecmaVersion < 17 || !this.isContextual(e ? "await" : "using")) return !1;
	k.lastIndex = this.pos;
	var i = k.exec(this.input), s = this.pos + i[0].length;
	if (L.test(this.input.slice(this.pos, s))) return !1;
	if (e) {
		var r = s + 5, o;
		if (this.input.slice(s, r) !== "using" || r === this.input.length || X(o = this.input.charCodeAt(r)) || o > 55295 && o < 56320) return !1;
		k.lastIndex = r;
		var u = k.exec(this.input);
		if (u && L.test(this.input.slice(r, r + u[0].length))) return !1;
	}
	if (t) {
		var p = s + 2, h;
		if (this.input.slice(s, p) === "of" && (p === this.input.length || !X(h = this.input.charCodeAt(p)) && !(h > 55295 && h < 56320))) return !1;
	}
	var l = this.input.charCodeAt(s);
	return j(l, !0) || l === 92;
};
d.isAwaitUsing = function(e) {
	return this.isUsingKeyword(!0, e);
};
d.isUsing = function(e) {
	return this.isUsingKeyword(!1, e);
};
d.parseStatement = function(e, t, i) {
	var s = this.type, r = this.startNode(), o;
	switch (this.isLet(e) && (s = a._var, o = "let"), s) {
		case a._break:
		case a._continue: return this.parseBreakContinueStatement(r, s.keyword);
		case a._debugger: return this.parseDebuggerStatement(r);
		case a._do: return this.parseDoStatement(r);
		case a._for: return this.parseForStatement(r);
		case a._function: return e && (this.strict || e !== "if" && e !== "label") && this.options.ecmaVersion >= 6 && this.unexpected(), this.parseFunctionStatement(r, !1, !e);
		case a._class: return e && this.unexpected(), this.parseClass(r, !0);
		case a._if: return this.parseIfStatement(r);
		case a._return: return this.parseReturnStatement(r);
		case a._switch: return this.parseSwitchStatement(r);
		case a._throw: return this.parseThrowStatement(r);
		case a._try: return this.parseTryStatement(r);
		case a._const:
		case a._var: return o = o || this.value, e && o !== "var" && this.unexpected(), this.parseVarStatement(r, o);
		case a._while: return this.parseWhileStatement(r);
		case a._with: return this.parseWithStatement(r);
		case a.braceL: return this.parseBlock(!0, r);
		case a.semi: return this.parseEmptyStatement(r);
		case a._export:
		case a._import:
			if (this.options.ecmaVersion > 10 && s === a._import) {
				k.lastIndex = this.pos;
				var u = k.exec(this.input), p = this.pos + u[0].length, h = this.input.charCodeAt(p);
				if (h === 40 || h === 46) return this.parseExpressionStatement(r, this.parseExpression());
			}
			return this.options.allowImportExportEverywhere || (t || this.raise(this.start, "'import' and 'export' may only appear at the top level"), this.inModule || this.raise(this.start, "'import' and 'export' may appear only with 'sourceType: module'")), s === a._import ? this.parseImport(r) : this.parseExport(r, i);
		default:
			if (this.isAsyncFunction()) return e && this.unexpected(), this.next(), this.parseFunctionStatement(r, !0, !e);
			var l = this.isAwaitUsing(!1) ? "await using" : this.isUsing(!1) ? "using" : null;
			if (l) return t && this.options.sourceType === "script" && this.raise(this.start, "Using declaration cannot appear in the top level when source type is `script`"), l === "await using" && (this.canAwait || this.raise(this.start, "Await using cannot appear outside of async function"), this.next()), this.next(), this.parseVar(r, !1, l), this.semicolon(), this.finishNode(r, "VariableDeclaration");
			var m = this.value, S = this.parseExpression();
			return s === a.name && S.type === "Identifier" && this.eat(a.colon) ? this.parseLabeledStatement(r, m, S, e) : this.parseExpressionStatement(r, S);
	}
};
d.parseBreakContinueStatement = function(e, t) {
	var i = t === "break";
	this.next(), this.eat(a.semi) || this.insertSemicolon() ? e.label = null : this.type !== a.name ? this.unexpected() : (e.label = this.parseIdent(), this.semicolon());
	for (var s = 0; s < this.labels.length; ++s) {
		var r = this.labels[s];
		if ((e.label == null || r.name === e.label.name) && (r.kind != null && (i || r.kind === "loop") || e.label && i)) break;
	}
	return s === this.labels.length && this.raise(e.start, "Unsyntactic " + t), this.finishNode(e, i ? "BreakStatement" : "ContinueStatement");
};
d.parseDebuggerStatement = function(e) {
	return this.next(), this.semicolon(), this.finishNode(e, "DebuggerStatement");
};
d.parseDoStatement = function(e) {
	return this.next(), this.labels.push(ze), e.body = this.parseStatement("do"), this.labels.pop(), this.expect(a._while), e.test = this.parseParenExpression(), this.options.ecmaVersion >= 6 ? this.eat(a.semi) : this.semicolon(), this.finishNode(e, "DoWhileStatement");
};
d.parseForStatement = function(e) {
	this.next();
	var t = this.options.ecmaVersion >= 9 && this.canAwait && this.eatContextual("await") ? this.lastTokStart : -1;
	if (this.labels.push(ze), this.enterScope(0), this.expect(a.parenL), this.type === a.semi) return t > -1 && this.unexpected(t), this.parseFor(e, null);
	var i = this.isLet();
	if (this.type === a._var || this.type === a._const || i) {
		var s = this.startNode(), r = i ? "let" : this.value;
		return this.next(), this.parseVar(s, !0, r), this.finishNode(s, "VariableDeclaration"), this.parseForAfterInit(e, s, t);
	}
	var o = this.isContextual("let"), u = !1, p = this.isUsing(!0) ? "using" : this.isAwaitUsing(!0) ? "await using" : null;
	if (p) {
		var h = this.startNode();
		return this.next(), p === "await using" && this.next(), this.parseVar(h, !0, p), this.finishNode(h, "VariableDeclaration"), this.parseForAfterInit(e, h, t);
	}
	var l = this.containsEsc, m = new Ce(), S = this.start, E = t > -1 ? this.parseExprSubscripts(m, "await") : this.parseExpression(!0, m);
	return this.type === a._in || (u = this.options.ecmaVersion >= 6 && this.isContextual("of")) ? (t > -1 ? (this.type === a._in && this.unexpected(t), e.await = !0) : u && this.options.ecmaVersion >= 8 && (E.start === S && !l && E.type === "Identifier" && E.name === "async" ? this.unexpected() : this.options.ecmaVersion >= 9 && (e.await = !1)), o && u && this.raise(E.start, "The left-hand side of a for-of loop may not start with 'let'."), this.toAssignable(E, !1, m), this.checkLValPattern(E), this.parseForIn(e, E)) : (this.checkExpressionErrors(m, !0), t > -1 && this.unexpected(t), this.parseFor(e, E));
};
d.parseForAfterInit = function(e, t, i) {
	return (this.type === a._in || this.options.ecmaVersion >= 6 && this.isContextual("of")) && t.declarations.length === 1 ? (this.options.ecmaVersion >= 9 && (this.type === a._in ? i > -1 && this.unexpected(i) : e.await = i > -1), this.parseForIn(e, t)) : (i > -1 && this.unexpected(i), this.parseFor(e, t));
};
d.parseFunctionStatement = function(e, t, i) {
	return this.next(), this.parseFunction(e, ae | (i ? 0 : Ge), !1, t);
};
d.parseIfStatement = function(e) {
	return this.next(), e.test = this.parseParenExpression(), e.consequent = this.parseStatement("if"), e.alternate = this.eat(a._else) ? this.parseStatement("if") : null, this.finishNode(e, "IfStatement");
};
d.parseReturnStatement = function(e) {
	return !this.inFunction && !this.options.allowReturnOutsideFunction && this.raise(this.start, "'return' outside of function"), this.next(), this.eat(a.semi) || this.insertSemicolon() ? e.argument = null : (e.argument = this.parseExpression(), this.semicolon()), this.finishNode(e, "ReturnStatement");
};
d.parseSwitchStatement = function(e) {
	this.next(), e.discriminant = this.parseParenExpression(), e.cases = [], this.expect(a.braceL), this.labels.push(Qi), this.enterScope(0);
	for (var t, i = !1; this.type !== a.braceR;) if (this.type === a._case || this.type === a._default) {
		var s = this.type === a._case;
		t && this.finishNode(t, "SwitchCase"), e.cases.push(t = this.startNode()), t.consequent = [], this.next(), s ? t.test = this.parseExpression() : (i && this.raiseRecoverable(this.lastTokStart, "Multiple default clauses"), i = !0, t.test = null), this.expect(a.colon);
	} else t || this.unexpected(), t.consequent.push(this.parseStatement(null));
	return this.exitScope(), t && this.finishNode(t, "SwitchCase"), this.next(), this.labels.pop(), this.finishNode(e, "SwitchStatement");
};
d.parseThrowStatement = function(e) {
	return this.next(), L.test(this.input.slice(this.lastTokEnd, this.start)) && this.raise(this.lastTokEnd, "Illegal newline after throw"), e.argument = this.parseExpression(), this.semicolon(), this.finishNode(e, "ThrowStatement");
};
var Yi = [];
d.parseCatchClauseParam = function() {
	var e = this.parseBindingAtom(), t = e.type === "Identifier";
	return this.enterScope(t ? St : 0), this.checkLValPattern(e, t ? Tt : K), this.expect(a.parenR), e;
};
d.parseTryStatement = function(e) {
	if (this.next(), e.block = this.parseBlock(), e.handler = null, this.type === a._catch) {
		var t = this.startNode();
		this.next(), this.eat(a.parenL) ? t.param = this.parseCatchClauseParam() : (this.options.ecmaVersion < 10 && this.unexpected(), t.param = null, this.enterScope(0)), t.body = this.parseBlock(!1), this.exitScope(), e.handler = this.finishNode(t, "CatchClause");
	}
	return e.finalizer = this.eat(a._finally) ? this.parseBlock() : null, !e.handler && !e.finalizer && this.raise(e.start, "Missing catch or finally clause"), this.finishNode(e, "TryStatement");
};
d.parseVarStatement = function(e, t, i) {
	return this.next(), this.parseVar(e, !1, t, i), this.semicolon(), this.finishNode(e, "VariableDeclaration");
};
d.parseWhileStatement = function(e) {
	return this.next(), e.test = this.parseParenExpression(), this.labels.push(ze), e.body = this.parseStatement("while"), this.labels.pop(), this.finishNode(e, "WhileStatement");
};
d.parseWithStatement = function(e) {
	return this.strict && this.raise(this.start, "'with' in strict mode"), this.next(), e.object = this.parseParenExpression(), e.body = this.parseStatement("with"), this.finishNode(e, "WithStatement");
};
d.parseEmptyStatement = function(e) {
	return this.next(), this.finishNode(e, "EmptyStatement");
};
d.parseLabeledStatement = function(e, t, i, s) {
	for (var r = 0, o = this.labels; r < o.length; r += 1) o[r].name === t && this.raise(i.start, "Label '" + t + "' is already declared");
	for (var p = this.type.isLoop ? "loop" : this.type === a._switch ? "switch" : null, h = this.labels.length - 1; h >= 0; h--) {
		var l = this.labels[h];
		if (l.statementStart === e.start) l.statementStart = this.start, l.kind = p;
		else break;
	}
	return this.labels.push({
		name: t,
		kind: p,
		statementStart: this.start
	}), e.body = this.parseStatement(s ? s.indexOf("label") === -1 ? s + "label" : s : "label"), this.labels.pop(), e.label = i, this.finishNode(e, "LabeledStatement");
};
d.parseExpressionStatement = function(e, t) {
	return e.expression = t, this.semicolon(), this.finishNode(e, "ExpressionStatement");
};
d.parseBlock = function(e, t, i) {
	for (e === void 0 && (e = !0), t === void 0 && (t = this.startNode()), t.body = [], this.expect(a.braceL), e && this.enterScope(0); this.type !== a.braceR;) {
		var s = this.parseStatement(null);
		t.body.push(s);
	}
	return i && (this.strict = !1), this.next(), e && this.exitScope(), this.finishNode(t, "BlockStatement");
};
d.parseFor = function(e, t) {
	return e.init = t, this.expect(a.semi), e.test = this.type === a.semi ? null : this.parseExpression(), this.expect(a.semi), e.update = this.type === a.parenR ? null : this.parseExpression(), this.expect(a.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, "ForStatement");
};
d.parseForIn = function(e, t) {
	var i = this.type === a._in;
	return this.next(), t.type === "VariableDeclaration" && t.declarations[0].init != null && (!i || this.options.ecmaVersion < 8 || this.strict || t.kind !== "var" || t.declarations[0].id.type !== "Identifier") && this.raise(t.start, (i ? "for-in" : "for-of") + " loop variable declaration may not have an initializer"), e.left = t, e.right = i ? this.parseExpression() : this.parseMaybeAssign(), this.expect(a.parenR), e.body = this.parseStatement("for"), this.exitScope(), this.labels.pop(), this.finishNode(e, i ? "ForInStatement" : "ForOfStatement");
};
d.parseVar = function(e, t, i, s) {
	for (e.declarations = [], e.kind = i;;) {
		var r = this.startNode();
		if (this.parseVarId(r, i), this.eat(a.eq) ? r.init = this.parseMaybeAssign(t) : !s && i === "const" && !(this.type === a._in || this.options.ecmaVersion >= 6 && this.isContextual("of")) ? this.unexpected() : !s && (i === "using" || i === "await using") && this.options.ecmaVersion >= 17 && this.type !== a._in && !this.isContextual("of") ? this.raise(this.lastTokEnd, "Missing initializer in " + i + " declaration") : !s && r.id.type !== "Identifier" && !(t && (this.type === a._in || this.isContextual("of"))) ? this.raise(this.lastTokEnd, "Complex binding patterns require an initialization value") : r.init = null, e.declarations.push(this.finishNode(r, "VariableDeclarator")), !this.eat(a.comma)) break;
	}
	return e;
};
d.parseVarId = function(e, t) {
	e.id = t === "using" || t === "await using" ? this.parseIdent() : this.parseBindingAtom(), this.checkLValPattern(e.id, t === "var" ? We : K, !1);
};
var ae = 1, Ge = 2, At = 4;
d.parseFunction = function(e, t, i, s, r) {
	this.initFunction(e), (this.options.ecmaVersion >= 9 || this.options.ecmaVersion >= 6 && !s) && (this.type === a.star && t & Ge && this.unexpected(), e.generator = this.eat(a.star)), this.options.ecmaVersion >= 8 && (e.async = !!s), t & ae && (e.id = t & At && this.type !== a.name ? null : this.parseIdent(), e.id && !(t & Ge) && this.checkLValSimple(e.id, this.strict || e.generator || e.async ? this.treatFunctionsAsVar ? We : K : Ct));
	var o = this.yieldPos, u = this.awaitPos, p = this.awaitIdentPos;
	return this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(Xe(e.async, e.generator)), t & ae || (e.id = this.type === a.name ? this.parseIdent() : null), this.parseFunctionParams(e), this.parseFunctionBody(e, i, !1, r), this.yieldPos = o, this.awaitPos = u, this.awaitIdentPos = p, this.finishNode(e, t & ae ? "FunctionDeclaration" : "FunctionExpression");
};
d.parseFunctionParams = function(e) {
	this.expect(a.parenL), e.params = this.parseBindingList(a.parenR, !1, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams();
};
d.parseClass = function(e, t) {
	this.next();
	var i = this.strict;
	this.strict = !0, this.parseClassId(e, t), this.parseClassSuper(e);
	var s = this.enterClassBody(), r = this.startNode(), o = !1;
	for (r.body = [], this.expect(a.braceL); this.type !== a.braceR;) {
		var u = this.parseClassElement(e.superClass !== null);
		u && (r.body.push(u), u.type === "MethodDefinition" && u.kind === "constructor" ? (o && this.raiseRecoverable(u.start, "Duplicate constructor in the same class"), o = !0) : u.key && u.key.type === "PrivateIdentifier" && $i(s, u) && this.raiseRecoverable(u.key.start, "Identifier '#" + u.key.name + "' has already been declared"));
	}
	return this.strict = i, this.next(), e.body = this.finishNode(r, "ClassBody"), this.exitClassBody(), this.finishNode(e, t ? "ClassDeclaration" : "ClassExpression");
};
d.parseClassElement = function(e) {
	if (this.eat(a.semi)) return null;
	var t = this.options.ecmaVersion, i = this.startNode(), s = "", r = !1, o = !1, u = "method", p = !1;
	if (this.eatContextual("static")) {
		if (t >= 13 && this.eat(a.braceL)) return this.parseClassStaticBlock(i), i;
		this.isClassElementNameStart() || this.type === a.star ? p = !0 : s = "static";
	}
	if (i.static = p, !s && t >= 8 && this.eatContextual("async") && ((this.isClassElementNameStart() || this.type === a.star) && !this.canInsertSemicolon() ? o = !0 : s = "async"), !s && (t >= 9 || !o) && this.eat(a.star) && (r = !0), !s && !o && !r) {
		var h = this.value;
		(this.eatContextual("get") || this.eatContextual("set")) && (this.isClassElementNameStart() ? u = h : s = h);
	}
	if (s ? (i.computed = !1, i.key = this.startNodeAt(this.lastTokStart, this.lastTokStartLoc), i.key.name = s, this.finishNode(i.key, "Identifier")) : this.parseClassElementName(i), t < 13 || this.type === a.parenL || u !== "method" || r || o) {
		var l = !i.static && ye(i, "constructor"), m = l && e;
		l && u !== "method" && this.raise(i.key.start, "Constructor can't have get/set modifier"), i.kind = l ? "constructor" : u, this.parseClassMethod(i, r, o, m);
	} else this.parseClassField(i);
	return i;
};
d.isClassElementNameStart = function() {
	return this.type === a.name || this.type === a.privateId || this.type === a.num || this.type === a.string || this.type === a.bracketL || this.type.keyword;
};
d.parseClassElementName = function(e) {
	this.type === a.privateId ? (this.value === "constructor" && this.raise(this.start, "Classes can't have an element named '#constructor'"), e.computed = !1, e.key = this.parsePrivateIdent()) : this.parsePropertyName(e);
};
d.parseClassMethod = function(e, t, i, s) {
	var r = e.key;
	e.kind === "constructor" ? (t && this.raise(r.start, "Constructor can't be a generator"), i && this.raise(r.start, "Constructor can't be an async method")) : e.static && ye(e, "prototype") && this.raise(r.start, "Classes may not have a static property named prototype");
	var o = e.value = this.parseMethod(t, i, s);
	return e.kind === "get" && o.params.length !== 0 && this.raiseRecoverable(o.start, "getter should have no params"), e.kind === "set" && o.params.length !== 1 && this.raiseRecoverable(o.start, "setter should have exactly one param"), e.kind === "set" && o.params[0].type === "RestElement" && this.raiseRecoverable(o.params[0].start, "Setter cannot use rest params"), this.finishNode(e, "MethodDefinition");
};
d.parseClassField = function(e) {
	return ye(e, "constructor") ? this.raise(e.key.start, "Classes can't have a field named 'constructor'") : e.static && ye(e, "prototype") && this.raise(e.key.start, "Classes can't have a static field named 'prototype'"), this.eat(a.eq) ? (this.enterScope(ue | Se), e.value = this.parseMaybeAssign(), this.exitScope()) : e.value = null, this.semicolon(), this.finishNode(e, "PropertyDefinition");
};
d.parseClassStaticBlock = function(e) {
	e.body = [];
	var t = this.labels;
	for (this.labels = [], this.enterScope(z | Se); this.type !== a.braceR;) {
		var i = this.parseStatement(null);
		e.body.push(i);
	}
	return this.next(), this.exitScope(), this.labels = t, this.finishNode(e, "StaticBlock");
};
d.parseClassId = function(e, t) {
	this.type === a.name ? (e.id = this.parseIdent(), t && this.checkLValSimple(e.id, K, !1)) : (t === !0 && this.unexpected(), e.id = null);
};
d.parseClassSuper = function(e) {
	e.superClass = this.eat(a._extends) ? this.parseExprSubscripts(null, !1) : null;
};
d.enterClassBody = function() {
	var e = {
		declared: Object.create(null),
		used: []
	};
	return this.privateNameStack.push(e), e.declared;
};
d.exitClassBody = function() {
	var e = this.privateNameStack.pop(), t = e.declared, i = e.used;
	if (this.options.checkPrivateFields) for (var s = this.privateNameStack.length, r = s === 0 ? null : this.privateNameStack[s - 1], o = 0; o < i.length; ++o) {
		var u = i[o];
		$(t, u.name) || (r ? r.used.push(u) : this.raiseRecoverable(u.start, "Private field '#" + u.name + "' must be declared in an enclosing class"));
	}
};
function $i(e, t) {
	var i = t.key.name, s = e[i], r = "true";
	return t.type === "MethodDefinition" && (t.kind === "get" || t.kind === "set") && (r = (t.static ? "s" : "i") + t.kind), s === "iget" && r === "iset" || s === "iset" && r === "iget" || s === "sget" && r === "sset" || s === "sset" && r === "sget" ? (e[i] = "true", !1) : s ? !0 : (e[i] = r, !1);
}
function ye(e, t) {
	var i = e.computed, s = e.key;
	return !i && (s.type === "Identifier" && s.name === t || s.type === "Literal" && s.value === t);
}
d.parseExportAllDeclaration = function(e, t) {
	return this.options.ecmaVersion >= 11 && (this.eatContextual("as") ? (e.exported = this.parseModuleExportName(), this.checkExport(t, e.exported, this.lastTokStart)) : e.exported = null), this.expectContextual("from"), this.type !== a.string && this.unexpected(), e.source = this.parseExprAtom(), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause()), this.semicolon(), this.finishNode(e, "ExportAllDeclaration");
};
d.parseExport = function(e, t) {
	if (this.next(), this.eat(a.star)) return this.parseExportAllDeclaration(e, t);
	if (this.eat(a._default)) return this.checkExport(t, "default", this.lastTokStart), e.declaration = this.parseExportDefaultDeclaration(), this.finishNode(e, "ExportDefaultDeclaration");
	if (this.shouldParseExportStatement()) e.declaration = this.parseExportDeclaration(e), e.declaration.type === "VariableDeclaration" ? this.checkVariableExport(t, e.declaration.declarations) : this.checkExport(t, e.declaration.id, e.declaration.id.start), e.specifiers = [], e.source = null, this.options.ecmaVersion >= 16 && (e.attributes = []);
	else {
		if (e.declaration = null, e.specifiers = this.parseExportSpecifiers(t), this.eatContextual("from")) this.type !== a.string && this.unexpected(), e.source = this.parseExprAtom(), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause());
		else {
			for (var i = 0, s = e.specifiers; i < s.length; i += 1) {
				var r = s[i];
				this.checkUnreserved(r.local), this.checkLocalExport(r.local), r.local.type === "Literal" && this.raise(r.local.start, "A string literal cannot be used as an exported binding without `from`.");
			}
			e.source = null, this.options.ecmaVersion >= 16 && (e.attributes = []);
		}
		this.semicolon();
	}
	return this.finishNode(e, "ExportNamedDeclaration");
};
d.parseExportDeclaration = function(e) {
	return this.parseStatement(null);
};
d.parseExportDefaultDeclaration = function() {
	var e;
	if (this.type === a._function || (e = this.isAsyncFunction())) {
		var t = this.startNode();
		return this.next(), e && this.next(), this.parseFunction(t, ae | At, !1, e);
	} else if (this.type === a._class) {
		var i = this.startNode();
		return this.parseClass(i, "nullableID");
	} else {
		var s = this.parseMaybeAssign();
		return this.semicolon(), s;
	}
};
d.checkExport = function(e, t, i) {
	e && (typeof t != "string" && (t = t.type === "Identifier" ? t.name : t.value), $(e, t) && this.raiseRecoverable(i, "Duplicate export '" + t + "'"), e[t] = !0);
};
d.checkPatternExport = function(e, t) {
	var i = t.type;
	if (i === "Identifier") this.checkExport(e, t, t.start);
	else if (i === "ObjectPattern") for (var s = 0, r = t.properties; s < r.length; s += 1) {
		var o = r[s];
		this.checkPatternExport(e, o);
	}
	else if (i === "ArrayPattern") for (var u = 0, p = t.elements; u < p.length; u += 1) {
		var h = p[u];
		h && this.checkPatternExport(e, h);
	}
	else i === "Property" ? this.checkPatternExport(e, t.value) : i === "AssignmentPattern" ? this.checkPatternExport(e, t.left) : i === "RestElement" && this.checkPatternExport(e, t.argument);
};
d.checkVariableExport = function(e, t) {
	if (e) for (var i = 0, s = t; i < s.length; i += 1) {
		var r = s[i];
		this.checkPatternExport(e, r.id);
	}
};
d.shouldParseExportStatement = function() {
	return this.type.keyword === "var" || this.type.keyword === "const" || this.type.keyword === "class" || this.type.keyword === "function" || this.isLet() || this.isAsyncFunction();
};
d.parseExportSpecifier = function(e) {
	var t = this.startNode();
	return t.local = this.parseModuleExportName(), t.exported = this.eatContextual("as") ? this.parseModuleExportName() : t.local, this.checkExport(e, t.exported, t.exported.start), this.finishNode(t, "ExportSpecifier");
};
d.parseExportSpecifiers = function(e) {
	var t = [], i = !0;
	for (this.expect(a.braceL); !this.eat(a.braceR);) {
		if (i) i = !1;
		else if (this.expect(a.comma), this.afterTrailingComma(a.braceR)) break;
		t.push(this.parseExportSpecifier(e));
	}
	return t;
};
d.parseImport = function(e) {
	return this.next(), this.type === a.string ? (e.specifiers = Yi, e.source = this.parseExprAtom()) : (e.specifiers = this.parseImportSpecifiers(), this.expectContextual("from"), e.source = this.type === a.string ? this.parseExprAtom() : this.unexpected()), this.options.ecmaVersion >= 16 && (e.attributes = this.parseWithClause()), this.semicolon(), this.finishNode(e, "ImportDeclaration");
};
d.parseImportSpecifier = function() {
	var e = this.startNode();
	return e.imported = this.parseModuleExportName(), this.eatContextual("as") ? e.local = this.parseIdent() : (this.checkUnreserved(e.imported), e.local = e.imported), this.checkLValSimple(e.local, K), this.finishNode(e, "ImportSpecifier");
};
d.parseImportDefaultSpecifier = function() {
	var e = this.startNode();
	return e.local = this.parseIdent(), this.checkLValSimple(e.local, K), this.finishNode(e, "ImportDefaultSpecifier");
};
d.parseImportNamespaceSpecifier = function() {
	var e = this.startNode();
	return this.next(), this.expectContextual("as"), e.local = this.parseIdent(), this.checkLValSimple(e.local, K), this.finishNode(e, "ImportNamespaceSpecifier");
};
d.parseImportSpecifiers = function() {
	var e = [], t = !0;
	if (this.type === a.name && (e.push(this.parseImportDefaultSpecifier()), !this.eat(a.comma))) return e;
	if (this.type === a.star) return e.push(this.parseImportNamespaceSpecifier()), e;
	for (this.expect(a.braceL); !this.eat(a.braceR);) {
		if (t) t = !1;
		else if (this.expect(a.comma), this.afterTrailingComma(a.braceR)) break;
		e.push(this.parseImportSpecifier());
	}
	return e;
};
d.parseWithClause = function() {
	var e = [];
	if (!this.eat(a._with)) return e;
	this.expect(a.braceL);
	for (var t = {}, i = !0; !this.eat(a.braceR);) {
		if (i) i = !1;
		else if (this.expect(a.comma), this.afterTrailingComma(a.braceR)) break;
		var s = this.parseImportAttribute(), r = s.key.type === "Identifier" ? s.key.name : s.key.value;
		$(t, r) && this.raiseRecoverable(s.key.start, "Duplicate attribute key '" + r + "'"), t[r] = !0, e.push(s);
	}
	return e;
};
d.parseImportAttribute = function() {
	var e = this.startNode();
	return e.key = this.type === a.string ? this.parseExprAtom() : this.parseIdent(this.options.allowReserved !== "never"), this.expect(a.colon), this.type !== a.string && this.unexpected(), e.value = this.parseExprAtom(), this.finishNode(e, "ImportAttribute");
};
d.parseModuleExportName = function() {
	if (this.options.ecmaVersion >= 13 && this.type === a.string) {
		var e = this.parseLiteral(this.value);
		return Hi.test(e.value) && this.raise(e.start, "An export name cannot include a lone surrogate."), e;
	}
	return this.parseIdent(!0);
};
d.adaptDirectivePrologue = function(e) {
	for (var t = 0; t < e.length && this.isDirectiveCandidate(e[t]); ++t) e[t].directive = e[t].expression.raw.slice(1, -1);
};
d.isDirectiveCandidate = function(e) {
	return this.options.ecmaVersion >= 5 && e.type === "ExpressionStatement" && e.expression.type === "Literal" && typeof e.expression.value == "string" && (this.input[e.start] === "\"" || this.input[e.start] === "'");
};
var D = A.prototype;
D.toAssignable = function(e, t, i) {
	if (this.options.ecmaVersion >= 6 && e) switch (e.type) {
		case "Identifier":
			this.inAsync && e.name === "await" && this.raise(e.start, "Cannot use 'await' as identifier inside an async function");
			break;
		case "ObjectPattern":
		case "ArrayPattern":
		case "AssignmentPattern":
		case "RestElement": break;
		case "ObjectExpression":
			e.type = "ObjectPattern", i && this.checkPatternErrors(i, !0);
			for (var s = 0, r = e.properties; s < r.length; s += 1) {
				var o = r[s];
				this.toAssignable(o, t), o.type === "RestElement" && (o.argument.type === "ArrayPattern" || o.argument.type === "ObjectPattern") && this.raise(o.argument.start, "Unexpected token");
			}
			break;
		case "Property":
			e.kind !== "init" && this.raise(e.key.start, "Object pattern can't contain getter or setter"), this.toAssignable(e.value, t);
			break;
		case "ArrayExpression":
			e.type = "ArrayPattern", i && this.checkPatternErrors(i, !0), this.toAssignableList(e.elements, t);
			break;
		case "SpreadElement":
			e.type = "RestElement", this.toAssignable(e.argument, t), e.argument.type === "AssignmentPattern" && this.raise(e.argument.start, "Rest elements cannot have a default value");
			break;
		case "AssignmentExpression":
			e.operator !== "=" && this.raise(e.left.end, "Only '=' operator can be used for specifying default value."), e.type = "AssignmentPattern", delete e.operator, this.toAssignable(e.left, t);
			break;
		case "ParenthesizedExpression":
			this.toAssignable(e.expression, t, i);
			break;
		case "ChainExpression":
			this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
			break;
		case "MemberExpression": if (!t) break;
		default: this.raise(e.start, "Assigning to rvalue");
	}
	else i && this.checkPatternErrors(i, !0);
	return e;
};
D.toAssignableList = function(e, t) {
	for (var i = e.length, s = 0; s < i; s++) {
		var r = e[s];
		r && this.toAssignable(r, t);
	}
	if (i) {
		var o = e[i - 1];
		this.options.ecmaVersion === 6 && t && o && o.type === "RestElement" && o.argument.type !== "Identifier" && this.unexpected(o.argument.start);
	}
	return e;
};
D.parseSpread = function(e) {
	var t = this.startNode();
	return this.next(), t.argument = this.parseMaybeAssign(!1, e), this.finishNode(t, "SpreadElement");
};
D.parseRestBinding = function() {
	var e = this.startNode();
	return this.next(), this.options.ecmaVersion === 6 && this.type !== a.name && this.unexpected(), e.argument = this.parseBindingAtom(), this.finishNode(e, "RestElement");
};
D.parseBindingAtom = function() {
	if (this.options.ecmaVersion >= 6) switch (this.type) {
		case a.bracketL:
			var e = this.startNode();
			return this.next(), e.elements = this.parseBindingList(a.bracketR, !0, !0), this.finishNode(e, "ArrayPattern");
		case a.braceL: return this.parseObj(!0);
	}
	return this.parseIdent();
};
D.parseBindingList = function(e, t, i, s) {
	for (var r = [], o = !0; !this.eat(e);) if (o ? o = !1 : this.expect(a.comma), t && this.type === a.comma) r.push(null);
	else {
		if (i && this.afterTrailingComma(e)) break;
		if (this.type === a.ellipsis) {
			var u = this.parseRestBinding();
			this.parseBindingListItem(u), r.push(u), this.type === a.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element"), this.expect(e);
			break;
		} else r.push(this.parseAssignableListItem(s));
	}
	return r;
};
D.parseAssignableListItem = function(e) {
	var t = this.parseMaybeDefault(this.start, this.startLoc);
	return this.parseBindingListItem(t), t;
};
D.parseBindingListItem = function(e) {
	return e;
};
D.parseMaybeDefault = function(e, t, i) {
	if (i = i || this.parseBindingAtom(), this.options.ecmaVersion < 6 || !this.eat(a.eq)) return i;
	var s = this.startNodeAt(e, t);
	return s.left = i, s.right = this.parseMaybeAssign(), this.finishNode(s, "AssignmentPattern");
};
D.checkLValSimple = function(e, t, i) {
	t === void 0 && (t = xe);
	var s = t !== xe;
	switch (e.type) {
		case "Identifier":
			this.strict && this.reservedWordsStrictBind.test(e.name) && this.raiseRecoverable(e.start, (s ? "Binding " : "Assigning to ") + e.name + " in strict mode"), s && (t === K && e.name === "let" && this.raiseRecoverable(e.start, "let is disallowed as a lexically bound name"), i && ($(i, e.name) && this.raiseRecoverable(e.start, "Argument name clash"), i[e.name] = !0), t !== Et && this.declareName(e.name, t, e.start));
			break;
		case "ChainExpression":
			this.raiseRecoverable(e.start, "Optional chaining cannot appear in left-hand side");
			break;
		case "MemberExpression":
			s && this.raiseRecoverable(e.start, "Binding member expression");
			break;
		case "ParenthesizedExpression": return s && this.raiseRecoverable(e.start, "Binding parenthesized expression"), this.checkLValSimple(e.expression, t, i);
		default: this.raise(e.start, (s ? "Binding" : "Assigning to") + " rvalue");
	}
};
D.checkLValPattern = function(e, t, i) {
	switch (t === void 0 && (t = xe), e.type) {
		case "ObjectPattern":
			for (var s = 0, r = e.properties; s < r.length; s += 1) {
				var o = r[s];
				this.checkLValInnerPattern(o, t, i);
			}
			break;
		case "ArrayPattern":
			for (var u = 0, p = e.elements; u < p.length; u += 1) {
				var h = p[u];
				h && this.checkLValInnerPattern(h, t, i);
			}
			break;
		default: this.checkLValSimple(e, t, i);
	}
};
D.checkLValInnerPattern = function(e, t, i) {
	switch (t === void 0 && (t = xe), e.type) {
		case "Property":
			this.checkLValInnerPattern(e.value, t, i);
			break;
		case "AssignmentPattern":
			this.checkLValPattern(e.left, t, i);
			break;
		case "RestElement":
			this.checkLValPattern(e.argument, t, i);
			break;
		default: this.checkLValPattern(e, t, i);
	}
};
var F = function(t, i, s, r, o) {
	this.token = t, this.isExpr = !!i, this.preserveSpace = !!s, this.override = r, this.generator = !!o;
}, T = {
	b_stat: new F("{", !1),
	b_expr: new F("{", !0),
	b_tmpl: new F("${", !1),
	p_stat: new F("(", !1),
	p_expr: new F("(", !0),
	q_tmpl: new F("`", !0, !0, function(e) {
		return e.tryReadTemplateToken();
	}),
	f_stat: new F("function", !1),
	f_expr: new F("function", !0),
	f_expr_gen: new F("function", !0, !1, null, !0),
	f_gen: new F("function", !1, !1, null, !0)
}, ee = A.prototype;
ee.initialContext = function() {
	return [T.b_stat];
};
ee.curContext = function() {
	return this.context[this.context.length - 1];
};
ee.braceIsBlock = function(e) {
	var t = this.curContext();
	return t === T.f_expr || t === T.f_stat ? !0 : e === a.colon && (t === T.b_stat || t === T.b_expr) ? !t.isExpr : e === a._return || e === a.name && this.exprAllowed ? L.test(this.input.slice(this.lastTokEnd, this.start)) : e === a._else || e === a.semi || e === a.eof || e === a.parenR || e === a.arrow ? !0 : e === a.braceL ? t === T.b_stat : e === a._var || e === a._const || e === a.name ? !1 : !this.exprAllowed;
};
ee.inGeneratorContext = function() {
	for (var e = this.context.length - 1; e >= 1; e--) {
		var t = this.context[e];
		if (t.token === "function") return t.generator;
	}
	return !1;
};
ee.updateContext = function(e) {
	var t, i = this.type;
	i.keyword && e === a.dot ? this.exprAllowed = !1 : (t = i.updateContext) ? t.call(this, e) : this.exprAllowed = i.beforeExpr;
};
ee.overrideContext = function(e) {
	this.curContext() !== e && (this.context[this.context.length - 1] = e);
};
a.parenR.updateContext = a.braceR.updateContext = function() {
	if (this.context.length === 1) {
		this.exprAllowed = !0;
		return;
	}
	var e = this.context.pop();
	e === T.b_stat && this.curContext().token === "function" && (e = this.context.pop()), this.exprAllowed = !e.isExpr;
};
a.braceL.updateContext = function(e) {
	this.context.push(this.braceIsBlock(e) ? T.b_stat : T.b_expr), this.exprAllowed = !0;
};
a.dollarBraceL.updateContext = function() {
	this.context.push(T.b_tmpl), this.exprAllowed = !0;
};
a.parenL.updateContext = function(e) {
	var t = e === a._if || e === a._for || e === a._with || e === a._while;
	this.context.push(t ? T.p_stat : T.p_expr), this.exprAllowed = !0;
};
a.incDec.updateContext = function() {};
a._function.updateContext = a._class.updateContext = function(e) {
	e.beforeExpr && e !== a._else && !(e === a.semi && this.curContext() !== T.p_stat) && !(e === a._return && L.test(this.input.slice(this.lastTokEnd, this.start))) && !((e === a.colon || e === a.braceL) && this.curContext() === T.b_stat) ? this.context.push(T.f_expr) : this.context.push(T.f_stat), this.exprAllowed = !1;
};
a.colon.updateContext = function() {
	this.curContext().token === "function" && this.context.pop(), this.exprAllowed = !0;
};
a.backQuote.updateContext = function() {
	this.curContext() === T.q_tmpl ? this.context.pop() : this.context.push(T.q_tmpl), this.exprAllowed = !1;
};
a.star.updateContext = function(e) {
	if (e === a._function) {
		var t = this.context.length - 1;
		this.context[t] === T.f_expr ? this.context[t] = T.f_expr_gen : this.context[t] = T.f_gen;
	}
	this.exprAllowed = !0;
};
a.name.updateContext = function(e) {
	var t = !1;
	this.options.ecmaVersion >= 6 && e !== a.dot && (this.value === "of" && !this.exprAllowed || this.value === "yield" && this.inGeneratorContext()) && (t = !0), this.exprAllowed = t;
};
var g = A.prototype;
g.checkPropClash = function(e, t, i) {
	if (!(this.options.ecmaVersion >= 9 && e.type === "SpreadElement") && !(this.options.ecmaVersion >= 6 && (e.computed || e.method || e.shorthand))) {
		var s = e.key, r;
		switch (s.type) {
			case "Identifier":
				r = s.name;
				break;
			case "Literal":
				r = String(s.value);
				break;
			default: return;
		}
		var o = e.kind;
		if (this.options.ecmaVersion >= 6) {
			r === "__proto__" && o === "init" && (t.proto && (i ? i.doubleProto < 0 && (i.doubleProto = s.start) : this.raiseRecoverable(s.start, "Redefinition of __proto__ property")), t.proto = !0);
			return;
		}
		r = "$" + r;
		var u = t[r];
		if (u) {
			var p;
			o === "init" ? p = this.strict && u.init || u.get || u.set : p = u.init || u[o], p && this.raiseRecoverable(s.start, "Redefinition of property");
		} else u = t[r] = {
			init: !1,
			get: !1,
			set: !1
		};
		u[o] = !0;
	}
};
g.parseExpression = function(e, t) {
	var i = this.start, s = this.startLoc, r = this.parseMaybeAssign(e, t);
	if (this.type === a.comma) {
		var o = this.startNodeAt(i, s);
		for (o.expressions = [r]; this.eat(a.comma);) o.expressions.push(this.parseMaybeAssign(e, t));
		return this.finishNode(o, "SequenceExpression");
	}
	return r;
};
g.parseMaybeAssign = function(e, t, i) {
	if (this.isContextual("yield")) {
		if (this.inGenerator) return this.parseYield(e);
		this.exprAllowed = !1;
	}
	var s = !1, r = -1, o = -1, u = -1;
	t ? (r = t.parenthesizedAssign, o = t.trailingComma, u = t.doubleProto, t.parenthesizedAssign = t.trailingComma = -1) : (t = new Ce(), s = !0);
	var p = this.start, h = this.startLoc;
	(this.type === a.parenL || this.type === a.name) && (this.potentialArrowAt = this.start, this.potentialArrowInForAwait = e === "await");
	var l = this.parseMaybeConditional(e, t);
	if (i && (l = i.call(this, l, p, h)), this.type.isAssign) {
		var m = this.startNodeAt(p, h);
		return m.operator = this.value, this.type === a.eq && (l = this.toAssignable(l, !1, t)), s || (t.parenthesizedAssign = t.trailingComma = t.doubleProto = -1), t.shorthandAssign >= l.start && (t.shorthandAssign = -1), this.type === a.eq ? this.checkLValPattern(l) : this.checkLValSimple(l), m.left = l, this.next(), m.right = this.parseMaybeAssign(e), u > -1 && (t.doubleProto = u), this.finishNode(m, "AssignmentExpression");
	} else s && this.checkExpressionErrors(t, !0);
	return r > -1 && (t.parenthesizedAssign = r), o > -1 && (t.trailingComma = o), l;
};
g.parseMaybeConditional = function(e, t) {
	var i = this.start, s = this.startLoc, r = this.parseExprOps(e, t);
	if (this.checkExpressionErrors(t)) return r;
	if (this.eat(a.question)) {
		var o = this.startNodeAt(i, s);
		return o.test = r, o.consequent = this.parseMaybeAssign(), this.expect(a.colon), o.alternate = this.parseMaybeAssign(e), this.finishNode(o, "ConditionalExpression");
	}
	return r;
};
g.parseExprOps = function(e, t) {
	var i = this.start, s = this.startLoc, r = this.parseMaybeUnary(t, !1, !1, e);
	return this.checkExpressionErrors(t) || r.start === i && r.type === "ArrowFunctionExpression" ? r : this.parseExprOp(r, i, s, -1, e);
};
g.parseExprOp = function(e, t, i, s, r) {
	var o = this.type.binop;
	if (o != null && (!r || this.type !== a._in) && o > s) {
		var u = this.type === a.logicalOR || this.type === a.logicalAND, p = this.type === a.coalesce;
		p && (o = a.logicalAND.binop);
		var h = this.value;
		this.next();
		var l = this.start, m = this.startLoc, S = this.parseExprOp(this.parseMaybeUnary(null, !1, !1, r), l, m, o, r), E = this.buildBinary(t, i, e, S, h, u || p);
		return (u && this.type === a.coalesce || p && (this.type === a.logicalOR || this.type === a.logicalAND)) && this.raiseRecoverable(this.start, "Logical expressions and coalesce expressions cannot be mixed. Wrap either by parentheses"), this.parseExprOp(E, t, i, s, r);
	}
	return e;
};
g.buildBinary = function(e, t, i, s, r, o) {
	s.type === "PrivateIdentifier" && this.raise(s.start, "Private identifier can only be left side of binary expression");
	var u = this.startNodeAt(e, t);
	return u.left = i, u.operator = r, u.right = s, this.finishNode(u, o ? "LogicalExpression" : "BinaryExpression");
};
g.parseMaybeUnary = function(e, t, i, s) {
	var r = this.start, o = this.startLoc, u;
	if (this.isContextual("await") && this.canAwait) u = this.parseAwait(s), t = !0;
	else if (this.type.prefix) {
		var p = this.startNode(), h = this.type === a.incDec;
		p.operator = this.value, p.prefix = !0, this.next(), p.argument = this.parseMaybeUnary(null, !0, h, s), this.checkExpressionErrors(e, !0), h ? this.checkLValSimple(p.argument) : this.strict && p.operator === "delete" && kt(p.argument) ? this.raiseRecoverable(p.start, "Deleting local variable in strict mode") : p.operator === "delete" && qe(p.argument) ? this.raiseRecoverable(p.start, "Private fields can not be deleted") : t = !0, u = this.finishNode(p, h ? "UpdateExpression" : "UnaryExpression");
	} else if (!t && this.type === a.privateId) (s || this.privateNameStack.length === 0) && this.options.checkPrivateFields && this.unexpected(), u = this.parsePrivateIdent(), this.type !== a._in && this.unexpected();
	else {
		if (u = this.parseExprSubscripts(e, s), this.checkExpressionErrors(e)) return u;
		for (; this.type.postfix && !this.canInsertSemicolon();) {
			var l = this.startNodeAt(r, o);
			l.operator = this.value, l.prefix = !1, l.argument = u, this.checkLValSimple(u), this.next(), u = this.finishNode(l, "UpdateExpression");
		}
	}
	if (!i && this.eat(a.starstar)) if (t) this.unexpected(this.lastTokStart);
	else return this.buildBinary(r, o, u, this.parseMaybeUnary(null, !1, !1, s), "**", !1);
	else return u;
};
function kt(e) {
	return e.type === "Identifier" || e.type === "ParenthesizedExpression" && kt(e.expression);
}
function qe(e) {
	return e.type === "MemberExpression" && e.property.type === "PrivateIdentifier" || e.type === "ChainExpression" && qe(e.expression) || e.type === "ParenthesizedExpression" && qe(e.expression);
}
g.parseExprSubscripts = function(e, t) {
	var i = this.start, s = this.startLoc, r = this.parseExprAtom(e, t);
	if (r.type === "ArrowFunctionExpression" && this.input.slice(this.lastTokStart, this.lastTokEnd) !== ")") return r;
	var o = this.parseSubscripts(r, i, s, !1, t);
	return e && o.type === "MemberExpression" && (e.parenthesizedAssign >= o.start && (e.parenthesizedAssign = -1), e.parenthesizedBind >= o.start && (e.parenthesizedBind = -1), e.trailingComma >= o.start && (e.trailingComma = -1)), o;
};
g.parseSubscripts = function(e, t, i, s, r) {
	for (var o = this.options.ecmaVersion >= 8 && e.type === "Identifier" && e.name === "async" && this.lastTokEnd === e.end && !this.canInsertSemicolon() && e.end - e.start === 5 && this.potentialArrowAt === e.start, u = !1;;) {
		var p = this.parseSubscript(e, t, i, s, o, u, r);
		if (p.optional && (u = !0), p === e || p.type === "ArrowFunctionExpression") {
			if (u) {
				var h = this.startNodeAt(t, i);
				h.expression = p, p = this.finishNode(h, "ChainExpression");
			}
			return p;
		}
		e = p;
	}
};
g.shouldParseAsyncArrow = function() {
	return !this.canInsertSemicolon() && this.eat(a.arrow);
};
g.parseSubscriptAsyncArrow = function(e, t, i, s) {
	return this.parseArrowExpression(this.startNodeAt(e, t), i, !0, s);
};
g.parseSubscript = function(e, t, i, s, r, o, u) {
	var p = this.options.ecmaVersion >= 11, h = p && this.eat(a.questionDot);
	s && h && this.raise(this.lastTokStart, "Optional chaining cannot appear in the callee of new expressions");
	var l = this.eat(a.bracketL);
	if (l || h && this.type !== a.parenL && this.type !== a.backQuote || this.eat(a.dot)) {
		var m = this.startNodeAt(t, i);
		m.object = e, l ? (m.property = this.parseExpression(), this.expect(a.bracketR)) : this.type === a.privateId && e.type !== "Super" ? m.property = this.parsePrivateIdent() : m.property = this.parseIdent(this.options.allowReserved !== "never"), m.computed = !!l, p && (m.optional = h), e = this.finishNode(m, "MemberExpression");
	} else if (!s && this.eat(a.parenL)) {
		var S = new Ce(), E = this.yieldPos, c = this.awaitPos, x = this.awaitIdentPos;
		this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0;
		var y = this.parseExprList(a.parenR, this.options.ecmaVersion >= 8, !1, S);
		if (r && !h && this.shouldParseAsyncArrow()) return this.checkPatternErrors(S, !1), this.checkYieldAwaitInDefaultParams(), this.awaitIdentPos > 0 && this.raise(this.awaitIdentPos, "Cannot use 'await' as identifier inside an async function"), this.yieldPos = E, this.awaitPos = c, this.awaitIdentPos = x, this.parseSubscriptAsyncArrow(t, i, y, u);
		this.checkExpressionErrors(S, !0), this.yieldPos = E || this.yieldPos, this.awaitPos = c || this.awaitPos, this.awaitIdentPos = x || this.awaitIdentPos;
		var v = this.startNodeAt(t, i);
		v.callee = e, v.arguments = y, p && (v.optional = h), e = this.finishNode(v, "CallExpression");
	} else if (this.type === a.backQuote) {
		(h || o) && this.raise(this.start, "Optional chaining cannot appear in the tag of tagged template expressions");
		var I = this.startNodeAt(t, i);
		I.tag = e, I.quasi = this.parseTemplate({ isTagged: !0 }), e = this.finishNode(I, "TaggedTemplateExpression");
	}
	return e;
};
g.parseExprAtom = function(e, t, i) {
	this.type === a.slash && this.readRegexp();
	var s, r = this.potentialArrowAt === this.start;
	switch (this.type) {
		case a._super: return this.allowSuper || this.raise(this.start, "'super' keyword outside a method"), s = this.startNode(), this.next(), this.type === a.parenL && !this.allowDirectSuper && this.raise(s.start, "super() call outside constructor of a subclass"), this.type !== a.dot && this.type !== a.bracketL && this.type !== a.parenL && this.unexpected(), this.finishNode(s, "Super");
		case a._this: return s = this.startNode(), this.next(), this.finishNode(s, "ThisExpression");
		case a.name:
			var o = this.start, u = this.startLoc, p = this.containsEsc, h = this.parseIdent(!1);
			if (this.options.ecmaVersion >= 8 && !p && h.name === "async" && !this.canInsertSemicolon() && this.eat(a._function)) return this.overrideContext(T.f_expr), this.parseFunction(this.startNodeAt(o, u), 0, !1, !0, t);
			if (r && !this.canInsertSemicolon()) {
				if (this.eat(a.arrow)) return this.parseArrowExpression(this.startNodeAt(o, u), [h], !1, t);
				if (this.options.ecmaVersion >= 8 && h.name === "async" && this.type === a.name && !p && (!this.potentialArrowInForAwait || this.value !== "of" || this.containsEsc)) return h = this.parseIdent(!1), (this.canInsertSemicolon() || !this.eat(a.arrow)) && this.unexpected(), this.parseArrowExpression(this.startNodeAt(o, u), [h], !0, t);
			}
			return h;
		case a.regexp:
			var l = this.value;
			return s = this.parseLiteral(l.value), s.regex = {
				pattern: l.pattern,
				flags: l.flags
			}, s;
		case a.num:
		case a.string: return this.parseLiteral(this.value);
		case a._null:
		case a._true:
		case a._false: return s = this.startNode(), s.value = this.type === a._null ? null : this.type === a._true, s.raw = this.type.keyword, this.next(), this.finishNode(s, "Literal");
		case a.parenL:
			var m = this.start, S = this.parseParenAndDistinguishExpression(r, t);
			return e && (e.parenthesizedAssign < 0 && !this.isSimpleAssignTarget(S) && (e.parenthesizedAssign = m), e.parenthesizedBind < 0 && (e.parenthesizedBind = m)), S;
		case a.bracketL: return s = this.startNode(), this.next(), s.elements = this.parseExprList(a.bracketR, !0, !0, e), this.finishNode(s, "ArrayExpression");
		case a.braceL: return this.overrideContext(T.b_expr), this.parseObj(!1, e);
		case a._function: return s = this.startNode(), this.next(), this.parseFunction(s, 0);
		case a._class: return this.parseClass(this.startNode(), !1);
		case a._new: return this.parseNew();
		case a.backQuote: return this.parseTemplate();
		case a._import: return this.options.ecmaVersion >= 11 ? this.parseExprImport(i) : this.unexpected();
		default: return this.parseExprAtomDefault();
	}
};
g.parseExprAtomDefault = function() {
	this.unexpected();
};
g.parseExprImport = function(e) {
	var t = this.startNode();
	if (this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword import"), this.next(), this.type === a.parenL && !e) return this.parseDynamicImport(t);
	if (this.type === a.dot) {
		var i = this.startNodeAt(t.start, t.loc && t.loc.start);
		return i.name = "import", t.meta = this.finishNode(i, "Identifier"), this.parseImportMeta(t);
	} else this.unexpected();
};
g.parseDynamicImport = function(e) {
	if (this.next(), e.source = this.parseMaybeAssign(), this.options.ecmaVersion >= 16) this.eat(a.parenR) ? e.options = null : (this.expect(a.comma), this.afterTrailingComma(a.parenR) ? e.options = null : (e.options = this.parseMaybeAssign(), this.eat(a.parenR) || (this.expect(a.comma), this.afterTrailingComma(a.parenR) || this.unexpected())));
	else if (!this.eat(a.parenR)) {
		var t = this.start;
		this.eat(a.comma) && this.eat(a.parenR) ? this.raiseRecoverable(t, "Trailing comma is not allowed in import()") : this.unexpected(t);
	}
	return this.finishNode(e, "ImportExpression");
};
g.parseImportMeta = function(e) {
	this.next();
	var t = this.containsEsc;
	return e.property = this.parseIdent(!0), e.property.name !== "meta" && this.raiseRecoverable(e.property.start, "The only valid meta property for import is 'import.meta'"), t && this.raiseRecoverable(e.start, "'import.meta' must not contain escaped characters"), this.options.sourceType !== "module" && !this.options.allowImportExportEverywhere && this.raiseRecoverable(e.start, "Cannot use 'import.meta' outside a module"), this.finishNode(e, "MetaProperty");
};
g.parseLiteral = function(e) {
	var t = this.startNode();
	return t.value = e, t.raw = this.input.slice(this.start, this.end), t.raw.charCodeAt(t.raw.length - 1) === 110 && (t.bigint = t.value != null ? t.value.toString() : t.raw.slice(0, -1).replace(/_/g, "")), this.next(), this.finishNode(t, "Literal");
};
g.parseParenExpression = function() {
	this.expect(a.parenL);
	var e = this.parseExpression();
	return this.expect(a.parenR), e;
};
g.shouldParseArrow = function(e) {
	return !this.canInsertSemicolon();
};
g.parseParenAndDistinguishExpression = function(e, t) {
	var i = this.start, s = this.startLoc, r, o = this.options.ecmaVersion >= 8;
	if (this.options.ecmaVersion >= 6) {
		this.next();
		var u = this.start, p = this.startLoc, h = [], l = !0, m = !1, S = new Ce(), E = this.yieldPos, c = this.awaitPos, x;
		for (this.yieldPos = 0, this.awaitPos = 0; this.type !== a.parenR;) if (l ? l = !1 : this.expect(a.comma), o && this.afterTrailingComma(a.parenR, !0)) {
			m = !0;
			break;
		} else if (this.type === a.ellipsis) {
			x = this.start, h.push(this.parseParenItem(this.parseRestBinding())), this.type === a.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element");
			break;
		} else h.push(this.parseMaybeAssign(!1, S, this.parseParenItem));
		var y = this.lastTokEnd, v = this.lastTokEndLoc;
		if (this.expect(a.parenR), e && this.shouldParseArrow(h) && this.eat(a.arrow)) return this.checkPatternErrors(S, !1), this.checkYieldAwaitInDefaultParams(), this.yieldPos = E, this.awaitPos = c, this.parseParenArrowList(i, s, h, t);
		(!h.length || m) && this.unexpected(this.lastTokStart), x && this.unexpected(x), this.checkExpressionErrors(S, !0), this.yieldPos = E || this.yieldPos, this.awaitPos = c || this.awaitPos, h.length > 1 ? (r = this.startNodeAt(u, p), r.expressions = h, this.finishNodeAt(r, "SequenceExpression", y, v)) : r = h[0];
	} else r = this.parseParenExpression();
	if (this.options.preserveParens) {
		var I = this.startNodeAt(i, s);
		return I.expression = r, this.finishNode(I, "ParenthesizedExpression");
	} else return r;
};
g.parseParenItem = function(e) {
	return e;
};
g.parseParenArrowList = function(e, t, i, s) {
	return this.parseArrowExpression(this.startNodeAt(e, t), i, !1, s);
};
var Zi = [];
g.parseNew = function() {
	this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword new");
	var e = this.startNode();
	if (this.next(), this.options.ecmaVersion >= 6 && this.type === a.dot) {
		var t = this.startNodeAt(e.start, e.loc && e.loc.start);
		t.name = "new", e.meta = this.finishNode(t, "Identifier"), this.next();
		var i = this.containsEsc;
		return e.property = this.parseIdent(!0), e.property.name !== "target" && this.raiseRecoverable(e.property.start, "The only valid meta property for new is 'new.target'"), i && this.raiseRecoverable(e.start, "'new.target' must not contain escaped characters"), this.allowNewDotTarget || this.raiseRecoverable(e.start, "'new.target' can only be used in functions and class static block"), this.finishNode(e, "MetaProperty");
	}
	var s = this.start, r = this.startLoc;
	return e.callee = this.parseSubscripts(this.parseExprAtom(null, !1, !0), s, r, !0, !1), this.eat(a.parenL) ? e.arguments = this.parseExprList(a.parenR, this.options.ecmaVersion >= 8, !1) : e.arguments = Zi, this.finishNode(e, "NewExpression");
};
g.parseTemplateElement = function(e) {
	var t = e.isTagged, i = this.startNode();
	return this.type === a.invalidTemplate ? (t || this.raiseRecoverable(this.start, "Bad escape sequence in untagged template literal"), i.value = {
		raw: this.value.replace(/\r\n?/g, `
`),
		cooked: null
	}) : i.value = {
		raw: this.input.slice(this.start, this.end).replace(/\r\n?/g, `
`),
		cooked: this.value
	}, this.next(), i.tail = this.type === a.backQuote, this.finishNode(i, "TemplateElement");
};
g.parseTemplate = function(e) {
	e === void 0 && (e = {});
	var t = e.isTagged;
	t === void 0 && (t = !1);
	var i = this.startNode();
	this.next(), i.expressions = [];
	var s = this.parseTemplateElement({ isTagged: t });
	for (i.quasis = [s]; !s.tail;) this.type === a.eof && this.raise(this.pos, "Unterminated template literal"), this.expect(a.dollarBraceL), i.expressions.push(this.parseExpression()), this.expect(a.braceR), i.quasis.push(s = this.parseTemplateElement({ isTagged: t }));
	return this.next(), this.finishNode(i, "TemplateLiteral");
};
g.isAsyncProp = function(e) {
	return !e.computed && e.key.type === "Identifier" && e.key.name === "async" && (this.type === a.name || this.type === a.num || this.type === a.string || this.type === a.bracketL || this.type.keyword || this.options.ecmaVersion >= 9 && this.type === a.star) && !L.test(this.input.slice(this.lastTokEnd, this.start));
};
g.parseObj = function(e, t) {
	var i = this.startNode(), s = !0, r = {};
	for (i.properties = [], this.next(); !this.eat(a.braceR);) {
		if (s) s = !1;
		else if (this.expect(a.comma), this.options.ecmaVersion >= 5 && this.afterTrailingComma(a.braceR)) break;
		var o = this.parseProperty(e, t);
		e || this.checkPropClash(o, r, t), i.properties.push(o);
	}
	return this.finishNode(i, e ? "ObjectPattern" : "ObjectExpression");
};
g.parseProperty = function(e, t) {
	var i = this.startNode(), s, r, o, u;
	if (this.options.ecmaVersion >= 9 && this.eat(a.ellipsis)) return e ? (i.argument = this.parseIdent(!1), this.type === a.comma && this.raiseRecoverable(this.start, "Comma is not permitted after the rest element"), this.finishNode(i, "RestElement")) : (i.argument = this.parseMaybeAssign(!1, t), this.type === a.comma && t && t.trailingComma < 0 && (t.trailingComma = this.start), this.finishNode(i, "SpreadElement"));
	this.options.ecmaVersion >= 6 && (i.method = !1, i.shorthand = !1, (e || t) && (o = this.start, u = this.startLoc), e || (s = this.eat(a.star)));
	var p = this.containsEsc;
	return this.parsePropertyName(i), !e && !p && this.options.ecmaVersion >= 8 && !s && this.isAsyncProp(i) ? (r = !0, s = this.options.ecmaVersion >= 9 && this.eat(a.star), this.parsePropertyName(i)) : r = !1, this.parsePropertyValue(i, e, s, r, o, u, t, p), this.finishNode(i, "Property");
};
g.parseGetterSetter = function(e) {
	var t = e.key.name;
	this.parsePropertyName(e), e.value = this.parseMethod(!1), e.kind = t;
	var i = e.kind === "get" ? 0 : 1;
	if (e.value.params.length !== i) {
		var s = e.value.start;
		e.kind === "get" ? this.raiseRecoverable(s, "getter should have no params") : this.raiseRecoverable(s, "setter should have exactly one param");
	} else e.kind === "set" && e.value.params[0].type === "RestElement" && this.raiseRecoverable(e.value.params[0].start, "Setter cannot use rest params");
};
g.parsePropertyValue = function(e, t, i, s, r, o, u, p) {
	(i || s) && this.type === a.colon && this.unexpected(), this.eat(a.colon) ? (e.value = t ? this.parseMaybeDefault(this.start, this.startLoc) : this.parseMaybeAssign(!1, u), e.kind = "init") : this.options.ecmaVersion >= 6 && this.type === a.parenL ? (t && this.unexpected(), e.method = !0, e.value = this.parseMethod(i, s), e.kind = "init") : !t && !p && this.options.ecmaVersion >= 5 && !e.computed && e.key.type === "Identifier" && (e.key.name === "get" || e.key.name === "set") && this.type !== a.comma && this.type !== a.braceR && this.type !== a.eq ? ((i || s) && this.unexpected(), this.parseGetterSetter(e)) : this.options.ecmaVersion >= 6 && !e.computed && e.key.type === "Identifier" ? ((i || s) && this.unexpected(), this.checkUnreserved(e.key), e.key.name === "await" && !this.awaitIdentPos && (this.awaitIdentPos = r), t ? e.value = this.parseMaybeDefault(r, o, this.copyNode(e.key)) : this.type === a.eq && u ? (u.shorthandAssign < 0 && (u.shorthandAssign = this.start), e.value = this.parseMaybeDefault(r, o, this.copyNode(e.key))) : e.value = this.copyNode(e.key), e.kind = "init", e.shorthand = !0) : this.unexpected();
};
g.parsePropertyName = function(e) {
	if (this.options.ecmaVersion >= 6) {
		if (this.eat(a.bracketL)) return e.computed = !0, e.key = this.parseMaybeAssign(), this.expect(a.bracketR), e.key;
		e.computed = !1;
	}
	return e.key = this.type === a.num || this.type === a.string ? this.parseExprAtom() : this.parseIdent(this.options.allowReserved !== "never");
};
g.initFunction = function(e) {
	e.id = null, this.options.ecmaVersion >= 6 && (e.generator = e.expression = !1), this.options.ecmaVersion >= 8 && (e.async = !1);
};
g.parseMethod = function(e, t, i) {
	var s = this.startNode(), r = this.yieldPos, o = this.awaitPos, u = this.awaitIdentPos;
	return this.initFunction(s), this.options.ecmaVersion >= 6 && (s.generator = e), this.options.ecmaVersion >= 8 && (s.async = !!t), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, this.enterScope(Xe(t, s.generator) | Se | (i ? _t : 0)), this.expect(a.parenL), s.params = this.parseBindingList(a.parenR, !1, this.options.ecmaVersion >= 8), this.checkYieldAwaitInDefaultParams(), this.parseFunctionBody(s, !1, !0, !1), this.yieldPos = r, this.awaitPos = o, this.awaitIdentPos = u, this.finishNode(s, "FunctionExpression");
};
g.parseArrowExpression = function(e, t, i, s) {
	var r = this.yieldPos, o = this.awaitPos, u = this.awaitIdentPos;
	return this.enterScope(Xe(i, !1) | He), this.initFunction(e), this.options.ecmaVersion >= 8 && (e.async = !!i), this.yieldPos = 0, this.awaitPos = 0, this.awaitIdentPos = 0, e.params = this.toAssignableList(t, !0), this.parseFunctionBody(e, !0, !1, s), this.yieldPos = r, this.awaitPos = o, this.awaitIdentPos = u, this.finishNode(e, "ArrowFunctionExpression");
};
g.parseFunctionBody = function(e, t, i, s) {
	var r = t && this.type !== a.braceL, o = this.strict, u = !1;
	if (r) e.body = this.parseMaybeAssign(s), e.expression = !0, this.checkParams(e, !1);
	else {
		var p = this.options.ecmaVersion >= 7 && !this.isSimpleParamList(e.params);
		(!o || p) && (u = this.strictDirective(this.end), u && p && this.raiseRecoverable(e.start, "Illegal 'use strict' directive in function with non-simple parameter list"));
		var h = this.labels;
		this.labels = [], u && (this.strict = !0), this.checkParams(e, !o && !u && !t && !i && this.isSimpleParamList(e.params)), this.strict && e.id && this.checkLValSimple(e.id, Et), e.body = this.parseBlock(!1, void 0, u && !o), e.expression = !1, this.adaptDirectivePrologue(e.body.body), this.labels = h;
	}
	this.exitScope();
};
g.isSimpleParamList = function(e) {
	for (var t = 0, i = e; t < i.length; t += 1) if (i[t].type !== "Identifier") return !1;
	return !0;
};
g.checkParams = function(e, t) {
	for (var i = Object.create(null), s = 0, r = e.params; s < r.length; s += 1) {
		var o = r[s];
		this.checkLValInnerPattern(o, We, t ? null : i);
	}
};
g.parseExprList = function(e, t, i, s) {
	for (var r = [], o = !0; !this.eat(e);) {
		if (o) o = !1;
		else if (this.expect(a.comma), t && this.afterTrailingComma(e)) break;
		var u = void 0;
		i && this.type === a.comma ? u = null : this.type === a.ellipsis ? (u = this.parseSpread(s), s && this.type === a.comma && s.trailingComma < 0 && (s.trailingComma = this.start)) : u = this.parseMaybeAssign(!1, s), r.push(u);
	}
	return r;
};
g.checkUnreserved = function(e) {
	var t = e.start, i = e.end, s = e.name;
	if (this.inGenerator && s === "yield" && this.raiseRecoverable(t, "Cannot use 'yield' as identifier inside a generator"), this.inAsync && s === "await" && this.raiseRecoverable(t, "Cannot use 'await' as identifier inside an async function"), !(this.currentThisScope().flags & _e) && s === "arguments" && this.raiseRecoverable(t, "Cannot use 'arguments' in class field initializer"), this.inClassStaticBlock && (s === "arguments" || s === "await") && this.raise(t, "Cannot use " + s + " in class static initialization block"), this.keywords.test(s) && this.raise(t, "Unexpected keyword '" + s + "'"), !(this.options.ecmaVersion < 6 && this.input.slice(t, i).indexOf("\\") !== -1)) (this.strict ? this.reservedWordsStrict : this.reservedWords).test(s) && (!this.inAsync && s === "await" && this.raiseRecoverable(t, "Cannot use keyword 'await' outside an async function"), this.raiseRecoverable(t, "The keyword '" + s + "' is reserved"));
};
g.parseIdent = function(e) {
	var t = this.parseIdentNode();
	return this.next(!!e), this.finishNode(t, "Identifier"), e || (this.checkUnreserved(t), t.name === "await" && !this.awaitIdentPos && (this.awaitIdentPos = t.start)), t;
};
g.parseIdentNode = function() {
	var e = this.startNode();
	return this.type === a.name ? e.name = this.value : this.type.keyword ? (e.name = this.type.keyword, (e.name === "class" || e.name === "function") && (this.lastTokEnd !== this.lastTokStart + 1 || this.input.charCodeAt(this.lastTokStart) !== 46) && this.context.pop(), this.type = a.name) : this.unexpected(), e;
};
g.parsePrivateIdent = function() {
	var e = this.startNode();
	return this.type === a.privateId ? e.name = this.value : this.unexpected(), this.next(), this.finishNode(e, "PrivateIdentifier"), this.options.checkPrivateFields && (this.privateNameStack.length === 0 ? this.raise(e.start, "Private field '#" + e.name + "' must be declared in an enclosing class") : this.privateNameStack[this.privateNameStack.length - 1].used.push(e)), e;
};
g.parseYield = function(e) {
	this.yieldPos || (this.yieldPos = this.start);
	var t = this.startNode();
	return this.next(), this.type === a.semi || this.canInsertSemicolon() || this.type !== a.star && !this.type.startsExpr ? (t.delegate = !1, t.argument = null) : (t.delegate = this.eat(a.star), t.argument = this.parseMaybeAssign(e)), this.finishNode(t, "YieldExpression");
};
g.parseAwait = function(e) {
	this.awaitPos || (this.awaitPos = this.start);
	var t = this.startNode();
	return this.next(), t.argument = this.parseMaybeUnary(null, !0, !1, e), this.finishNode(t, "AwaitExpression");
};
var ge = A.prototype;
ge.raise = function(e, t) {
	var i = vt(this.input, e);
	t += " (" + i.line + ":" + i.column + ")", this.sourceFile && (t += " in " + this.sourceFile);
	var s = new SyntaxError(t);
	throw s.pos = e, s.loc = i, s.raisedAt = this.pos, s;
};
ge.raiseRecoverable = ge.raise;
ge.curPosition = function() {
	if (this.options.locations) return new ne(this.curLine, this.pos - this.lineStart);
};
var W = A.prototype, es = function(t) {
	this.flags = t, this.var = [], this.lexical = [], this.functions = [];
};
W.enterScope = function(e) {
	this.scopeStack.push(new es(e));
};
W.exitScope = function() {
	this.scopeStack.pop();
};
W.treatFunctionsAsVarInScope = function(e) {
	return e.flags & Z || !this.inModule && e.flags & oe;
};
W.declareName = function(e, t, i) {
	var s = !1;
	if (t === K) {
		var r = this.currentScope();
		s = r.lexical.indexOf(e) > -1 || r.functions.indexOf(e) > -1 || r.var.indexOf(e) > -1, r.lexical.push(e), this.inModule && r.flags & oe && delete this.undefinedExports[e];
	} else if (t === Tt) this.currentScope().lexical.push(e);
	else if (t === Ct) {
		var u = this.currentScope();
		this.treatFunctionsAsVar ? s = u.lexical.indexOf(e) > -1 : s = u.lexical.indexOf(e) > -1 || u.var.indexOf(e) > -1, u.functions.push(e);
	} else for (var p = this.scopeStack.length - 1; p >= 0; --p) {
		var h = this.scopeStack[p];
		if (h.lexical.indexOf(e) > -1 && !(h.flags & St && h.lexical[0] === e) || !this.treatFunctionsAsVarInScope(h) && h.functions.indexOf(e) > -1) {
			s = !0;
			break;
		}
		if (h.var.push(e), this.inModule && h.flags & oe && delete this.undefinedExports[e], h.flags & _e) break;
	}
	s && this.raiseRecoverable(i, "Identifier '" + e + "' has already been declared");
};
W.checkLocalExport = function(e) {
	this.scopeStack[0].lexical.indexOf(e.name) === -1 && this.scopeStack[0].var.indexOf(e.name) === -1 && (this.undefinedExports[e.name] = e);
};
W.currentScope = function() {
	return this.scopeStack[this.scopeStack.length - 1];
};
W.currentVarScope = function() {
	for (var e = this.scopeStack.length - 1;; e--) {
		var t = this.scopeStack[e];
		if (t.flags & (_e | ue | z)) return t;
	}
};
W.currentThisScope = function() {
	for (var e = this.scopeStack.length - 1;; e--) {
		var t = this.scopeStack[e];
		if (t.flags & (_e | ue | z) && !(t.flags & He)) return t;
	}
};
var Te = function(t, i, s) {
	this.type = "", this.start = i, this.end = 0, t.options.locations && (this.loc = new be(t, s)), t.options.directSourceFile && (this.sourceFile = t.options.directSourceFile), t.options.ranges && (this.range = [i, 0]);
}, he = A.prototype;
he.startNode = function() {
	return new Te(this, this.start, this.startLoc);
};
he.startNodeAt = function(e, t) {
	return new Te(this, e, t);
};
function wt(e, t, i, s) {
	return e.type = t, e.end = i, this.options.locations && (e.loc.end = s), this.options.ranges && (e.range[1] = i), e;
}
he.finishNode = function(e, t) {
	return wt.call(this, e, t, this.lastTokEnd, this.lastTokEndLoc);
};
he.finishNodeAt = function(e, t, i, s) {
	return wt.call(this, e, t, i, s);
};
he.copyNode = function(e) {
	var t = new Te(this, e.start, this.startLoc);
	for (var i in e) t[i] = e[i];
	return t;
};
var ts = "Gara Garay Gukh Gurung_Khema Hrkt Katakana_Or_Hiragana Kawi Kirat_Rai Krai Nag_Mundari Nagm Ol_Onal Onao Sunu Sunuwar Todhri Todr Tulu_Tigalari Tutg Unknown Zzzz", Pt = "ASCII ASCII_Hex_Digit AHex Alphabetic Alpha Any Assigned Bidi_Control Bidi_C Bidi_Mirrored Bidi_M Case_Ignorable CI Cased Changes_When_Casefolded CWCF Changes_When_Casemapped CWCM Changes_When_Lowercased CWL Changes_When_NFKC_Casefolded CWKCF Changes_When_Titlecased CWT Changes_When_Uppercased CWU Dash Default_Ignorable_Code_Point DI Deprecated Dep Diacritic Dia Emoji Emoji_Component Emoji_Modifier Emoji_Modifier_Base Emoji_Presentation Extender Ext Grapheme_Base Gr_Base Grapheme_Extend Gr_Ext Hex_Digit Hex IDS_Binary_Operator IDSB IDS_Trinary_Operator IDST ID_Continue IDC ID_Start IDS Ideographic Ideo Join_Control Join_C Logical_Order_Exception LOE Lowercase Lower Math Noncharacter_Code_Point NChar Pattern_Syntax Pat_Syn Pattern_White_Space Pat_WS Quotation_Mark QMark Radical Regional_Indicator RI Sentence_Terminal STerm Soft_Dotted SD Terminal_Punctuation Term Unified_Ideograph UIdeo Uppercase Upper Variation_Selector VS White_Space space XID_Continue XIDC XID_Start XIDS", It = Pt + " Extended_Pictographic", Nt = It, Lt = Nt + " EBase EComp EMod EPres ExtPict", Rt = Lt, is = Rt, ss = {
	9: Pt,
	10: It,
	11: Nt,
	12: Lt,
	13: Rt,
	14: is
}, rs = "Basic_Emoji Emoji_Keycap_Sequence RGI_Emoji_Modifier_Sequence RGI_Emoji_Flag_Sequence RGI_Emoji_Tag_Sequence RGI_Emoji_ZWJ_Sequence RGI_Emoji", as = {
	9: "",
	10: "",
	11: "",
	12: "",
	13: "",
	14: rs
}, lt = "Cased_Letter LC Close_Punctuation Pe Connector_Punctuation Pc Control Cc cntrl Currency_Symbol Sc Dash_Punctuation Pd Decimal_Number Nd digit Enclosing_Mark Me Final_Punctuation Pf Format Cf Initial_Punctuation Pi Letter L Letter_Number Nl Line_Separator Zl Lowercase_Letter Ll Mark M Combining_Mark Math_Symbol Sm Modifier_Letter Lm Modifier_Symbol Sk Nonspacing_Mark Mn Number N Open_Punctuation Ps Other C Other_Letter Lo Other_Number No Other_Punctuation Po Other_Symbol So Paragraph_Separator Zp Private_Use Co Punctuation P punct Separator Z Space_Separator Zs Spacing_Mark Mc Surrogate Cs Symbol S Titlecase_Letter Lt Unassigned Cn Uppercase_Letter Lu", Vt = "Adlam Adlm Ahom Anatolian_Hieroglyphs Hluw Arabic Arab Armenian Armn Avestan Avst Balinese Bali Bamum Bamu Bassa_Vah Bass Batak Batk Bengali Beng Bhaiksuki Bhks Bopomofo Bopo Brahmi Brah Braille Brai Buginese Bugi Buhid Buhd Canadian_Aboriginal Cans Carian Cari Caucasian_Albanian Aghb Chakma Cakm Cham Cham Cherokee Cher Common Zyyy Coptic Copt Qaac Cuneiform Xsux Cypriot Cprt Cyrillic Cyrl Deseret Dsrt Devanagari Deva Duployan Dupl Egyptian_Hieroglyphs Egyp Elbasan Elba Ethiopic Ethi Georgian Geor Glagolitic Glag Gothic Goth Grantha Gran Greek Grek Gujarati Gujr Gurmukhi Guru Han Hani Hangul Hang Hanunoo Hano Hatran Hatr Hebrew Hebr Hiragana Hira Imperial_Aramaic Armi Inherited Zinh Qaai Inscriptional_Pahlavi Phli Inscriptional_Parthian Prti Javanese Java Kaithi Kthi Kannada Knda Katakana Kana Kayah_Li Kali Kharoshthi Khar Khmer Khmr Khojki Khoj Khudawadi Sind Lao Laoo Latin Latn Lepcha Lepc Limbu Limb Linear_A Lina Linear_B Linb Lisu Lisu Lycian Lyci Lydian Lydi Mahajani Mahj Malayalam Mlym Mandaic Mand Manichaean Mani Marchen Marc Masaram_Gondi Gonm Meetei_Mayek Mtei Mende_Kikakui Mend Meroitic_Cursive Merc Meroitic_Hieroglyphs Mero Miao Plrd Modi Mongolian Mong Mro Mroo Multani Mult Myanmar Mymr Nabataean Nbat New_Tai_Lue Talu Newa Newa Nko Nkoo Nushu Nshu Ogham Ogam Ol_Chiki Olck Old_Hungarian Hung Old_Italic Ital Old_North_Arabian Narb Old_Permic Perm Old_Persian Xpeo Old_South_Arabian Sarb Old_Turkic Orkh Oriya Orya Osage Osge Osmanya Osma Pahawh_Hmong Hmng Palmyrene Palm Pau_Cin_Hau Pauc Phags_Pa Phag Phoenician Phnx Psalter_Pahlavi Phlp Rejang Rjng Runic Runr Samaritan Samr Saurashtra Saur Sharada Shrd Shavian Shaw Siddham Sidd SignWriting Sgnw Sinhala Sinh Sora_Sompeng Sora Soyombo Soyo Sundanese Sund Syloti_Nagri Sylo Syriac Syrc Tagalog Tglg Tagbanwa Tagb Tai_Le Tale Tai_Tham Lana Tai_Viet Tavt Takri Takr Tamil Taml Tangut Tang Telugu Telu Thaana Thaa Thai Thai Tibetan Tibt Tifinagh Tfng Tirhuta Tirh Ugaritic Ugar Vai Vaii Warang_Citi Wara Yi Yiii Zanabazar_Square Zanb", Ot = Vt + " Dogra Dogr Gunjala_Gondi Gong Hanifi_Rohingya Rohg Makasar Maka Medefaidrin Medf Old_Sogdian Sogo Sogdian Sogd", Bt = Ot + " Elymaic Elym Nandinagari Nand Nyiakeng_Puachue_Hmong Hmnp Wancho Wcho", Dt = Bt + " Chorasmian Chrs Diak Dives_Akuru Khitan_Small_Script Kits Yezi Yezidi", Mt = Dt + " Cypro_Minoan Cpmn Old_Uyghur Ougr Tangsa Tnsa Toto Vithkuqi Vith", ns = Mt + " " + ts, os = {
	9: Vt,
	10: Ot,
	11: Bt,
	12: Dt,
	13: Mt,
	14: ns
}, Ft = {};
function us(e) {
	var t = Ft[e] = {
		binary: H(ss[e] + " " + lt),
		binaryOfStrings: H(as[e]),
		nonBinary: {
			General_Category: H(lt),
			Script: H(os[e])
		}
	};
	t.nonBinary.Script_Extensions = t.nonBinary.Script, t.nonBinary.gc = t.nonBinary.General_Category, t.nonBinary.sc = t.nonBinary.Script, t.nonBinary.scx = t.nonBinary.Script_Extensions;
}
for (me = 0, Fe = [
	9,
	10,
	11,
	12,
	13,
	14
]; me < Fe.length; me += 1) ft = Fe[me], us(ft);
var ft, me, Fe, f = A.prototype, ve = function(t, i) {
	this.parent = t, this.base = i || this;
};
ve.prototype.separatedFrom = function(t) {
	for (var i = this; i; i = i.parent) for (var s = t; s; s = s.parent) if (i.base === s.base && i !== s) return !0;
	return !1;
};
ve.prototype.sibling = function() {
	return new ve(this.parent, this.base);
};
var G = function(t) {
	this.parser = t, this.validFlags = "gim" + (t.options.ecmaVersion >= 6 ? "uy" : "") + (t.options.ecmaVersion >= 9 ? "s" : "") + (t.options.ecmaVersion >= 13 ? "d" : "") + (t.options.ecmaVersion >= 15 ? "v" : ""), this.unicodeProperties = Ft[t.options.ecmaVersion >= 14 ? 14 : t.options.ecmaVersion], this.source = "", this.flags = "", this.start = 0, this.switchU = !1, this.switchV = !1, this.switchN = !1, this.pos = 0, this.lastIntValue = 0, this.lastStringValue = "", this.lastAssertionIsQuantifiable = !1, this.numCapturingParens = 0, this.maxBackReference = 0, this.groupNames = Object.create(null), this.backReferenceNames = [], this.branchID = null;
};
G.prototype.reset = function(t, i, s) {
	var r = s.indexOf("v") !== -1, o = s.indexOf("u") !== -1;
	this.start = t | 0, this.source = i + "", this.flags = s, r && this.parser.options.ecmaVersion >= 15 ? (this.switchU = !0, this.switchV = !0, this.switchN = !0) : (this.switchU = o && this.parser.options.ecmaVersion >= 6, this.switchV = !1, this.switchN = o && this.parser.options.ecmaVersion >= 9);
};
G.prototype.raise = function(t) {
	this.parser.raiseRecoverable(this.start, "Invalid regular expression: /" + this.source + "/: " + t);
};
G.prototype.at = function(t, i) {
	i === void 0 && (i = !1);
	var s = this.source, r = s.length;
	if (t >= r) return -1;
	var o = s.charCodeAt(t);
	if (!(i || this.switchU) || o <= 55295 || o >= 57344 || t + 1 >= r) return o;
	var u = s.charCodeAt(t + 1);
	return u >= 56320 && u <= 57343 ? (o << 10) + u - 56613888 : o;
};
G.prototype.nextIndex = function(t, i) {
	i === void 0 && (i = !1);
	var s = this.source, r = s.length;
	if (t >= r) return r;
	var o = s.charCodeAt(t), u;
	return !(i || this.switchU) || o <= 55295 || o >= 57344 || t + 1 >= r || (u = s.charCodeAt(t + 1)) < 56320 || u > 57343 ? t + 1 : t + 2;
};
G.prototype.current = function(t) {
	return t === void 0 && (t = !1), this.at(this.pos, t);
};
G.prototype.lookahead = function(t) {
	return t === void 0 && (t = !1), this.at(this.nextIndex(this.pos, t), t);
};
G.prototype.advance = function(t) {
	t === void 0 && (t = !1), this.pos = this.nextIndex(this.pos, t);
};
G.prototype.eat = function(t, i) {
	return i === void 0 && (i = !1), this.current(i) === t ? (this.advance(i), !0) : !1;
};
G.prototype.eatChars = function(t, i) {
	i === void 0 && (i = !1);
	for (var s = this.pos, r = 0, o = t; r < o.length; r += 1) {
		var u = o[r], p = this.at(s, i);
		if (p === -1 || p !== u) return !1;
		s = this.nextIndex(s, i);
	}
	return this.pos = s, !0;
};
f.validateRegExpFlags = function(e) {
	for (var t = e.validFlags, i = e.flags, s = !1, r = !1, o = 0; o < i.length; o++) {
		var u = i.charAt(o);
		t.indexOf(u) === -1 && this.raise(e.start, "Invalid regular expression flag"), i.indexOf(u, o + 1) > -1 && this.raise(e.start, "Duplicate regular expression flag"), u === "u" && (s = !0), u === "v" && (r = !0);
	}
	this.options.ecmaVersion >= 15 && s && r && this.raise(e.start, "Invalid regular expression flag");
};
function hs(e) {
	for (var t in e) return !0;
	return !1;
}
f.validateRegExpPattern = function(e) {
	this.regexp_pattern(e), !e.switchN && this.options.ecmaVersion >= 9 && hs(e.groupNames) && (e.switchN = !0, this.regexp_pattern(e));
};
f.regexp_pattern = function(e) {
	e.pos = 0, e.lastIntValue = 0, e.lastStringValue = "", e.lastAssertionIsQuantifiable = !1, e.numCapturingParens = 0, e.maxBackReference = 0, e.groupNames = Object.create(null), e.backReferenceNames.length = 0, e.branchID = null, this.regexp_disjunction(e), e.pos !== e.source.length && (e.eat(41) && e.raise("Unmatched ')'"), (e.eat(93) || e.eat(125)) && e.raise("Lone quantifier brackets")), e.maxBackReference > e.numCapturingParens && e.raise("Invalid escape");
	for (var t = 0, i = e.backReferenceNames; t < i.length; t += 1) {
		var s = i[t];
		e.groupNames[s] || e.raise("Invalid named capture referenced");
	}
};
f.regexp_disjunction = function(e) {
	var t = this.options.ecmaVersion >= 16;
	for (t && (e.branchID = new ve(e.branchID, null)), this.regexp_alternative(e); e.eat(124);) t && (e.branchID = e.branchID.sibling()), this.regexp_alternative(e);
	t && (e.branchID = e.branchID.parent), this.regexp_eatQuantifier(e, !0) && e.raise("Nothing to repeat"), e.eat(123) && e.raise("Lone quantifier brackets");
};
f.regexp_alternative = function(e) {
	for (; e.pos < e.source.length && this.regexp_eatTerm(e););
};
f.regexp_eatTerm = function(e) {
	return this.regexp_eatAssertion(e) ? (e.lastAssertionIsQuantifiable && this.regexp_eatQuantifier(e) && e.switchU && e.raise("Invalid quantifier"), !0) : (e.switchU ? this.regexp_eatAtom(e) : this.regexp_eatExtendedAtom(e)) ? (this.regexp_eatQuantifier(e), !0) : !1;
};
f.regexp_eatAssertion = function(e) {
	var t = e.pos;
	if (e.lastAssertionIsQuantifiable = !1, e.eat(94) || e.eat(36)) return !0;
	if (e.eat(92)) {
		if (e.eat(66) || e.eat(98)) return !0;
		e.pos = t;
	}
	if (e.eat(40) && e.eat(63)) {
		var i = !1;
		if (this.options.ecmaVersion >= 9 && (i = e.eat(60)), e.eat(61) || e.eat(33)) return this.regexp_disjunction(e), e.eat(41) || e.raise("Unterminated group"), e.lastAssertionIsQuantifiable = !i, !0;
	}
	return e.pos = t, !1;
};
f.regexp_eatQuantifier = function(e, t) {
	return t === void 0 && (t = !1), this.regexp_eatQuantifierPrefix(e, t) ? (e.eat(63), !0) : !1;
};
f.regexp_eatQuantifierPrefix = function(e, t) {
	return e.eat(42) || e.eat(43) || e.eat(63) || this.regexp_eatBracedQuantifier(e, t);
};
f.regexp_eatBracedQuantifier = function(e, t) {
	var i = e.pos;
	if (e.eat(123)) {
		var s = 0, r = -1;
		if (this.regexp_eatDecimalDigits(e) && (s = e.lastIntValue, e.eat(44) && this.regexp_eatDecimalDigits(e) && (r = e.lastIntValue), e.eat(125))) return r !== -1 && r < s && !t && e.raise("numbers out of order in {} quantifier"), !0;
		e.switchU && !t && e.raise("Incomplete quantifier"), e.pos = i;
	}
	return !1;
};
f.regexp_eatAtom = function(e) {
	return this.regexp_eatPatternCharacters(e) || e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e);
};
f.regexp_eatReverseSolidusAtomEscape = function(e) {
	var t = e.pos;
	if (e.eat(92)) {
		if (this.regexp_eatAtomEscape(e)) return !0;
		e.pos = t;
	}
	return !1;
};
f.regexp_eatUncapturingGroup = function(e) {
	var t = e.pos;
	if (e.eat(40)) {
		if (e.eat(63)) {
			if (this.options.ecmaVersion >= 16) {
				var i = this.regexp_eatModifiers(e), s = e.eat(45);
				if (i || s) {
					for (var r = 0; r < i.length; r++) {
						var o = i.charAt(r);
						i.indexOf(o, r + 1) > -1 && e.raise("Duplicate regular expression modifiers");
					}
					if (s) {
						var u = this.regexp_eatModifiers(e);
						!i && !u && e.current() === 58 && e.raise("Invalid regular expression modifiers");
						for (var p = 0; p < u.length; p++) {
							var h = u.charAt(p);
							(u.indexOf(h, p + 1) > -1 || i.indexOf(h) > -1) && e.raise("Duplicate regular expression modifiers");
						}
					}
				}
			}
			if (e.eat(58)) {
				if (this.regexp_disjunction(e), e.eat(41)) return !0;
				e.raise("Unterminated group");
			}
		}
		e.pos = t;
	}
	return !1;
};
f.regexp_eatCapturingGroup = function(e) {
	if (e.eat(40)) {
		if (this.options.ecmaVersion >= 9 ? this.regexp_groupSpecifier(e) : e.current() === 63 && e.raise("Invalid group"), this.regexp_disjunction(e), e.eat(41)) return e.numCapturingParens += 1, !0;
		e.raise("Unterminated group");
	}
	return !1;
};
f.regexp_eatModifiers = function(e) {
	for (var t = "", i = 0; (i = e.current()) !== -1 && ps(i);) t += q(i), e.advance();
	return t;
};
function ps(e) {
	return e === 105 || e === 109 || e === 115;
}
f.regexp_eatExtendedAtom = function(e) {
	return e.eat(46) || this.regexp_eatReverseSolidusAtomEscape(e) || this.regexp_eatCharacterClass(e) || this.regexp_eatUncapturingGroup(e) || this.regexp_eatCapturingGroup(e) || this.regexp_eatInvalidBracedQuantifier(e) || this.regexp_eatExtendedPatternCharacter(e);
};
f.regexp_eatInvalidBracedQuantifier = function(e) {
	return this.regexp_eatBracedQuantifier(e, !0) && e.raise("Nothing to repeat"), !1;
};
f.regexp_eatSyntaxCharacter = function(e) {
	var t = e.current();
	return jt(t) ? (e.lastIntValue = t, e.advance(), !0) : !1;
};
function jt(e) {
	return e === 36 || e >= 40 && e <= 43 || e === 46 || e === 63 || e >= 91 && e <= 94 || e >= 123 && e <= 125;
}
f.regexp_eatPatternCharacters = function(e) {
	for (var t = e.pos, i = 0; (i = e.current()) !== -1 && !jt(i);) e.advance();
	return e.pos !== t;
};
f.regexp_eatExtendedPatternCharacter = function(e) {
	var t = e.current();
	return t !== -1 && t !== 36 && !(t >= 40 && t <= 43) && t !== 46 && t !== 63 && t !== 91 && t !== 94 && t !== 124 ? (e.advance(), !0) : !1;
};
f.regexp_groupSpecifier = function(e) {
	if (e.eat(63)) {
		this.regexp_eatGroupName(e) || e.raise("Invalid group");
		var t = this.options.ecmaVersion >= 16, i = e.groupNames[e.lastStringValue];
		if (i) if (t) for (var s = 0, r = i; s < r.length; s += 1) r[s].separatedFrom(e.branchID) || e.raise("Duplicate capture group name");
		else e.raise("Duplicate capture group name");
		t ? (i || (e.groupNames[e.lastStringValue] = [])).push(e.branchID) : e.groupNames[e.lastStringValue] = !0;
	}
};
f.regexp_eatGroupName = function(e) {
	if (e.lastStringValue = "", e.eat(60)) {
		if (this.regexp_eatRegExpIdentifierName(e) && e.eat(62)) return !0;
		e.raise("Invalid capture group name");
	}
	return !1;
};
f.regexp_eatRegExpIdentifierName = function(e) {
	if (e.lastStringValue = "", this.regexp_eatRegExpIdentifierStart(e)) {
		for (e.lastStringValue += q(e.lastIntValue); this.regexp_eatRegExpIdentifierPart(e);) e.lastStringValue += q(e.lastIntValue);
		return !0;
	}
	return !1;
};
f.regexp_eatRegExpIdentifierStart = function(e) {
	var t = e.pos, i = this.options.ecmaVersion >= 11, s = e.current(i);
	return e.advance(i), s === 92 && this.regexp_eatRegExpUnicodeEscapeSequence(e, i) && (s = e.lastIntValue), cs(s) ? (e.lastIntValue = s, !0) : (e.pos = t, !1);
};
function cs(e) {
	return j(e, !0) || e === 36 || e === 95;
}
f.regexp_eatRegExpIdentifierPart = function(e) {
	var t = e.pos, i = this.options.ecmaVersion >= 11, s = e.current(i);
	return e.advance(i), s === 92 && this.regexp_eatRegExpUnicodeEscapeSequence(e, i) && (s = e.lastIntValue), ls(s) ? (e.lastIntValue = s, !0) : (e.pos = t, !1);
};
function ls(e) {
	return X(e, !0) || e === 36 || e === 95 || e === 8204 || e === 8205;
}
f.regexp_eatAtomEscape = function(e) {
	return this.regexp_eatBackReference(e) || this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e) || e.switchN && this.regexp_eatKGroupName(e) ? !0 : (e.switchU && (e.current() === 99 && e.raise("Invalid unicode escape"), e.raise("Invalid escape")), !1);
};
f.regexp_eatBackReference = function(e) {
	var t = e.pos;
	if (this.regexp_eatDecimalEscape(e)) {
		var i = e.lastIntValue;
		if (e.switchU) return i > e.maxBackReference && (e.maxBackReference = i), !0;
		if (i <= e.numCapturingParens) return !0;
		e.pos = t;
	}
	return !1;
};
f.regexp_eatKGroupName = function(e) {
	if (e.eat(107)) {
		if (this.regexp_eatGroupName(e)) return e.backReferenceNames.push(e.lastStringValue), !0;
		e.raise("Invalid named reference");
	}
	return !1;
};
f.regexp_eatCharacterEscape = function(e) {
	return this.regexp_eatControlEscape(e) || this.regexp_eatCControlLetter(e) || this.regexp_eatZero(e) || this.regexp_eatHexEscapeSequence(e) || this.regexp_eatRegExpUnicodeEscapeSequence(e, !1) || !e.switchU && this.regexp_eatLegacyOctalEscapeSequence(e) || this.regexp_eatIdentityEscape(e);
};
f.regexp_eatCControlLetter = function(e) {
	var t = e.pos;
	if (e.eat(99)) {
		if (this.regexp_eatControlLetter(e)) return !0;
		e.pos = t;
	}
	return !1;
};
f.regexp_eatZero = function(e) {
	return e.current() === 48 && !Ee(e.lookahead()) ? (e.lastIntValue = 0, e.advance(), !0) : !1;
};
f.regexp_eatControlEscape = function(e) {
	var t = e.current();
	return t === 116 ? (e.lastIntValue = 9, e.advance(), !0) : t === 110 ? (e.lastIntValue = 10, e.advance(), !0) : t === 118 ? (e.lastIntValue = 11, e.advance(), !0) : t === 102 ? (e.lastIntValue = 12, e.advance(), !0) : t === 114 ? (e.lastIntValue = 13, e.advance(), !0) : !1;
};
f.regexp_eatControlLetter = function(e) {
	var t = e.current();
	return Ut(t) ? (e.lastIntValue = t % 32, e.advance(), !0) : !1;
};
function Ut(e) {
	return e >= 65 && e <= 90 || e >= 97 && e <= 122;
}
f.regexp_eatRegExpUnicodeEscapeSequence = function(e, t) {
	t === void 0 && (t = !1);
	var i = e.pos, s = t || e.switchU;
	if (e.eat(117)) {
		if (this.regexp_eatFixedHexDigits(e, 4)) {
			var r = e.lastIntValue;
			if (s && r >= 55296 && r <= 56319) {
				var o = e.pos;
				if (e.eat(92) && e.eat(117) && this.regexp_eatFixedHexDigits(e, 4)) {
					var u = e.lastIntValue;
					if (u >= 56320 && u <= 57343) return e.lastIntValue = (r - 55296) * 1024 + (u - 56320) + 65536, !0;
				}
				e.pos = o, e.lastIntValue = r;
			}
			return !0;
		}
		if (s && e.eat(123) && this.regexp_eatHexDigits(e) && e.eat(125) && fs(e.lastIntValue)) return !0;
		s && e.raise("Invalid unicode escape"), e.pos = i;
	}
	return !1;
};
function fs(e) {
	return e >= 0 && e <= 1114111;
}
f.regexp_eatIdentityEscape = function(e) {
	if (e.switchU) return this.regexp_eatSyntaxCharacter(e) ? !0 : e.eat(47) ? (e.lastIntValue = 47, !0) : !1;
	var t = e.current();
	return t !== 99 && (!e.switchN || t !== 107) ? (e.lastIntValue = t, e.advance(), !0) : !1;
};
f.regexp_eatDecimalEscape = function(e) {
	e.lastIntValue = 0;
	var t = e.current();
	if (t >= 49 && t <= 57) {
		do
			e.lastIntValue = 10 * e.lastIntValue + (t - 48), e.advance();
		while ((t = e.current()) >= 48 && t <= 57);
		return !0;
	}
	return !1;
};
var Gt = 0, J = 1, B = 2;
f.regexp_eatCharacterClassEscape = function(e) {
	var t = e.current();
	if (ds(t)) return e.lastIntValue = -1, e.advance(), J;
	var i = !1;
	if (e.switchU && this.options.ecmaVersion >= 9 && ((i = t === 80) || t === 112)) {
		e.lastIntValue = -1, e.advance();
		var s;
		if (e.eat(123) && (s = this.regexp_eatUnicodePropertyValueExpression(e)) && e.eat(125)) return i && s === B && e.raise("Invalid property name"), s;
		e.raise("Invalid property name");
	}
	return Gt;
};
function ds(e) {
	return e === 100 || e === 68 || e === 115 || e === 83 || e === 119 || e === 87;
}
f.regexp_eatUnicodePropertyValueExpression = function(e) {
	var t = e.pos;
	if (this.regexp_eatUnicodePropertyName(e) && e.eat(61)) {
		var i = e.lastStringValue;
		if (this.regexp_eatUnicodePropertyValue(e)) {
			var s = e.lastStringValue;
			return this.regexp_validateUnicodePropertyNameAndValue(e, i, s), J;
		}
	}
	if (e.pos = t, this.regexp_eatLoneUnicodePropertyNameOrValue(e)) {
		var r = e.lastStringValue;
		return this.regexp_validateUnicodePropertyNameOrValue(e, r);
	}
	return Gt;
};
f.regexp_validateUnicodePropertyNameAndValue = function(e, t, i) {
	$(e.unicodeProperties.nonBinary, t) || e.raise("Invalid property name"), e.unicodeProperties.nonBinary[t].test(i) || e.raise("Invalid property value");
};
f.regexp_validateUnicodePropertyNameOrValue = function(e, t) {
	if (e.unicodeProperties.binary.test(t)) return J;
	if (e.switchV && e.unicodeProperties.binaryOfStrings.test(t)) return B;
	e.raise("Invalid property name");
};
f.regexp_eatUnicodePropertyName = function(e) {
	var t = 0;
	for (e.lastStringValue = ""; qt(t = e.current());) e.lastStringValue += q(t), e.advance();
	return e.lastStringValue !== "";
};
function qt(e) {
	return Ut(e) || e === 95;
}
f.regexp_eatUnicodePropertyValue = function(e) {
	var t = 0;
	for (e.lastStringValue = ""; ms(t = e.current());) e.lastStringValue += q(t), e.advance();
	return e.lastStringValue !== "";
};
function ms(e) {
	return qt(e) || Ee(e);
}
f.regexp_eatLoneUnicodePropertyNameOrValue = function(e) {
	return this.regexp_eatUnicodePropertyValue(e);
};
f.regexp_eatCharacterClass = function(e) {
	if (e.eat(91)) {
		var t = e.eat(94), i = this.regexp_classContents(e);
		return e.eat(93) || e.raise("Unterminated character class"), t && i === B && e.raise("Negated character class may contain strings"), !0;
	}
	return !1;
};
f.regexp_classContents = function(e) {
	return e.current() === 93 ? J : e.switchV ? this.regexp_classSetExpression(e) : (this.regexp_nonEmptyClassRanges(e), J);
};
f.regexp_nonEmptyClassRanges = function(e) {
	for (; this.regexp_eatClassAtom(e);) {
		var t = e.lastIntValue;
		if (e.eat(45) && this.regexp_eatClassAtom(e)) {
			var i = e.lastIntValue;
			e.switchU && (t === -1 || i === -1) && e.raise("Invalid character class"), t !== -1 && i !== -1 && t > i && e.raise("Range out of order in character class");
		}
	}
};
f.regexp_eatClassAtom = function(e) {
	var t = e.pos;
	if (e.eat(92)) {
		if (this.regexp_eatClassEscape(e)) return !0;
		if (e.switchU) {
			var i = e.current();
			(i === 99 || Ht(i)) && e.raise("Invalid class escape"), e.raise("Invalid escape");
		}
		e.pos = t;
	}
	var s = e.current();
	return s !== 93 ? (e.lastIntValue = s, e.advance(), !0) : !1;
};
f.regexp_eatClassEscape = function(e) {
	var t = e.pos;
	if (e.eat(98)) return e.lastIntValue = 8, !0;
	if (e.switchU && e.eat(45)) return e.lastIntValue = 45, !0;
	if (!e.switchU && e.eat(99)) {
		if (this.regexp_eatClassControlLetter(e)) return !0;
		e.pos = t;
	}
	return this.regexp_eatCharacterClassEscape(e) || this.regexp_eatCharacterEscape(e);
};
f.regexp_classSetExpression = function(e) {
	var t = J, i;
	if (!this.regexp_eatClassSetRange(e)) if (i = this.regexp_eatClassSetOperand(e)) {
		i === B && (t = B);
		for (var s = e.pos; e.eatChars([38, 38]);) {
			if (e.current() !== 38 && (i = this.regexp_eatClassSetOperand(e))) {
				i !== B && (t = J);
				continue;
			}
			e.raise("Invalid character in character class");
		}
		if (s !== e.pos) return t;
		for (; e.eatChars([45, 45]);) this.regexp_eatClassSetOperand(e) || e.raise("Invalid character in character class");
		if (s !== e.pos) return t;
	} else e.raise("Invalid character in character class");
	for (;;) if (!this.regexp_eatClassSetRange(e)) {
		if (i = this.regexp_eatClassSetOperand(e), !i) return t;
		i === B && (t = B);
	}
};
f.regexp_eatClassSetRange = function(e) {
	var t = e.pos;
	if (this.regexp_eatClassSetCharacter(e)) {
		var i = e.lastIntValue;
		if (e.eat(45) && this.regexp_eatClassSetCharacter(e)) {
			var s = e.lastIntValue;
			return i !== -1 && s !== -1 && i > s && e.raise("Range out of order in character class"), !0;
		}
		e.pos = t;
	}
	return !1;
};
f.regexp_eatClassSetOperand = function(e) {
	return this.regexp_eatClassSetCharacter(e) ? J : this.regexp_eatClassStringDisjunction(e) || this.regexp_eatNestedClass(e);
};
f.regexp_eatNestedClass = function(e) {
	var t = e.pos;
	if (e.eat(91)) {
		var i = e.eat(94), s = this.regexp_classContents(e);
		if (e.eat(93)) return i && s === B && e.raise("Negated character class may contain strings"), s;
		e.pos = t;
	}
	if (e.eat(92)) {
		var r = this.regexp_eatCharacterClassEscape(e);
		if (r) return r;
		e.pos = t;
	}
	return null;
};
f.regexp_eatClassStringDisjunction = function(e) {
	var t = e.pos;
	if (e.eatChars([92, 113])) {
		if (e.eat(123)) {
			var i = this.regexp_classStringDisjunctionContents(e);
			if (e.eat(125)) return i;
		} else e.raise("Invalid escape");
		e.pos = t;
	}
	return null;
};
f.regexp_classStringDisjunctionContents = function(e) {
	for (var t = this.regexp_classString(e); e.eat(124);) this.regexp_classString(e) === B && (t = B);
	return t;
};
f.regexp_classString = function(e) {
	for (var t = 0; this.regexp_eatClassSetCharacter(e);) t++;
	return t === 1 ? J : B;
};
f.regexp_eatClassSetCharacter = function(e) {
	var t = e.pos;
	if (e.eat(92)) return this.regexp_eatCharacterEscape(e) || this.regexp_eatClassSetReservedPunctuator(e) ? !0 : e.eat(98) ? (e.lastIntValue = 8, !0) : (e.pos = t, !1);
	var i = e.current();
	return i < 0 || i === e.lookahead() && xs(i) || ys(i) ? !1 : (e.advance(), e.lastIntValue = i, !0);
};
function xs(e) {
	return e === 33 || e >= 35 && e <= 38 || e >= 42 && e <= 44 || e === 46 || e >= 58 && e <= 64 || e === 94 || e === 96 || e === 126;
}
function ys(e) {
	return e === 40 || e === 41 || e === 45 || e === 47 || e >= 91 && e <= 93 || e >= 123 && e <= 125;
}
f.regexp_eatClassSetReservedPunctuator = function(e) {
	var t = e.current();
	return gs(t) ? (e.lastIntValue = t, e.advance(), !0) : !1;
};
function gs(e) {
	return e === 33 || e === 35 || e === 37 || e === 38 || e === 44 || e === 45 || e >= 58 && e <= 62 || e === 64 || e === 96 || e === 126;
}
f.regexp_eatClassControlLetter = function(e) {
	var t = e.current();
	return Ee(t) || t === 95 ? (e.lastIntValue = t % 32, e.advance(), !0) : !1;
};
f.regexp_eatHexEscapeSequence = function(e) {
	var t = e.pos;
	if (e.eat(120)) {
		if (this.regexp_eatFixedHexDigits(e, 2)) return !0;
		e.switchU && e.raise("Invalid escape"), e.pos = t;
	}
	return !1;
};
f.regexp_eatDecimalDigits = function(e) {
	var t = e.pos, i = 0;
	for (e.lastIntValue = 0; Ee(i = e.current());) e.lastIntValue = 10 * e.lastIntValue + (i - 48), e.advance();
	return e.pos !== t;
};
function Ee(e) {
	return e >= 48 && e <= 57;
}
f.regexp_eatHexDigits = function(e) {
	var t = e.pos, i = 0;
	for (e.lastIntValue = 0; Jt(i = e.current());) e.lastIntValue = 16 * e.lastIntValue + Kt(i), e.advance();
	return e.pos !== t;
};
function Jt(e) {
	return e >= 48 && e <= 57 || e >= 65 && e <= 70 || e >= 97 && e <= 102;
}
function Kt(e) {
	return e >= 65 && e <= 70 ? 10 + (e - 65) : e >= 97 && e <= 102 ? 10 + (e - 97) : e - 48;
}
f.regexp_eatLegacyOctalEscapeSequence = function(e) {
	if (this.regexp_eatOctalDigit(e)) {
		var t = e.lastIntValue;
		if (this.regexp_eatOctalDigit(e)) {
			var i = e.lastIntValue;
			t <= 3 && this.regexp_eatOctalDigit(e) ? e.lastIntValue = t * 64 + i * 8 + e.lastIntValue : e.lastIntValue = t * 8 + i;
		} else e.lastIntValue = t;
		return !0;
	}
	return !1;
};
f.regexp_eatOctalDigit = function(e) {
	var t = e.current();
	return Ht(t) ? (e.lastIntValue = t - 48, e.advance(), !0) : (e.lastIntValue = 0, !1);
};
function Ht(e) {
	return e >= 48 && e <= 55;
}
f.regexp_eatFixedHexDigits = function(e, t) {
	var i = e.pos;
	e.lastIntValue = 0;
	for (var s = 0; s < t; ++s) {
		var r = e.current();
		if (!Jt(r)) return e.pos = i, !1;
		e.lastIntValue = 16 * e.lastIntValue + Kt(r), e.advance();
	}
	return !0;
};
var Qe = function(t) {
	this.type = t.type, this.value = t.value, this.start = t.start, this.end = t.end, t.options.locations && (this.loc = new be(t, t.startLoc, t.endLoc)), t.options.ranges && (this.range = [t.start, t.end]);
}, b = A.prototype;
b.next = function(e) {
	!e && this.type.keyword && this.containsEsc && this.raiseRecoverable(this.start, "Escape sequence in keyword " + this.type.keyword), this.options.onToken && this.options.onToken(new Qe(this)), this.lastTokEnd = this.end, this.lastTokStart = this.start, this.lastTokEndLoc = this.endLoc, this.lastTokStartLoc = this.startLoc, this.nextToken();
};
b.getToken = function() {
	return this.next(), new Qe(this);
};
typeof Symbol < "u" && (b[Symbol.iterator] = function() {
	var e = this;
	return { next: function() {
		var t = e.getToken();
		return {
			done: t.type === a.eof,
			value: t
		};
	} };
});
b.nextToken = function() {
	var e = this.curContext();
	if ((!e || !e.preserveSpace) && this.skipSpace(), this.start = this.pos, this.options.locations && (this.startLoc = this.curPosition()), this.pos >= this.input.length) return this.finishToken(a.eof);
	if (e.override) return e.override(this);
	this.readToken(this.fullCharCodeAtPos());
};
b.readToken = function(e) {
	return j(e, this.options.ecmaVersion >= 6) || e === 92 ? this.readWord() : this.getTokenFromCode(e);
};
b.fullCharCodeAtPos = function() {
	var e = this.input.charCodeAt(this.pos);
	if (e <= 55295 || e >= 56320) return e;
	var t = this.input.charCodeAt(this.pos + 1);
	return t <= 56319 || t >= 57344 ? e : (e << 10) + t - 56613888;
};
b.skipBlockComment = function() {
	var e = this.options.onComment && this.curPosition(), t = this.pos, i = this.input.indexOf("*/", this.pos += 2);
	if (i === -1 && this.raise(this.pos - 2, "Unterminated comment"), this.pos = i + 2, this.options.locations) for (var s = void 0, r = t; (s = xt(this.input, r, this.pos)) > -1;) ++this.curLine, r = this.lineStart = s;
	this.options.onComment && this.options.onComment(!0, this.input.slice(t + 2, i), t, this.pos, e, this.curPosition());
};
b.skipLineComment = function(e) {
	for (var t = this.pos, i = this.options.onComment && this.curPosition(), s = this.input.charCodeAt(this.pos += e); this.pos < this.input.length && !Y(s);) s = this.input.charCodeAt(++this.pos);
	this.options.onComment && this.options.onComment(!1, this.input.slice(t + e, this.pos), t, this.pos, i, this.curPosition());
};
b.skipSpace = function() {
	e: for (; this.pos < this.input.length;) {
		var e = this.input.charCodeAt(this.pos);
		switch (e) {
			case 32:
			case 160:
				++this.pos;
				break;
			case 13: this.input.charCodeAt(this.pos + 1) === 10 && ++this.pos;
			case 10:
			case 8232:
			case 8233:
				++this.pos, this.options.locations && (++this.curLine, this.lineStart = this.pos);
				break;
			case 47:
				switch (this.input.charCodeAt(this.pos + 1)) {
					case 42:
						this.skipBlockComment();
						break;
					case 47:
						this.skipLineComment(2);
						break;
					default: break e;
				}
				break;
			default: if (e > 8 && e < 14 || e >= 5760 && yt.test(String.fromCharCode(e))) ++this.pos;
			else break e;
		}
	}
};
b.finishToken = function(e, t) {
	this.end = this.pos, this.options.locations && (this.endLoc = this.curPosition());
	var i = this.type;
	this.type = e, this.value = t, this.updateContext(i);
};
b.readToken_dot = function() {
	var e = this.input.charCodeAt(this.pos + 1);
	if (e >= 48 && e <= 57) return this.readNumber(!0);
	var t = this.input.charCodeAt(this.pos + 2);
	return this.options.ecmaVersion >= 6 && e === 46 && t === 46 ? (this.pos += 3, this.finishToken(a.ellipsis)) : (++this.pos, this.finishToken(a.dot));
};
b.readToken_slash = function() {
	var e = this.input.charCodeAt(this.pos + 1);
	return this.exprAllowed ? (++this.pos, this.readRegexp()) : e === 61 ? this.finishOp(a.assign, 2) : this.finishOp(a.slash, 1);
};
b.readToken_mult_modulo_exp = function(e) {
	var t = this.input.charCodeAt(this.pos + 1), i = 1, s = e === 42 ? a.star : a.modulo;
	return this.options.ecmaVersion >= 7 && e === 42 && t === 42 && (++i, s = a.starstar, t = this.input.charCodeAt(this.pos + 2)), t === 61 ? this.finishOp(a.assign, i + 1) : this.finishOp(s, i);
};
b.readToken_pipe_amp = function(e) {
	var t = this.input.charCodeAt(this.pos + 1);
	if (t === e) {
		if (this.options.ecmaVersion >= 12) {
			if (this.input.charCodeAt(this.pos + 2) === 61) return this.finishOp(a.assign, 3);
		}
		return this.finishOp(e === 124 ? a.logicalOR : a.logicalAND, 2);
	}
	return t === 61 ? this.finishOp(a.assign, 2) : this.finishOp(e === 124 ? a.bitwiseOR : a.bitwiseAND, 1);
};
b.readToken_caret = function() {
	return this.input.charCodeAt(this.pos + 1) === 61 ? this.finishOp(a.assign, 2) : this.finishOp(a.bitwiseXOR, 1);
};
b.readToken_plus_min = function(e) {
	var t = this.input.charCodeAt(this.pos + 1);
	return t === e ? t === 45 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 62 && (this.lastTokEnd === 0 || L.test(this.input.slice(this.lastTokEnd, this.pos))) ? (this.skipLineComment(3), this.skipSpace(), this.nextToken()) : this.finishOp(a.incDec, 2) : t === 61 ? this.finishOp(a.assign, 2) : this.finishOp(a.plusMin, 1);
};
b.readToken_lt_gt = function(e) {
	var t = this.input.charCodeAt(this.pos + 1), i = 1;
	return t === e ? (i = e === 62 && this.input.charCodeAt(this.pos + 2) === 62 ? 3 : 2, this.input.charCodeAt(this.pos + i) === 61 ? this.finishOp(a.assign, i + 1) : this.finishOp(a.bitShift, i)) : t === 33 && e === 60 && !this.inModule && this.input.charCodeAt(this.pos + 2) === 45 && this.input.charCodeAt(this.pos + 3) === 45 ? (this.skipLineComment(4), this.skipSpace(), this.nextToken()) : (t === 61 && (i = 2), this.finishOp(a.relational, i));
};
b.readToken_eq_excl = function(e) {
	var t = this.input.charCodeAt(this.pos + 1);
	return t === 61 ? this.finishOp(a.equality, this.input.charCodeAt(this.pos + 2) === 61 ? 3 : 2) : e === 61 && t === 62 && this.options.ecmaVersion >= 6 ? (this.pos += 2, this.finishToken(a.arrow)) : this.finishOp(e === 61 ? a.eq : a.prefix, 1);
};
b.readToken_question = function() {
	var e = this.options.ecmaVersion;
	if (e >= 11) {
		var t = this.input.charCodeAt(this.pos + 1);
		if (t === 46) {
			var i = this.input.charCodeAt(this.pos + 2);
			if (i < 48 || i > 57) return this.finishOp(a.questionDot, 2);
		}
		if (t === 63) {
			if (e >= 12) {
				if (this.input.charCodeAt(this.pos + 2) === 61) return this.finishOp(a.assign, 3);
			}
			return this.finishOp(a.coalesce, 2);
		}
	}
	return this.finishOp(a.question, 1);
};
b.readToken_numberSign = function() {
	var e = this.options.ecmaVersion, t = 35;
	if (e >= 13 && (++this.pos, t = this.fullCharCodeAtPos(), j(t, !0) || t === 92)) return this.finishToken(a.privateId, this.readWord1());
	this.raise(this.pos, "Unexpected character '" + q(t) + "'");
};
b.getTokenFromCode = function(e) {
	switch (e) {
		case 46: return this.readToken_dot();
		case 40: return ++this.pos, this.finishToken(a.parenL);
		case 41: return ++this.pos, this.finishToken(a.parenR);
		case 59: return ++this.pos, this.finishToken(a.semi);
		case 44: return ++this.pos, this.finishToken(a.comma);
		case 91: return ++this.pos, this.finishToken(a.bracketL);
		case 93: return ++this.pos, this.finishToken(a.bracketR);
		case 123: return ++this.pos, this.finishToken(a.braceL);
		case 125: return ++this.pos, this.finishToken(a.braceR);
		case 58: return ++this.pos, this.finishToken(a.colon);
		case 96:
			if (this.options.ecmaVersion < 6) break;
			return ++this.pos, this.finishToken(a.backQuote);
		case 48:
			var t = this.input.charCodeAt(this.pos + 1);
			if (t === 120 || t === 88) return this.readRadixNumber(16);
			if (this.options.ecmaVersion >= 6) {
				if (t === 111 || t === 79) return this.readRadixNumber(8);
				if (t === 98 || t === 66) return this.readRadixNumber(2);
			}
		case 49:
		case 50:
		case 51:
		case 52:
		case 53:
		case 54:
		case 55:
		case 56:
		case 57: return this.readNumber(!1);
		case 34:
		case 39: return this.readString(e);
		case 47: return this.readToken_slash();
		case 37:
		case 42: return this.readToken_mult_modulo_exp(e);
		case 124:
		case 38: return this.readToken_pipe_amp(e);
		case 94: return this.readToken_caret();
		case 43:
		case 45: return this.readToken_plus_min(e);
		case 60:
		case 62: return this.readToken_lt_gt(e);
		case 61:
		case 33: return this.readToken_eq_excl(e);
		case 63: return this.readToken_question();
		case 126: return this.finishOp(a.prefix, 1);
		case 35: return this.readToken_numberSign();
	}
	this.raise(this.pos, "Unexpected character '" + q(e) + "'");
};
b.finishOp = function(e, t) {
	var i = this.input.slice(this.pos, this.pos + t);
	return this.pos += t, this.finishToken(e, i);
};
b.readRegexp = function() {
	for (var e, t, i = this.pos;;) {
		this.pos >= this.input.length && this.raise(i, "Unterminated regular expression");
		var s = this.input.charAt(this.pos);
		if (L.test(s) && this.raise(i, "Unterminated regular expression"), e) e = !1;
		else {
			if (s === "[") t = !0;
			else if (s === "]" && t) t = !1;
			else if (s === "/" && !t) break;
			e = s === "\\";
		}
		++this.pos;
	}
	var r = this.input.slice(i, this.pos);
	++this.pos;
	var o = this.pos, u = this.readWord1();
	this.containsEsc && this.unexpected(o);
	var p = this.regexpState || (this.regexpState = new G(this));
	p.reset(i, r, u), this.validateRegExpFlags(p), this.validateRegExpPattern(p);
	var h = null;
	try {
		h = new RegExp(r, u);
	} catch {}
	return this.finishToken(a.regexp, {
		pattern: r,
		flags: u,
		value: h
	});
};
b.readInt = function(e, t, i) {
	for (var s = this.options.ecmaVersion >= 12 && t === void 0, r = i && this.input.charCodeAt(this.pos) === 48, o = this.pos, u = 0, p = 0, h = 0, l = t ?? Infinity; h < l; ++h, ++this.pos) {
		var m = this.input.charCodeAt(this.pos), S = void 0;
		if (s && m === 95) {
			r && this.raiseRecoverable(this.pos, "Numeric separator is not allowed in legacy octal numeric literals"), p === 95 && this.raiseRecoverable(this.pos, "Numeric separator must be exactly one underscore"), h === 0 && this.raiseRecoverable(this.pos, "Numeric separator is not allowed at the first of digits"), p = m;
			continue;
		}
		if (m >= 97 ? S = m - 97 + 10 : m >= 65 ? S = m - 65 + 10 : m >= 48 && m <= 57 ? S = m - 48 : S = Infinity, S >= e) break;
		p = m, u = u * e + S;
	}
	return s && p === 95 && this.raiseRecoverable(this.pos - 1, "Numeric separator is not allowed at the last of digits"), this.pos === o || t != null && this.pos - o !== t ? null : u;
};
function vs(e, t) {
	return t ? parseInt(e, 8) : parseFloat(e.replace(/_/g, ""));
}
function Xt(e) {
	return typeof BigInt != "function" ? null : BigInt(e.replace(/_/g, ""));
}
b.readRadixNumber = function(e) {
	var t = this.pos;
	this.pos += 2;
	var i = this.readInt(e);
	return i ?? this.raise(this.start + 2, "Expected number in radix " + e), this.options.ecmaVersion >= 11 && this.input.charCodeAt(this.pos) === 110 ? (i = Xt(this.input.slice(t, this.pos)), ++this.pos) : j(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(a.num, i);
};
b.readNumber = function(e) {
	var t = this.pos;
	!e && this.readInt(10, void 0, !0) === null && this.raise(t, "Invalid number");
	var i = this.pos - t >= 2 && this.input.charCodeAt(t) === 48;
	i && this.strict && this.raise(t, "Invalid number");
	var s = this.input.charCodeAt(this.pos);
	if (!i && !e && this.options.ecmaVersion >= 11 && s === 110) {
		var r = Xt(this.input.slice(t, this.pos));
		return ++this.pos, j(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number"), this.finishToken(a.num, r);
	}
	i && /[89]/.test(this.input.slice(t, this.pos)) && (i = !1), s === 46 && !i && (++this.pos, this.readInt(10), s = this.input.charCodeAt(this.pos)), (s === 69 || s === 101) && !i && (s = this.input.charCodeAt(++this.pos), (s === 43 || s === 45) && ++this.pos, this.readInt(10) === null && this.raise(t, "Invalid number")), j(this.fullCharCodeAtPos()) && this.raise(this.pos, "Identifier directly after number");
	var o = vs(this.input.slice(t, this.pos), i);
	return this.finishToken(a.num, o);
};
b.readCodePoint = function() {
	var e = this.input.charCodeAt(this.pos), t;
	if (e === 123) {
		this.options.ecmaVersion < 6 && this.unexpected();
		var i = ++this.pos;
		t = this.readHexChar(this.input.indexOf("}", this.pos) - this.pos), ++this.pos, t > 1114111 && this.invalidStringToken(i, "Code point out of bounds");
	} else t = this.readHexChar(4);
	return t;
};
b.readString = function(e) {
	for (var t = "", i = ++this.pos;;) {
		this.pos >= this.input.length && this.raise(this.start, "Unterminated string constant");
		var s = this.input.charCodeAt(this.pos);
		if (s === e) break;
		s === 92 ? (t += this.input.slice(i, this.pos), t += this.readEscapedChar(!1), i = this.pos) : s === 8232 || s === 8233 ? (this.options.ecmaVersion < 10 && this.raise(this.start, "Unterminated string constant"), ++this.pos, this.options.locations && (this.curLine++, this.lineStart = this.pos)) : (Y(s) && this.raise(this.start, "Unterminated string constant"), ++this.pos);
	}
	return t += this.input.slice(i, this.pos++), this.finishToken(a.string, t);
};
var Wt = {};
b.tryReadTemplateToken = function() {
	this.inTemplateElement = !0;
	try {
		this.readTmplToken();
	} catch (e) {
		if (e === Wt) this.readInvalidTemplateToken();
		else throw e;
	}
	this.inTemplateElement = !1;
};
b.invalidStringToken = function(e, t) {
	if (this.inTemplateElement && this.options.ecmaVersion >= 9) throw Wt;
	this.raise(e, t);
};
b.readTmplToken = function() {
	for (var e = "", t = this.pos;;) {
		this.pos >= this.input.length && this.raise(this.start, "Unterminated template");
		var i = this.input.charCodeAt(this.pos);
		if (i === 96 || i === 36 && this.input.charCodeAt(this.pos + 1) === 123) return this.pos === this.start && (this.type === a.template || this.type === a.invalidTemplate) ? i === 36 ? (this.pos += 2, this.finishToken(a.dollarBraceL)) : (++this.pos, this.finishToken(a.backQuote)) : (e += this.input.slice(t, this.pos), this.finishToken(a.template, e));
		if (i === 92) e += this.input.slice(t, this.pos), e += this.readEscapedChar(!0), t = this.pos;
		else if (Y(i)) {
			switch (e += this.input.slice(t, this.pos), ++this.pos, i) {
				case 13: this.input.charCodeAt(this.pos) === 10 && ++this.pos;
				case 10:
					e += `
`;
					break;
				default:
					e += String.fromCharCode(i);
					break;
			}
			this.options.locations && (++this.curLine, this.lineStart = this.pos), t = this.pos;
		} else ++this.pos;
	}
};
b.readInvalidTemplateToken = function() {
	for (; this.pos < this.input.length; this.pos++) switch (this.input[this.pos]) {
		case "\\":
			++this.pos;
			break;
		case "$": if (this.input[this.pos + 1] !== "{") break;
		case "`": return this.finishToken(a.invalidTemplate, this.input.slice(this.start, this.pos));
		case "\r": this.input[this.pos + 1] === `
` && ++this.pos;
		case `
`:
		case "\u2028":
		case "\u2029":
			++this.curLine, this.lineStart = this.pos + 1;
			break;
	}
	this.raise(this.start, "Unterminated template");
};
b.readEscapedChar = function(e) {
	var t = this.input.charCodeAt(++this.pos);
	switch (++this.pos, t) {
		case 110: return `
`;
		case 114: return "\r";
		case 120: return String.fromCharCode(this.readHexChar(2));
		case 117: return q(this.readCodePoint());
		case 116: return "	";
		case 98: return "\b";
		case 118: return "\v";
		case 102: return "\f";
		case 13: this.input.charCodeAt(this.pos) === 10 && ++this.pos;
		case 10: return this.options.locations && (this.lineStart = this.pos, ++this.curLine), "";
		case 56:
		case 57: if (this.strict && this.invalidStringToken(this.pos - 1, "Invalid escape sequence"), e) {
			var i = this.pos - 1;
			this.invalidStringToken(i, "Invalid escape sequence in template string");
		}
		default:
			if (t >= 48 && t <= 55) {
				var s = this.input.substr(this.pos - 1, 3).match(/^[0-7]+/)[0], r = parseInt(s, 8);
				return r > 255 && (s = s.slice(0, -1), r = parseInt(s, 8)), this.pos += s.length - 1, t = this.input.charCodeAt(this.pos), (s !== "0" || t === 56 || t === 57) && (this.strict || e) && this.invalidStringToken(this.pos - 1 - s.length, e ? "Octal literal in template string" : "Octal literal in strict mode"), String.fromCharCode(r);
			}
			return Y(t) ? (this.options.locations && (this.lineStart = this.pos, ++this.curLine), "") : String.fromCharCode(t);
	}
};
b.readHexChar = function(e) {
	var t = this.pos, i = this.readInt(16, e);
	return i === null && this.invalidStringToken(t, "Bad character escape sequence"), i;
};
b.readWord1 = function() {
	this.containsEsc = !1;
	for (var e = "", t = !0, i = this.pos, s = this.options.ecmaVersion >= 6; this.pos < this.input.length;) {
		var r = this.fullCharCodeAtPos();
		if (X(r, s)) this.pos += r <= 65535 ? 1 : 2;
		else if (r === 92) {
			this.containsEsc = !0, e += this.input.slice(i, this.pos);
			var o = this.pos;
			this.input.charCodeAt(++this.pos) !== 117 && this.invalidStringToken(this.pos, "Expecting Unicode escape sequence \\uXXXX"), ++this.pos;
			var u = this.readCodePoint();
			(t ? j : X)(u, s) || this.invalidStringToken(o, "Invalid Unicode escape"), e += q(u), i = this.pos;
		} else break;
		t = !1;
	}
	return e + this.input.slice(i, this.pos);
};
b.readWord = function() {
	var e = this.readWord1(), t = a.name;
	return this.keywords.test(e) && (t = Je[e]), this.finishToken(t, e);
};
A.acorn = {
	Parser: A,
	version: "8.15.0",
	defaultOptions: Ue,
	Position: ne,
	SourceLocation: be,
	getLineInfo: vt,
	Node: Te,
	TokenType: C,
	tokTypes: a,
	keywordTypes: Je,
	TokContext: F,
	tokContexts: T,
	isIdentifierChar: X,
	isIdentifierStart: j,
	Token: Qe,
	isNewLine: Y,
	lineBreak: L,
	lineBreakG: qi,
	nonASCIIwhitespace: yt
};
var Si = ut($e(), 1);
function As(e, t) {
	let i = /* @__PURE__ */ new SyntaxError(e + " (" + t.loc.start.line + ":" + t.loc.start.column + ")");
	return Object.assign(i, t);
}
var Ae = As;
function ke(e) {
	let t = [];
	for (let i of e) try {
		return i();
	} catch (s) {
		t.push(s);
	}
	throw Object.assign(/* @__PURE__ */ new Error("All combinations failed"), { errors: t });
}
var te = (e, t) => (i, s, ...r) => i | 1 && s == null ? void 0 : (t.call(s) ?? s[e]).apply(s, r);
var ks = Array.prototype.findLast ?? function(e) {
	for (let t = this.length - 1; t >= 0; t--) {
		let i = this[t];
		if (e(i, t, this)) return i;
	}
}, Zt = te("findLast", function() {
	if (Array.isArray(this)) return ks;
});
function Ps(e) {
	return this[e < 0 ? this.length + e : e];
}
var ie = te("at", function() {
	if (Array.isArray(this) || typeof this == "string") return Ps;
});
function M(e) {
	let t = e.range?.[0] ?? e.start, i = (e.declaration?.decorators ?? e.decorators)?.[0];
	return i ? Math.min(M(i), t) : t;
}
function R(e) {
	return e.range?.[1] ?? e.end;
}
function Ns(e) {
	let t = new Set(e);
	return (i) => t.has(i?.type);
}
var se = Ns;
var re = se([
	"Block",
	"CommentBlock",
	"MultiLine"
]);
var ei = se([
	"Line",
	"CommentLine",
	"SingleLine",
	"HashbangComment",
	"HTMLOpen",
	"HTMLClose",
	"Hashbang",
	"InterpreterDirective"
]);
var Ze = /* @__PURE__ */ new WeakMap();
function Vs(e) {
	return Ze.has(e) || Ze.set(e, re(e) && e.value[0] === "*" && /@(?:type|satisfies)\b/u.test(e.value)), Ze.get(e);
}
var ti = Vs;
function Os(e) {
	if (!re(e)) return !1;
	let t = `*${e.value}*`.split(`
`);
	return t.length > 1 && t.every((i) => i.trimStart()[0] === "*");
}
var et = /* @__PURE__ */ new WeakMap();
function Bs(e) {
	return et.has(e) || et.set(e, Os(e)), et.get(e);
}
var tt = Bs;
function Ds(e) {
	if (e.length < 2) return;
	let t;
	for (let i = e.length - 1; i >= 0; i--) {
		let s = e[i];
		if (t && R(s) === M(t) && tt(s) && tt(t) && (e.splice(i + 1, 1), s.value += "*//*" + t.value, s.range = [M(s), R(t)]), !ei(s) && !re(s)) throw new TypeError(`Unknown comment type: "${s.type}".`);
		t = s;
	}
}
var ii = Ds;
function Ms(e) {
	return e !== null && typeof e == "object";
}
var si = Ms;
var ce = null;
function le(e) {
	if (ce !== null && typeof ce.property) {
		let t = ce;
		return ce = le.prototype = null, t;
	}
	return ce = le.prototype = e ?? Object.create(null), new le();
}
var Fs = 10;
for (let e = 0; e <= Fs; e++) le();
function it(e) {
	return le(e);
}
function js(e, t = "type") {
	it(e);
	function i(s) {
		let r = s[t], o = e[r];
		if (!Array.isArray(o)) throw Object.assign(/* @__PURE__ */ new Error(`Missing visitor keys for '${r}'.`), { node: s });
		return o;
	}
	return i;
}
var ri = js;
var n = [
	[
		"decorators",
		"key",
		"typeAnnotation",
		"value"
	],
	[],
	["elementType"],
	["expression"],
	["expression", "typeAnnotation"],
	["left", "right"],
	["argument"],
	["directives", "body"],
	["label"],
	[
		"callee",
		"typeArguments",
		"arguments"
	],
	["body"],
	[
		"decorators",
		"id",
		"typeParameters",
		"superClass",
		"superTypeArguments",
		"mixins",
		"implements",
		"body",
		"superTypeParameters"
	],
	["id", "typeParameters"],
	[
		"decorators",
		"key",
		"typeParameters",
		"params",
		"returnType",
		"body"
	],
	[
		"decorators",
		"variance",
		"key",
		"typeAnnotation",
		"value"
	],
	["name", "typeAnnotation"],
	[
		"test",
		"consequent",
		"alternate"
	],
	[
		"checkType",
		"extendsType",
		"trueType",
		"falseType"
	],
	["value"],
	["id", "body"],
	[
		"declaration",
		"specifiers",
		"source",
		"attributes"
	],
	["id"],
	[
		"id",
		"typeParameters",
		"extends",
		"body"
	],
	["typeAnnotation"],
	[
		"id",
		"typeParameters",
		"right"
	],
	["body", "test"],
	["members"],
	["id", "init"],
	["exported"],
	[
		"left",
		"right",
		"body"
	],
	[
		"id",
		"typeParameters",
		"params",
		"predicate",
		"returnType",
		"body"
	],
	[
		"id",
		"params",
		"body",
		"typeParameters",
		"returnType"
	],
	["key", "value"],
	["local"],
	["objectType", "indexType"],
	["typeParameter"],
	["types"],
	["node"],
	["object", "property"],
	["argument", "cases"],
	[
		"pattern",
		"body",
		"guard"
	],
	["literal"],
	[
		"decorators",
		"key",
		"value"
	],
	["expressions"],
	["qualification", "id"],
	[
		"decorators",
		"key",
		"typeAnnotation"
	],
	[
		"typeParameters",
		"params",
		"returnType"
	],
	["expression", "typeArguments"],
	["params"],
	["parameterName", "typeAnnotation"]
];
var ni = ri({
	AccessorProperty: n[0],
	AnyTypeAnnotation: n[1],
	ArgumentPlaceholder: n[1],
	ArrayExpression: ["elements"],
	ArrayPattern: [
		"elements",
		"typeAnnotation",
		"decorators"
	],
	ArrayTypeAnnotation: n[2],
	ArrowFunctionExpression: [
		"typeParameters",
		"params",
		"predicate",
		"returnType",
		"body"
	],
	AsConstExpression: n[3],
	AsExpression: n[4],
	AssignmentExpression: n[5],
	AssignmentPattern: [
		"left",
		"right",
		"decorators",
		"typeAnnotation"
	],
	AwaitExpression: n[6],
	BigIntLiteral: n[1],
	BigIntLiteralTypeAnnotation: n[1],
	BigIntTypeAnnotation: n[1],
	BinaryExpression: n[5],
	BindExpression: ["object", "callee"],
	BlockStatement: n[7],
	BooleanLiteral: n[1],
	BooleanLiteralTypeAnnotation: n[1],
	BooleanTypeAnnotation: n[1],
	BreakStatement: n[8],
	CallExpression: n[9],
	CatchClause: ["param", "body"],
	ChainExpression: n[3],
	ClassAccessorProperty: n[0],
	ClassBody: n[10],
	ClassDeclaration: n[11],
	ClassExpression: n[11],
	ClassImplements: n[12],
	ClassMethod: n[13],
	ClassPrivateMethod: n[13],
	ClassPrivateProperty: n[14],
	ClassProperty: n[14],
	ComponentDeclaration: [
		"id",
		"params",
		"body",
		"typeParameters",
		"rendersType"
	],
	ComponentParameter: ["name", "local"],
	ComponentTypeAnnotation: [
		"params",
		"rest",
		"typeParameters",
		"rendersType"
	],
	ComponentTypeParameter: n[15],
	ConditionalExpression: n[16],
	ConditionalTypeAnnotation: n[17],
	ContinueStatement: n[8],
	DebuggerStatement: n[1],
	DeclareClass: [
		"id",
		"typeParameters",
		"extends",
		"mixins",
		"implements",
		"body"
	],
	DeclareComponent: [
		"id",
		"params",
		"rest",
		"typeParameters",
		"rendersType"
	],
	DeclaredPredicate: n[18],
	DeclareEnum: n[19],
	DeclareExportAllDeclaration: ["source", "attributes"],
	DeclareExportDeclaration: n[20],
	DeclareFunction: ["id", "predicate"],
	DeclareHook: n[21],
	DeclareInterface: n[22],
	DeclareModule: n[19],
	DeclareModuleExports: n[23],
	DeclareNamespace: n[19],
	DeclareOpaqueType: [
		"id",
		"typeParameters",
		"supertype",
		"lowerBound",
		"upperBound"
	],
	DeclareTypeAlias: n[24],
	DeclareVariable: n[21],
	Decorator: n[3],
	Directive: n[18],
	DirectiveLiteral: n[1],
	DoExpression: n[10],
	DoWhileStatement: n[25],
	EmptyStatement: n[1],
	EmptyTypeAnnotation: n[1],
	EnumBigIntBody: n[26],
	EnumBigIntMember: n[27],
	EnumBooleanBody: n[26],
	EnumBooleanMember: n[27],
	EnumDeclaration: n[19],
	EnumDefaultedMember: n[21],
	EnumNumberBody: n[26],
	EnumNumberMember: n[27],
	EnumStringBody: n[26],
	EnumStringMember: n[27],
	EnumSymbolBody: n[26],
	ExistsTypeAnnotation: n[1],
	ExperimentalRestProperty: n[6],
	ExperimentalSpreadProperty: n[6],
	ExportAllDeclaration: [
		"source",
		"attributes",
		"exported"
	],
	ExportDefaultDeclaration: ["declaration"],
	ExportDefaultSpecifier: n[28],
	ExportNamedDeclaration: n[20],
	ExportNamespaceSpecifier: n[28],
	ExportSpecifier: ["local", "exported"],
	ExpressionStatement: n[3],
	File: ["program"],
	ForInStatement: n[29],
	ForOfStatement: n[29],
	ForStatement: [
		"init",
		"test",
		"update",
		"body"
	],
	FunctionDeclaration: n[30],
	FunctionExpression: n[30],
	FunctionTypeAnnotation: [
		"typeParameters",
		"this",
		"params",
		"rest",
		"returnType"
	],
	FunctionTypeParam: n[15],
	GenericTypeAnnotation: n[12],
	HookDeclaration: n[31],
	HookTypeAnnotation: [
		"params",
		"returnType",
		"rest",
		"typeParameters"
	],
	Identifier: ["typeAnnotation", "decorators"],
	IfStatement: n[16],
	ImportAttribute: n[32],
	ImportDeclaration: [
		"specifiers",
		"source",
		"attributes"
	],
	ImportDefaultSpecifier: n[33],
	ImportExpression: ["source", "options"],
	ImportNamespaceSpecifier: n[33],
	ImportSpecifier: ["imported", "local"],
	IndexedAccessType: n[34],
	InferredPredicate: n[1],
	InferTypeAnnotation: n[35],
	InterfaceDeclaration: n[22],
	InterfaceExtends: n[12],
	InterfaceTypeAnnotation: ["extends", "body"],
	InterpreterDirective: n[1],
	IntersectionTypeAnnotation: n[36],
	JsExpressionRoot: n[37],
	JsonRoot: n[37],
	JSXAttribute: ["name", "value"],
	JSXClosingElement: ["name"],
	JSXClosingFragment: n[1],
	JSXElement: [
		"openingElement",
		"children",
		"closingElement"
	],
	JSXEmptyExpression: n[1],
	JSXExpressionContainer: n[3],
	JSXFragment: [
		"openingFragment",
		"children",
		"closingFragment"
	],
	JSXIdentifier: n[1],
	JSXMemberExpression: n[38],
	JSXNamespacedName: ["namespace", "name"],
	JSXOpeningElement: [
		"name",
		"typeArguments",
		"attributes"
	],
	JSXOpeningFragment: n[1],
	JSXSpreadAttribute: n[6],
	JSXSpreadChild: n[3],
	JSXText: n[1],
	KeyofTypeAnnotation: n[6],
	LabeledStatement: ["label", "body"],
	Literal: n[1],
	LogicalExpression: n[5],
	MatchArrayPattern: ["elements", "rest"],
	MatchAsPattern: ["pattern", "target"],
	MatchBindingPattern: n[21],
	MatchExpression: n[39],
	MatchExpressionCase: n[40],
	MatchIdentifierPattern: n[21],
	MatchLiteralPattern: n[41],
	MatchMemberPattern: ["base", "property"],
	MatchObjectPattern: ["properties", "rest"],
	MatchObjectPatternProperty: ["key", "pattern"],
	MatchOrPattern: ["patterns"],
	MatchRestPattern: n[6],
	MatchStatement: n[39],
	MatchStatementCase: n[40],
	MatchUnaryPattern: n[6],
	MatchWildcardPattern: n[1],
	MemberExpression: n[38],
	MetaProperty: ["meta", "property"],
	MethodDefinition: n[42],
	MixedTypeAnnotation: n[1],
	ModuleExpression: n[10],
	NeverTypeAnnotation: n[1],
	NewExpression: n[9],
	NGChainedExpression: n[43],
	NGEmptyExpression: n[1],
	NGMicrosyntax: n[10],
	NGMicrosyntaxAs: ["key", "alias"],
	NGMicrosyntaxExpression: ["expression", "alias"],
	NGMicrosyntaxKey: n[1],
	NGMicrosyntaxKeyedExpression: ["key", "expression"],
	NGMicrosyntaxLet: n[32],
	NGPipeExpression: [
		"left",
		"right",
		"arguments"
	],
	NGRoot: n[37],
	NullableTypeAnnotation: n[23],
	NullLiteral: n[1],
	NullLiteralTypeAnnotation: n[1],
	NumberLiteralTypeAnnotation: n[1],
	NumberTypeAnnotation: n[1],
	NumericLiteral: n[1],
	ObjectExpression: ["properties"],
	ObjectMethod: n[13],
	ObjectPattern: [
		"decorators",
		"properties",
		"typeAnnotation"
	],
	ObjectProperty: n[42],
	ObjectTypeAnnotation: [
		"properties",
		"indexers",
		"callProperties",
		"internalSlots"
	],
	ObjectTypeCallProperty: n[18],
	ObjectTypeIndexer: [
		"variance",
		"id",
		"key",
		"value"
	],
	ObjectTypeInternalSlot: ["id", "value"],
	ObjectTypeMappedTypeProperty: [
		"keyTparam",
		"propType",
		"sourceType",
		"variance"
	],
	ObjectTypeProperty: [
		"key",
		"value",
		"variance"
	],
	ObjectTypeSpreadProperty: n[6],
	OpaqueType: [
		"id",
		"typeParameters",
		"supertype",
		"impltype",
		"lowerBound",
		"upperBound"
	],
	OptionalCallExpression: n[9],
	OptionalIndexedAccessType: n[34],
	OptionalMemberExpression: n[38],
	ParenthesizedExpression: n[3],
	PipelineBareFunction: ["callee"],
	PipelinePrimaryTopicReference: n[1],
	PipelineTopicExpression: n[3],
	Placeholder: n[1],
	PrivateIdentifier: n[1],
	PrivateName: n[21],
	Program: n[7],
	Property: n[32],
	PropertyDefinition: n[14],
	QualifiedTypeIdentifier: n[44],
	QualifiedTypeofIdentifier: n[44],
	RegExpLiteral: n[1],
	RestElement: [
		"argument",
		"typeAnnotation",
		"decorators"
	],
	ReturnStatement: n[6],
	SatisfiesExpression: n[4],
	SequenceExpression: n[43],
	SpreadElement: n[6],
	StaticBlock: n[10],
	StringLiteral: n[1],
	StringLiteralTypeAnnotation: n[1],
	StringTypeAnnotation: n[1],
	Super: n[1],
	SwitchCase: ["test", "consequent"],
	SwitchStatement: ["discriminant", "cases"],
	SymbolTypeAnnotation: n[1],
	TaggedTemplateExpression: [
		"tag",
		"typeArguments",
		"quasi"
	],
	TemplateElement: n[1],
	TemplateLiteral: ["quasis", "expressions"],
	ThisExpression: n[1],
	ThisTypeAnnotation: n[1],
	ThrowStatement: n[6],
	TopicReference: n[1],
	TryStatement: [
		"block",
		"handler",
		"finalizer"
	],
	TSAbstractAccessorProperty: n[45],
	TSAbstractKeyword: n[1],
	TSAbstractMethodDefinition: n[32],
	TSAbstractPropertyDefinition: n[45],
	TSAnyKeyword: n[1],
	TSArrayType: n[2],
	TSAsExpression: n[4],
	TSAsyncKeyword: n[1],
	TSBigIntKeyword: n[1],
	TSBooleanKeyword: n[1],
	TSCallSignatureDeclaration: n[46],
	TSClassImplements: n[47],
	TSConditionalType: n[17],
	TSConstructorType: n[46],
	TSConstructSignatureDeclaration: n[46],
	TSDeclareFunction: n[31],
	TSDeclareKeyword: n[1],
	TSDeclareMethod: [
		"decorators",
		"key",
		"typeParameters",
		"params",
		"returnType"
	],
	TSEmptyBodyFunctionExpression: [
		"id",
		"typeParameters",
		"params",
		"returnType"
	],
	TSEnumBody: n[26],
	TSEnumDeclaration: n[19],
	TSEnumMember: ["id", "initializer"],
	TSExportAssignment: n[3],
	TSExportKeyword: n[1],
	TSExternalModuleReference: n[3],
	TSFunctionType: n[46],
	TSImportEqualsDeclaration: ["id", "moduleReference"],
	TSImportType: [
		"options",
		"qualifier",
		"typeArguments",
		"source"
	],
	TSIndexedAccessType: n[34],
	TSIndexSignature: ["parameters", "typeAnnotation"],
	TSInferType: n[35],
	TSInstantiationExpression: n[47],
	TSInterfaceBody: n[10],
	TSInterfaceDeclaration: n[22],
	TSInterfaceHeritage: n[47],
	TSIntersectionType: n[36],
	TSIntrinsicKeyword: n[1],
	TSJSDocAllType: n[1],
	TSJSDocNonNullableType: n[23],
	TSJSDocNullableType: n[23],
	TSJSDocUnknownType: n[1],
	TSLiteralType: n[41],
	TSMappedType: [
		"key",
		"constraint",
		"nameType",
		"typeAnnotation"
	],
	TSMethodSignature: [
		"key",
		"typeParameters",
		"params",
		"returnType"
	],
	TSModuleBlock: n[10],
	TSModuleDeclaration: n[19],
	TSNamedTupleMember: ["label", "elementType"],
	TSNamespaceExportDeclaration: n[21],
	TSNeverKeyword: n[1],
	TSNonNullExpression: n[3],
	TSNullKeyword: n[1],
	TSNumberKeyword: n[1],
	TSObjectKeyword: n[1],
	TSOptionalType: n[23],
	TSParameterProperty: ["parameter", "decorators"],
	TSParenthesizedType: n[23],
	TSPrivateKeyword: n[1],
	TSPropertySignature: ["key", "typeAnnotation"],
	TSProtectedKeyword: n[1],
	TSPublicKeyword: n[1],
	TSQualifiedName: n[5],
	TSReadonlyKeyword: n[1],
	TSRestType: n[23],
	TSSatisfiesExpression: n[4],
	TSStaticKeyword: n[1],
	TSStringKeyword: n[1],
	TSSymbolKeyword: n[1],
	TSTemplateLiteralType: ["quasis", "types"],
	TSThisType: n[1],
	TSTupleType: ["elementTypes"],
	TSTypeAliasDeclaration: [
		"id",
		"typeParameters",
		"typeAnnotation"
	],
	TSTypeAnnotation: n[23],
	TSTypeAssertion: n[4],
	TSTypeLiteral: n[26],
	TSTypeOperator: n[23],
	TSTypeParameter: [
		"name",
		"constraint",
		"default"
	],
	TSTypeParameterDeclaration: n[48],
	TSTypeParameterInstantiation: n[48],
	TSTypePredicate: n[49],
	TSTypeQuery: ["exprName", "typeArguments"],
	TSTypeReference: ["typeName", "typeArguments"],
	TSUndefinedKeyword: n[1],
	TSUnionType: n[36],
	TSUnknownKeyword: n[1],
	TSVoidKeyword: n[1],
	TupleTypeAnnotation: ["types", "elementTypes"],
	TupleTypeLabeledElement: [
		"label",
		"elementType",
		"variance"
	],
	TupleTypeSpreadElement: ["label", "typeAnnotation"],
	TypeAlias: n[24],
	TypeAnnotation: n[23],
	TypeCastExpression: n[4],
	TypeofTypeAnnotation: ["argument", "typeArguments"],
	TypeOperator: n[23],
	TypeParameter: [
		"bound",
		"default",
		"variance"
	],
	TypeParameterDeclaration: n[48],
	TypeParameterInstantiation: n[48],
	TypePredicate: n[49],
	UnaryExpression: n[6],
	UndefinedTypeAnnotation: n[1],
	UnionTypeAnnotation: n[36],
	UnknownTypeAnnotation: n[1],
	UpdateExpression: n[6],
	V8IntrinsicIdentifier: n[1],
	VariableDeclaration: ["declarations"],
	VariableDeclarator: n[27],
	Variance: n[1],
	VoidPattern: n[1],
	VoidTypeAnnotation: n[1],
	WhileStatement: n[25],
	WithStatement: ["object", "body"],
	YieldExpression: n[6]
});
function we(e, t) {
	if (!si(e)) return e;
	if (Array.isArray(e)) {
		for (let s = 0; s < e.length; s++) e[s] = we(e[s], t);
		return e;
	}
	if (t.onEnter) {
		let s = t.onEnter(e) ?? e;
		if (s !== e) return we(s, t);
		e = s;
	}
	let i = ni(e);
	for (let s = 0; s < i.length; s++) e[i[s]] = we(e[i[s]], t);
	return t.onLeave && (e = t.onLeave(e) || e), e;
}
var oi = we;
se([
	"RegExpLiteral",
	"BigIntLiteral",
	"NumericLiteral",
	"StringLiteral",
	"DirectiveLiteral",
	"Literal",
	"JSXText",
	"TemplateElement",
	"StringLiteralTypeAnnotation",
	"NumberLiteralTypeAnnotation",
	"BigIntLiteralTypeAnnotation"
]);
function Gs(e, t) {
	let { parser: i, text: s } = t, { comments: r } = e, o = i === "oxc" && t.oxcAstType === "ts";
	ii(r);
	let u = e.type === "File" ? e.program : e;
	u.interpreter && (r.unshift(u.interpreter), delete u.interpreter), o && e.hashbang && (r.unshift(e.hashbang), delete e.hashbang), e.type === "Program" && (e.range = [0, s.length]);
	let p;
	return e = oi(e, {
		onEnter(h) {
			switch (h.type) {
				case "ParenthesizedExpression": {
					let { expression: l } = h, m = M(h);
					if (l.type === "TypeCastExpression") return l.range = [m, R(h)], l;
					let S = !1;
					if (!o) {
						if (!p) {
							p = [];
							for (let c of r) ti(c) && p.push(R(c));
						}
						let E = Zt(0, p, (c) => c <= m);
						S = E && s.slice(E, m).trim().length === 0;
					}
					return S ? void 0 : (l.extra = {
						...l.extra,
						parenthesized: !0
					}, l);
				}
				case "TemplateLiteral":
					if (h.expressions.length !== h.quasis.length - 1) throw new Error("Malformed template literal.");
					break;
				case "TemplateElement":
					if (i === "flow" || i === "hermes" || i === "espree" || i === "typescript" || o) h.range = [M(h) + 1, R(h) - (h.tail ? 1 : 2)];
					break;
				case "VariableDeclaration": {
					let l = ie(0, h.declarations, -1);
					l?.init && s[R(l)] !== ";" && (h.range = [M(h), R(l)]);
					break;
				}
				case "TSParenthesizedType": return h.typeAnnotation;
				case "TopicReference":
					e.extra = {
						...e.extra,
						__isUsingHackPipeline: !0
					};
					break;
				case "TSUnionType":
				case "TSIntersectionType":
					if (h.types.length === 1) return h.types[0];
					break;
				case "ImportExpression":
					i === "hermes" && h.attributes && !h.options && (h.options = h.attributes);
					break;
			}
		},
		onLeave(h) {
			switch (h.type) {
				case "LogicalExpression":
					if (ui(h)) return st(h);
					break;
				case "TSImportType":
					!h.source && h.argument.type === "TSLiteralType" && (h.source = h.argument.literal, delete h.argument);
					break;
			}
		}
	}), e;
}
function ui(e) {
	return e.type === "LogicalExpression" && e.right.type === "LogicalExpression" && e.operator === e.right.operator;
}
function st(e) {
	return ui(e) ? st({
		type: "LogicalExpression",
		operator: e.operator,
		left: st({
			type: "LogicalExpression",
			operator: e.operator,
			left: e.left,
			right: e.right.left,
			range: [M(e.left), R(e.right.left)]
		}),
		right: e.right.right,
		range: [M(e), R(e)]
	}) : e;
}
var Pe = Gs;
var qs = String.prototype.replaceAll ?? function(e, t) {
	return e.global ? this.replace(e, t) : this.split(e).join(t);
}, fe = te("replaceAll", function() {
	if (typeof this == "string") return qs;
});
var Ks = /\*\/$/, Hs = /^\/\*\*?/, Xs = /^\s*(\/\*\*?(.|\r?\n)*?\*\/)/, Ws = /(^|\s+)\/\/([^\n\r]*)/g, hi = /^(\r?\n)+/, zs = /(?:^|\r?\n) *(@[^\n\r]*?) *\r?\n *(?![^\n\r@]*\/\/[^]*)([^\s@][^\n\r@]+?) *\r?\n/g, pi = /(?:^|\r?\n) *@(\S+) *([^\n\r]*)/g, Qs = /(\r?\n|^) *\* ?/g, Ys = [];
function ci(e) {
	let t = e.match(Xs);
	return t ? t[0].trimStart() : "";
}
function li(e) {
	e = fe(0, e.replace(Hs, "").replace(Ks, ""), Qs, "$1");
	let i = "";
	for (; i !== e;) i = e, e = fe(0, e, zs, `
$1 $2
`);
	e = e.replace(hi, "").trimEnd();
	let s = Object.create(null), r = fe(0, e, pi, "").replace(hi, "").trimEnd(), o;
	for (; o = pi.exec(e);) {
		let u = fe(0, o[2], Ws, "");
		if (typeof s[o[1]] == "string" || Array.isArray(s[o[1]])) {
			let p = s[o[1]];
			s[o[1]] = [
				...Ys,
				...Array.isArray(p) ? p : [p],
				u
			];
		} else s[o[1]] = u;
	}
	return {
		comments: r,
		pragmas: s
	};
}
var fi = ["noformat", "noprettier"], di = ["format", "prettier"];
function $s(e) {
	if (!e.startsWith("#!")) return "";
	let t = e.indexOf(`
`);
	return t === -1 ? e : e.slice(0, t);
}
var mi = $s;
function xi(e) {
	let t = mi(e);
	t && (e = e.slice(t.length + 1));
	let { pragmas: s, comments: r } = li(ci(e));
	return {
		shebang: t,
		text: e,
		pragmas: s,
		comments: r
	};
}
function yi(e) {
	let { pragmas: t } = xi(e);
	return di.some((i) => Object.prototype.hasOwnProperty.call(t, i));
}
function gi(e) {
	let { pragmas: t } = xi(e);
	return fi.some((i) => Object.prototype.hasOwnProperty.call(t, i));
}
function Zs(e) {
	return e = typeof e == "function" ? { parse: e } : e, {
		astFormat: "estree",
		hasPragma: yi,
		hasIgnorePragma: gi,
		locStart: M,
		locEnd: R,
		...e
	};
}
var Ie = Zs;
var Ne = "module", vi = "script", Le = "commonjs", Re = [Ne, Le];
function Ve(e) {
	if (typeof e == "string") {
		if (e = e.toLowerCase(), /\.(?:mjs|mts)$/iu.test(e)) return Ne;
		if (/\.(?:cjs|cts)$/iu.test(e)) return Le;
	}
}
var er = {
	ecmaVersion: "latest",
	allowReserved: !0,
	allowReturnOutsideFunction: !0,
	allowSuperOutsideMethod: !0,
	checkPrivateFields: !1,
	locations: !1,
	ranges: !0,
	preserveParens: !0
};
function tr(e) {
	let { message: t, loc: i } = e;
	if (!i) return e;
	let { line: s, column: r } = i;
	return Ae(t.replace(/ \(\d+:\d+\)$/u, ""), {
		loc: { start: {
			line: s,
			column: r + 1
		} },
		cause: e
	});
}
var bi, ir = () => (bi ?? (bi = A.extend((0, Si.default)())), bi);
function sr(e, t) {
	let i = ir(), s = [], r = i.parse(e, {
		...er,
		sourceType: t === Le ? vi : t,
		allowImportExportEverywhere: t === Ne,
		onComment: s
	});
	return r.comments = s, r;
}
function rr(e, t) {
	let i = Ve(t?.filepath), s = (i ? [i] : Re).map((o) => () => sr(e, o)), r;
	try {
		r = ke(s);
	} catch ({ errors: [o] }) {
		throw tr(o);
	}
	return Pe(r, { text: e });
}
var _i = Ie(rr);
var Ai = ut($e(), 1);
var P = {
	Boolean: "Boolean",
	EOF: "<end>",
	Identifier: "Identifier",
	PrivateIdentifier: "PrivateIdentifier",
	Keyword: "Keyword",
	Null: "Null",
	Numeric: "Numeric",
	Punctuator: "Punctuator",
	String: "String",
	RegularExpression: "RegularExpression",
	Template: "Template",
	JSXIdentifier: "JSXIdentifier",
	JSXText: "JSXText"
};
function ar(e, t) {
	let i = e[0], s = ie(0, e, -1), r = {
		type: P.Template,
		value: t.slice(i.start, s.end)
	};
	return i.loc && (r.loc = {
		start: i.loc.start,
		end: s.loc.end
	}), i.range && (r.start = i.range[0], r.end = s.range[1], r.range = [r.start, r.end]), r;
}
function rt(e, t) {
	this._acornTokTypes = e, this._tokens = [], this._curlyBrace = null, this._code = t;
}
rt.prototype = {
	constructor: rt,
	translate(e, t) {
		let i = e.type, s = this._acornTokTypes;
		if (i === s.name) e.type = P.Identifier, e.value === "static" && (e.type = P.Keyword), t.ecmaVersion > 5 && (e.value === "yield" || e.value === "let") && (e.type = P.Keyword);
		else if (i === s.privateId) e.type = P.PrivateIdentifier;
		else if (i === s.semi || i === s.comma || i === s.parenL || i === s.parenR || i === s.braceL || i === s.braceR || i === s.dot || i === s.bracketL || i === s.colon || i === s.question || i === s.bracketR || i === s.ellipsis || i === s.arrow || i === s.jsxTagStart || i === s.incDec || i === s.starstar || i === s.jsxTagEnd || i === s.prefix || i === s.questionDot || i.binop && !i.keyword || i.isAssign) e.type = P.Punctuator, e.value = this._code.slice(e.start, e.end);
		else if (i === s.jsxName) e.type = P.JSXIdentifier;
		else if (i.label === "jsxText" || i === s.jsxAttrValueToken) e.type = P.JSXText;
		else if (i.keyword) i.keyword === "true" || i.keyword === "false" ? e.type = P.Boolean : i.keyword === "null" ? e.type = P.Null : e.type = P.Keyword;
		else if (i === s.num) e.type = P.Numeric, e.value = this._code.slice(e.start, e.end);
		else if (i === s.string) t.jsxAttrValueToken ? (t.jsxAttrValueToken = !1, e.type = P.JSXText) : e.type = P.String, e.value = this._code.slice(e.start, e.end);
		else if (i === s.regexp) {
			e.type = P.RegularExpression;
			let r = e.value;
			e.regex = {
				flags: r.flags,
				pattern: r.pattern
			}, e.value = `/${r.pattern}/${r.flags}`;
		}
		return e;
	},
	onToken(e, t) {
		let i = this._acornTokTypes, s = t.tokens, r = this._tokens, o = () => {
			s.push(ar(this._tokens, this._code)), this._tokens = [];
		};
		if (e.type === i.eof) {
			this._curlyBrace && s.push(this.translate(this._curlyBrace, t));
			return;
		}
		if (e.type === i.backQuote) {
			this._curlyBrace && (s.push(this.translate(this._curlyBrace, t)), this._curlyBrace = null), r.push(e), r.length > 1 && o();
			return;
		}
		if (e.type === i.dollarBraceL) {
			r.push(e), o();
			return;
		}
		if (e.type === i.braceR) {
			this._curlyBrace && s.push(this.translate(this._curlyBrace, t)), this._curlyBrace = e;
			return;
		}
		if (e.type === i.template || e.type === i.invalidTemplate) {
			this._curlyBrace && (r.push(this._curlyBrace), this._curlyBrace = null), r.push(e);
			return;
		}
		this._curlyBrace && (s.push(this.translate(this._curlyBrace, t)), this._curlyBrace = null), s.push(this.translate(e, t));
	}
};
var Ci = rt;
var Ti = [
	3,
	5,
	6,
	7,
	8,
	9,
	10,
	11,
	12,
	13,
	14,
	15,
	16,
	17
];
function nr() {
	return ie(0, Ti, -1);
}
function or(e = 5) {
	let t = e === "latest" ? nr() : e;
	if (typeof t != "number") throw new Error(`ecmaVersion must be a number or "latest". Received value of type ${typeof e} instead.`);
	if (t >= 2015 && (t -= 2009), !Ti.includes(t)) throw new Error("Invalid ecmaVersion.");
	return t;
}
function ur(e = "script") {
	if (e === "script" || e === "module") return e;
	if (e === "commonjs") return "script";
	throw new Error("Invalid sourceType.");
}
function Ei(e) {
	let t = or(e.ecmaVersion), i = ur(e.sourceType), s = e.range === !0, r = e.loc === !0;
	if (t !== 3 && e.allowReserved) throw new Error("`allowReserved` is only supported when ecmaVersion is 3");
	if (typeof e.allowReserved < "u" && typeof e.allowReserved != "boolean") throw new Error("`allowReserved`, when present, must be `true` or `false`");
	let o = t === 3 ? e.allowReserved || "never" : !1, u = e.ecmaFeatures || {}, p = e.sourceType === "commonjs" || !!u.globalReturn;
	if (i === "module" && t < 6) throw new Error("sourceType 'module' is not supported when ecmaVersion < 2015. Consider adding `{ ecmaVersion: 2015 }` to the parser options.");
	return Object.assign({}, e, {
		ecmaVersion: t,
		sourceType: i,
		ranges: s,
		locations: r,
		allowReserved: o,
		allowReturnOutsideFunction: p
	});
}
var Q = Symbol("espree's internal state"), at = Symbol("espree's esprimaFinishNode");
function hr(e, t, i, s, r, o, u) {
	let p;
	e ? p = "Block" : u.slice(i, i + 2) === "#!" ? p = "Hashbang" : p = "Line";
	let h = {
		type: p,
		value: t
	};
	return typeof i == "number" && (h.start = i, h.end = s, h.range = [i, s]), typeof r == "object" && (h.loc = {
		start: r,
		end: o
	}), h;
}
var nt = () => (e) => {
	let t = Object.assign({}, e.acorn.tokTypes);
	return e.acornJsx && Object.assign(t, e.acornJsx.tokTypes), class extends e {
		constructor(s, r) {
			(typeof s != "object" || s === null) && (s = {}), typeof r != "string" && !(r instanceof String) && (r = String(r));
			let o = s.sourceType, u = Ei(s), p = u.ecmaFeatures || {}, h = u.tokens === !0 ? new Ci(t, r) : null, l = {
				originalSourceType: o || u.sourceType,
				tokens: h ? [] : null,
				comments: u.comment === !0 ? [] : null,
				impliedStrict: p.impliedStrict === !0 && u.ecmaVersion >= 5,
				ecmaVersion: u.ecmaVersion,
				jsxAttrValueToken: !1,
				lastToken: null,
				templateElements: []
			};
			super({
				ecmaVersion: u.ecmaVersion,
				sourceType: u.sourceType,
				ranges: u.ranges,
				locations: u.locations,
				allowReserved: u.allowReserved,
				allowReturnOutsideFunction: u.allowReturnOutsideFunction,
				onToken(m) {
					h && h.onToken(m, l), m.type !== t.eof && (l.lastToken = m);
				},
				onComment(m, S, E, c, x, y) {
					if (l.comments) {
						let v = hr(m, S, E, c, x, y, r);
						l.comments.push(v);
					}
				}
			}, r), this[Q] = l;
		}
		tokenize() {
			do
				this.next();
			while (this.type !== t.eof);
			this.next();
			let s = this[Q], r = s.tokens;
			return s.comments && (r.comments = s.comments), r;
		}
		finishNode(...s) {
			let r = super.finishNode(...s);
			return this[at](r);
		}
		finishNodeAt(...s) {
			let r = super.finishNodeAt(...s);
			return this[at](r);
		}
		parse() {
			let s = this[Q], r = super.parse();
			return r.sourceType = s.originalSourceType, s.comments && (r.comments = s.comments), s.tokens && (r.tokens = s.tokens), this[Q].templateElements.forEach((o) => {
				let p = o.tail ? 1 : 2;
				o.start += -1, o.end += p, o.range && (o.range[0] += -1, o.range[1] += p), o.loc && (o.loc.start.column += -1, o.loc.end.column += p);
			}), r;
		}
		parseTopLevel(s) {
			return this[Q].impliedStrict && (this.strict = !0), super.parseTopLevel(s);
		}
		raise(s, r) {
			let o = e.acorn.getLineInfo(this.input, s), u = new SyntaxError(r);
			throw u.index = s, u.lineNumber = o.line, u.column = o.column + 1, u;
		}
		raiseRecoverable(s, r) {
			this.raise(s, r);
		}
		unexpected(s) {
			let r = "Unexpected token";
			if (s != null) {
				if (this.pos = s, this.options.locations) for (; this.pos < this.lineStart;) this.lineStart = this.input.lastIndexOf(`
`, this.lineStart - 2) + 1, --this.curLine;
				this.nextToken();
			}
			this.end > this.start && (r += ` ${this.input.slice(this.start, this.end)}`), this.raise(this.start, r);
		}
		jsx_readString(s) {
			let r = super.jsx_readString(s);
			return this.type === t.string && (this[Q].jsxAttrValueToken = !0), r;
		}
		[at](s) {
			return s.type === "TemplateElement" && this[Q].templateElements.push(s), s.type.includes("Function") && !s.generator && (s.generator = !1), s;
		}
	};
};
var pr = {
	_regular: null,
	_jsx: null,
	get regular() {
		return this._regular === null && (this._regular = A.extend(nt())), this._regular;
	},
	get jsx() {
		return this._jsx === null && (this._jsx = A.extend((0, Ai.default)(), nt())), this._jsx;
	},
	get(e) {
		return !!(e && e.ecmaFeatures && e.ecmaFeatures.jsx) ? this.jsx : this.regular;
	}
};
function ki(e, t) {
	return new (pr.get(t))(t, e).parse();
}
var cr = {
	ecmaVersion: "latest",
	range: !0,
	loc: !1,
	comment: !0,
	tokens: !1,
	ecmaFeatures: {
		jsx: !0,
		impliedStrict: !1
	}
};
function lr(e) {
	let { message: t, lineNumber: i, column: s } = e;
	return typeof i != "number" ? e : Ae(t, {
		loc: { start: {
			line: i,
			column: s
		} },
		cause: e
	});
}
function fr(e, t) {
	let i = Ve(t?.filepath), s = (i ? [i] : Re).map((o) => () => ki(e, {
		...cr,
		sourceType: o
	})), r;
	try {
		r = ke(s);
	} catch ({ errors: [o] }) {
		throw lr(o);
	}
	return Pe(r, {
		parser: "espree",
		text: e
	});
}
var dr = {
	acorn: _i,
	espree: Ie(fr)
};
//#endregion
export { Pi as default, dr as parsers };
